import typing

import android.accessibilityservice
import android.animation
import android.app.assist
import android.content
import android.content.pm
import android.content.res
import android.database
import android.graphics
import android.graphics.drawable
import android.media
import android.media.session
import android.net
import android.os
import android.service.notification
import android.transition
import android.util
import android.view
import android.view.accessibility
import android.widget
import android.window
import java
import java.chaquopy
import java.io
import java.lang
import java.text
import java.time
import java.util
import java.util.concurrent
import java.util.function

class ActionBar(java.lang.Object):
    DISPLAY_HOME_AS_UP: typing.ClassVar[int] = ...
    DISPLAY_SHOW_CUSTOM: typing.ClassVar[int] = ...
    DISPLAY_SHOW_HOME: typing.ClassVar[int] = ...
    DISPLAY_SHOW_TITLE: typing.ClassVar[int] = ...
    DISPLAY_USE_LOGO: typing.ClassVar[int] = ...
    NAVIGATION_MODE_LIST: typing.ClassVar[int] = ...
    NAVIGATION_MODE_STANDARD: typing.ClassVar[int] = ...
    NAVIGATION_MODE_TABS: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def addOnMenuVisibilityListener(self, arg1: ActionBar.OnMenuVisibilityListener, /) -> None: ...
    @typing.overload
    def addTab(self, arg1: ActionBar.Tab, /) -> None: ...
    @typing.overload
    def addTab(self, arg1: ActionBar.Tab, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def addTab(self, arg1: ActionBar.Tab, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def addTab(self, arg1: ActionBar.Tab, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getCustomView(self) -> android.view.View: ...
    def getDisplayOptions(self) -> int: ...
    def getElevation(self) -> float: ...
    def getHeight(self) -> int: ...
    def getHideOffset(self) -> int: ...
    def getNavigationItemCount(self) -> int: ...
    def getNavigationMode(self) -> int: ...
    def getSelectedNavigationIndex(self) -> int: ...
    def getSelectedTab(self) -> ActionBar.Tab | None: ...
    def getSubtitle(self) -> java.lang.CharSequence | None: ...
    def getTabAt(self, arg1: int | java.jint | java.lang.Integer, /) -> ActionBar.Tab: ...
    def getTabCount(self) -> int: ...
    def getThemedContext(self) -> android.content.Context: ...
    def getTitle(self) -> java.lang.CharSequence | None: ...
    def hide(self) -> None: ...
    def isHideOnContentScrollEnabled(self) -> bool: ...
    def isShowing(self) -> bool: ...
    def newTab(self) -> ActionBar.Tab: ...
    def removeAllTabs(self) -> None: ...
    def removeOnMenuVisibilityListener(self, arg1: ActionBar.OnMenuVisibilityListener, /) -> None: ...
    def removeTab(self, arg1: ActionBar.Tab, /) -> None: ...
    def removeTabAt(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def selectTab(self, arg1: ActionBar.Tab, /) -> None: ...
    def setBackgroundDrawable(self, arg1: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setCustomView(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCustomView(self, arg1: android.view.View, /) -> None: ...
    @typing.overload
    def setCustomView(self, arg1: android.view.View, arg2: ActionBar.LayoutParams, /) -> None: ...
    def setDisplayHomeAsUpEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setDisplayOptions(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setDisplayOptions(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDisplayShowCustomEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDisplayShowHomeEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDisplayShowTitleEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setDisplayUseLogoEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setElevation(self, elevation: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setHideOffset(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
    def setHideOnContentScrollEnabled(self, hideOnContentScroll: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setHomeActionContentDescription(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setHomeActionContentDescription(self, description: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setHomeAsUpIndicator(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setHomeAsUpIndicator(self, indicator: android.graphics.drawable.Drawable, /) -> None: ...
    def setHomeButtonEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setIcon(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setIcon(self, arg1: android.graphics.drawable.Drawable, /) -> None: ...
    def setListNavigationCallbacks(self, arg1: android.widget.SpinnerAdapter, arg2: ActionBar.OnNavigationListener, /) -> None: ...
    @typing.overload
    def setLogo(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLogo(self, arg1: android.graphics.drawable.Drawable, /) -> None: ...
    def setNavigationMode(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSelectedNavigationItem(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSplitBackgroundDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setStackedBackgroundDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def setSubtitle(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setSubtitle(self, arg1: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setTitle(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, arg1: java.lang.CharSequence, /) -> None: ...
    def show(self) -> None: ...

    class TabListener(java.lang.Object):
        def onTabReselected(self, arg1: ActionBar.Tab, arg2: FragmentTransaction, /) -> None: ...
        def onTabSelected(self, arg1: ActionBar.Tab, arg2: FragmentTransaction, /) -> None: ...
        def onTabUnselected(self, arg1: ActionBar.Tab, arg2: FragmentTransaction, /) -> None: ...

    class Tab(java.lang.Object):
        INVALID_POSITION: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        def getContentDescription(self) -> java.lang.CharSequence: ...
        def getCustomView(self) -> android.view.View: ...
        def getIcon(self) -> android.graphics.drawable.Drawable: ...
        def getPosition(self) -> int: ...
        def getTag(self) -> java.lang.Object: ...
        def getText(self) -> java.lang.CharSequence: ...
        def select(self) -> None: ...
        @typing.overload
        def setContentDescription(self, arg1: int | java.jint | java.lang.Integer, /) -> ActionBar.Tab: ...
        @typing.overload
        def setContentDescription(self, arg1: java.lang.CharSequence, /) -> ActionBar.Tab: ...
        @typing.overload
        def setCustomView(self, arg1: int | java.jint | java.lang.Integer, /) -> ActionBar.Tab: ...
        @typing.overload
        def setCustomView(self, arg1: android.view.View, /) -> ActionBar.Tab: ...
        @typing.overload
        def setIcon(self, arg1: int | java.jint | java.lang.Integer, /) -> ActionBar.Tab: ...
        @typing.overload
        def setIcon(self, arg1: android.graphics.drawable.Drawable, /) -> ActionBar.Tab: ...
        def setTabListener(self, arg1: ActionBar.TabListener, /) -> ActionBar.Tab: ...
        def setTag(self, arg1: java.lang.Object | int | bool | float | str, /) -> ActionBar.Tab: ...
        @typing.overload
        def setText(self, arg1: int | java.jint | java.lang.Integer, /) -> ActionBar.Tab: ...
        @typing.overload
        def setText(self, arg1: java.lang.CharSequence, /) -> ActionBar.Tab: ...

    class OnNavigationListener(java.lang.Object):
        def onNavigationItemSelected(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, /) -> bool: ...

    class OnMenuVisibilityListener(java.lang.Object):
        def onMenuVisibilityChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class LayoutParams(android.view.ViewGroup.MarginLayoutParams):
        gravity: int = ...
        @typing.overload
        def __init__(self, gravity: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, source: ActionBar.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, source: android.view.ViewGroup.LayoutParams, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, c: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
        @typing.overload
        def __init__(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, gravity: int | java.jint | java.lang.Integer, /) -> None: ...

class Activity(android.content.ComponentCallbacks2, android.view.ContextThemeWrapper, android.view.KeyEvent.Callback, android.view.LayoutInflater.Factory2, android.view.View.OnCreateContextMenuListener, android.view.Window.Callback):
    DEFAULT_KEYS_DIALER: typing.ClassVar[int] = ...
    DEFAULT_KEYS_DISABLE: typing.ClassVar[int] = ...
    DEFAULT_KEYS_SEARCH_GLOBAL: typing.ClassVar[int] = ...
    DEFAULT_KEYS_SEARCH_LOCAL: typing.ClassVar[int] = ...
    DEFAULT_KEYS_SHORTCUT: typing.ClassVar[int] = ...
    FOCUSED_STATE_SET: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    FULLSCREEN_MODE_REQUEST_ENTER: typing.ClassVar[int] = ...
    FULLSCREEN_MODE_REQUEST_EXIT: typing.ClassVar[int] = ...
    OVERRIDE_TRANSITION_CLOSE: typing.ClassVar[int] = ...
    OVERRIDE_TRANSITION_OPEN: typing.ClassVar[int] = ...
    RESULT_CANCELED: typing.ClassVar[int] = ...
    RESULT_FIRST_USER: typing.ClassVar[int] = ...
    RESULT_OK: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def addContentView(self, view: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def attachBaseContext(self, newBase: android.content.Context, /) -> None: ...
    def clearOverrideActivityTransition(self, overrideType: int | java.jint | java.lang.Integer, /) -> None: ...
    def closeContextMenu(self) -> None: ...
    def closeOptionsMenu(self) -> None: ...
    def createPendingResult(self, requestCode: int | java.jint | java.lang.Integer, data: android.content.Intent, flags: int | java.jint | java.lang.Integer, /) -> PendingIntent | None: ...
    def dismissDialog(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def dismissKeyboardShortcutsHelper(self) -> None: ...
    def dispatchGenericMotionEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchKeyShortcutEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchPopulateAccessibilityEvent(self, event: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
    def dispatchTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def dispatchTrackballEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def dump(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def enterPictureInPictureMode(self) -> None: ...
    @typing.overload
    def enterPictureInPictureMode(self, params: PictureInPictureParams, /) -> bool: ...
    def findViewById(self, id: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def finish(self) -> None: ...
    def finishActivity(self, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def finishActivityFromChild(self, child: Activity, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def finishAffinity(self) -> None: ...
    def finishAfterTransition(self) -> None: ...
    def finishAndRemoveTask(self) -> None: ...
    def finishFromChild(self, child: Activity, /) -> None: ...
    def getActionBar(self) -> ActionBar | None: ...
    def getApplication(self) -> Application: ...
    def getCaller(self) -> ComponentCaller | None: ...
    def getCallingActivity(self) -> android.content.ComponentName | None: ...
    def getCallingPackage(self) -> str | None: ...
    def getChangingConfigurations(self) -> int: ...
    def getComponentName(self) -> android.content.ComponentName: ...
    def getContentScene(self) -> android.transition.Scene | None: ...
    def getContentTransitionManager(self) -> android.transition.TransitionManager | None: ...
    def getCurrentCaller(self) -> ComponentCaller: ...
    def getCurrentFocus(self) -> android.view.View | None: ...
    def getFragmentManager(self) -> FragmentManager: ...
    def getInitialCaller(self) -> ComponentCaller: ...
    def getIntent(self) -> android.content.Intent: ...
    def getLastNonConfigurationInstance(self) -> java.lang.Object | None: ...
    def getLaunchedFromPackage(self) -> str | None: ...
    def getLaunchedFromUid(self) -> int: ...
    def getLayoutInflater(self) -> android.view.LayoutInflater: ...
    def getLoaderManager(self) -> LoaderManager: ...
    def getLocalClassName(self) -> str: ...
    def getMaxNumPictureInPictureActions(self) -> int: ...
    def getMediaController(self) -> android.media.session.MediaController: ...
    def getMenuInflater(self) -> android.view.MenuInflater: ...
    def getOnBackInvokedDispatcher(self) -> android.window.OnBackInvokedDispatcher: ...
    def getParent(self) -> Activity: ...
    def getParentActivityIntent(self) -> android.content.Intent | None: ...
    def getPreferences(self, mode: int | java.jint | java.lang.Integer, /) -> android.content.SharedPreferences: ...
    def getReferrer(self) -> android.net.Uri | None: ...
    def getRequestedOrientation(self) -> int: ...
    def getSearchEvent(self) -> android.view.SearchEvent: ...
    def getSplashScreen(self) -> android.window.SplashScreen: ...
    def getSystemService(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def getTaskId(self) -> int: ...
    def getTitle(self) -> java.lang.CharSequence: ...
    def getTitleColor(self) -> int: ...
    def getVoiceInteractor(self) -> VoiceInteractor: ...
    def getVolumeControlStream(self) -> int: ...
    def getWindow(self) -> android.view.Window | None: ...
    def getWindowManager(self) -> android.view.WindowManager: ...
    def hasWindowFocus(self) -> bool: ...
    def invalidateOptionsMenu(self) -> None: ...
    def isActivityTransitionRunning(self) -> bool: ...
    def isChangingConfigurations(self) -> bool: ...
    def isChild(self) -> bool: ...
    def isDestroyed(self) -> bool: ...
    def isFinishing(self) -> bool: ...
    def isImmersive(self) -> bool: ...
    def isInMultiWindowMode(self) -> bool: ...
    def isInPictureInPictureMode(self) -> bool: ...
    def isLaunchedFromBubble(self) -> bool: ...
    def isLocalVoiceInteractionSupported(self) -> bool: ...
    def isTaskRoot(self) -> bool: ...
    def isVoiceInteraction(self) -> bool: ...
    def isVoiceInteractionRoot(self) -> bool: ...
    def managedQuery(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, /) -> android.database.Cursor: ...
    def moveTaskToBack(self, nonRoot: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def navigateUpTo(self, upIntent: android.content.Intent, /) -> bool: ...
    def navigateUpToFromChild(self, child: Activity, upIntent: android.content.Intent, /) -> bool: ...
    def onActionModeFinished(self, mode: android.view.ActionMode, /) -> None: ...
    def onActionModeStarted(self, mode: android.view.ActionMode, /) -> None: ...
    def onActivityReenter(self, resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, /) -> None: ...
    @typing.overload
    def onActivityResult(self, requestCode: int | java.jint | java.lang.Integer, resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, /) -> None: ...
    @typing.overload
    def onActivityResult(self, requestCode: int | java.jint | java.lang.Integer, resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, caller: ComponentCaller, /) -> None: ...
    def onApplyThemeResource(self, theme: android.content.res.Resources.Theme, resid: int | java.jint | java.lang.Integer, first: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onAttachFragment(self, fragment: Fragment, /) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onBackPressed(self) -> None: ...
    def onChildTitleChanged(self, childActivity: Activity, title: java.lang.CharSequence, /) -> None: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onContentChanged(self) -> None: ...
    def onContextItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def onContextMenuClosed(self, menu: android.view.Menu, /) -> None: ...
    @typing.overload
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def onCreate(self, savedInstanceState: android.os.Bundle, persistentState: android.os.PersistableBundle, /) -> None: ...
    def onCreateContextMenu(self, menu: android.view.ContextMenu, v: android.view.View, menuInfo: android.view.ContextMenu.ContextMenuInfo, /) -> None: ...
    def onCreateDescription(self) -> java.lang.CharSequence | None: ...
    @typing.overload
    def onCreateDialog(self, id: int | java.jint | java.lang.Integer, /) -> Dialog: ...
    @typing.overload
    def onCreateDialog(self, id: int | java.jint | java.lang.Integer, args: android.os.Bundle, /) -> Dialog: ...
    def onCreateNavigateUpTaskStack(self, builder: TaskStackBuilder, /) -> None: ...
    def onCreateOptionsMenu(self, menu: android.view.Menu, /) -> bool: ...
    def onCreatePanelMenu(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> bool: ...
    def onCreatePanelView(self, featureId: int | java.jint | java.lang.Integer, /) -> android.view.View | None: ...
    def onCreateThumbnail(self, outBitmap: android.graphics.Bitmap, canvas: android.graphics.Canvas, /) -> bool: ...
    @typing.overload
    def onCreateView(self, name: str | java.lang.String, context: android.content.Context, attrs: android.util.AttributeSet, /) -> android.view.View | None: ...
    @typing.overload
    def onCreateView(self, parent: android.view.View, name: str | java.lang.String, context: android.content.Context, attrs: android.util.AttributeSet, /) -> android.view.View | None: ...
    def onDestroy(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onEnterAnimationComplete(self) -> None: ...
    def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onGetDirectActions(self, cancellationSignal: android.os.CancellationSignal, callback: java.util.function.Consumer[java.util.List[DirectAction]], /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyLongPress(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, repeatCount: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyShortcut(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onLocalVoiceInteractionStarted(self) -> None: ...
    def onLocalVoiceInteractionStopped(self) -> None: ...
    def onLowMemory(self) -> None: ...
    def onMenuItemSelected(self, featureId: int | java.jint | java.lang.Integer, item: android.view.MenuItem, /) -> bool: ...
    def onMenuOpened(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> bool: ...
    @typing.overload
    def onMultiWindowModeChanged(self, isInMultiWindowMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onMultiWindowModeChanged(self, isInMultiWindowMode: bool | java.jboolean | java.lang.Boolean, newConfig: android.content.res.Configuration, /) -> None: ...
    def onNavigateUp(self) -> bool: ...
    def onNavigateUpFromChild(self, child: Activity, /) -> bool: ...
    @typing.overload
    def onNewIntent(self, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def onNewIntent(self, intent: android.content.Intent, caller: ComponentCaller, /) -> None: ...
    def onOptionsItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def onOptionsMenuClosed(self, menu: android.view.Menu, /) -> None: ...
    def onPanelClosed(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> None: ...
    def onPause(self) -> None: ...
    def onPerformDirectAction(self, actionId: str | java.lang.String, arguments: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, resultListener: java.util.function.Consumer[android.os.Bundle], /) -> None: ...
    @typing.overload
    def onPictureInPictureModeChanged(self, isInPictureInPictureMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onPictureInPictureModeChanged(self, isInPictureInPictureMode: bool | java.jboolean | java.lang.Boolean, newConfig: android.content.res.Configuration, /) -> None: ...
    def onPictureInPictureRequested(self) -> bool: ...
    def onPictureInPictureUiStateChanged(self, pipState: PictureInPictureUiState, /) -> None: ...
    @typing.overload
    def onPostCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def onPostCreate(self, savedInstanceState: android.os.Bundle, persistentState: android.os.PersistableBundle, /) -> None: ...
    def onPostResume(self) -> None: ...
    @typing.overload
    def onPrepareDialog(self, id: int | java.jint | java.lang.Integer, dialog: Dialog, /) -> None: ...
    @typing.overload
    def onPrepareDialog(self, id: int | java.jint | java.lang.Integer, dialog: Dialog, args: android.os.Bundle, /) -> None: ...
    def onPrepareNavigateUpTaskStack(self, builder: TaskStackBuilder, /) -> None: ...
    def onPrepareOptionsMenu(self, menu: android.view.Menu, /) -> bool: ...
    def onPreparePanel(self, featureId: int | java.jint | java.lang.Integer, view: android.view.View, menu: android.view.Menu, /) -> bool: ...
    def onProvideAssistContent(self, outContent: android.app.assist.AssistContent, /) -> None: ...
    def onProvideAssistData(self, data: android.os.Bundle, /) -> None: ...
    def onProvideKeyboardShortcuts(self, data: java.util.List[android.view.KeyboardShortcutGroup], menu: android.view.Menu, deviceId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onProvideReferrer(self) -> android.net.Uri: ...
    @typing.overload
    def onRequestPermissionsResult(self, requestCode: int | java.jint | java.lang.Integer, permissions: java.chaquopy.JavaArray[java.lang.String], grantResults: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    def onRequestPermissionsResult(self, requestCode: int | java.jint | java.lang.Integer, permissions: java.chaquopy.JavaArray[java.lang.String], grantResults: java.chaquopy.JavaArrayJInt, deviceId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRestart(self) -> None: ...
    @typing.overload
    def onRestoreInstanceState(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def onRestoreInstanceState(self, savedInstanceState: android.os.Bundle, persistentState: android.os.PersistableBundle, /) -> None: ...
    def onResume(self) -> None: ...
    def onRetainNonConfigurationInstance(self) -> java.lang.Object: ...
    @typing.overload
    def onSaveInstanceState(self, outState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def onSaveInstanceState(self, outState: android.os.Bundle, outPersistentState: android.os.PersistableBundle, /) -> None: ...
    @typing.overload
    def onSearchRequested(self) -> bool: ...
    @typing.overload
    def onSearchRequested(self, searchEvent: android.view.SearchEvent, /) -> bool: ...
    def onStart(self) -> None: ...
    def onStateNotSaved(self) -> None: ...
    def onStop(self) -> None: ...
    def onTitleChanged(self, title: java.lang.CharSequence, color: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTopResumedActivityChanged(self, isTopResumedActivity: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onTrimMemory(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def onUserInteraction(self) -> None: ...
    def onUserLeaveHint(self) -> None: ...
    def onVisibleBehindCanceled(self) -> None: ...
    def onWindowAttributesChanged(self, params: android.view.WindowManager.LayoutParams, /) -> None: ...
    def onWindowFocusChanged(self, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onWindowStartingActionMode(self, callback: android.view.ActionMode.Callback, /) -> android.view.ActionMode | None: ...
    @typing.overload
    def onWindowStartingActionMode(self, callback: android.view.ActionMode.Callback, type: int | java.jint | java.lang.Integer, /) -> android.view.ActionMode | None: ...
    def openContextMenu(self, view: android.view.View, /) -> None: ...
    def openOptionsMenu(self) -> None: ...
    @typing.overload
    def overrideActivityTransition(self, overrideType: int | java.jint | java.lang.Integer, enterAnim: int | java.jint | java.lang.Integer, exitAnim: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def overrideActivityTransition(self, overrideType: int | java.jint | java.lang.Integer, enterAnim: int | java.jint | java.lang.Integer, exitAnim: int | java.jint | java.lang.Integer, backgroundColor: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def overridePendingTransition(self, enterAnim: int | java.jint | java.lang.Integer, exitAnim: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def overridePendingTransition(self, enterAnim: int | java.jint | java.lang.Integer, exitAnim: int | java.jint | java.lang.Integer, backgroundColor: int | java.jint | java.lang.Integer, /) -> None: ...
    def postponeEnterTransition(self) -> None: ...
    def recreate(self) -> None: ...
    def registerActivityLifecycleCallbacks(self, callback: Application.ActivityLifecycleCallbacks, /) -> None: ...
    def registerComponentCallbacks(self, callback: android.content.ComponentCallbacks, /) -> None: ...
    def registerForContextMenu(self, view: android.view.View, /) -> None: ...
    def registerScreenCaptureCallback(self, executor: java.util.concurrent.Executor, callback: Activity.ScreenCaptureCallback, /) -> None: ...
    def releaseInstance(self) -> bool: ...
    def removeDialog(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def reportFullyDrawn(self) -> None: ...
    def requestDragAndDropPermissions(self, event: android.view.DragEvent, /) -> android.view.DragAndDropPermissions: ...
    def requestFullscreenMode(self, request: int | java.jint | java.lang.Integer, approvalCallback: android.os.OutcomeReceiver[java.lang.Void, java.lang.Throwable], /) -> None: ...
    def requestOpenInBrowserEducation(self) -> None: ...
    @typing.overload
    def requestPermissions(self, permissions: java.chaquopy.JavaArray[java.lang.String], requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def requestPermissions(self, permissions: java.chaquopy.JavaArray[java.lang.String], requestCode: int | java.jint | java.lang.Integer, deviceId: int | java.jint | java.lang.Integer, /) -> None: ...
    def requestShowKeyboardShortcuts(self) -> None: ...
    def requestVisibleBehind(self, visible: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def requestWindowFeature(self, featureId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def requireViewById(self, id: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def runOnUiThread(self, action: java.lang.Runnable, /) -> None: ...
    def setActionBar(self, toolbar: android.widget.Toolbar, /) -> None: ...
    def setAllowCrossUidActivitySwitchFromBelow(self, allowed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setContentTransitionManager(self, tm: android.transition.TransitionManager, /) -> None: ...
    @typing.overload
    def setContentView(self, layoutResID: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setContentView(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def setContentView(self, view: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def setDefaultKeyMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setEnterSharedElementCallback(self, callback: SharedElementCallback, /) -> None: ...
    def setExitSharedElementCallback(self, callback: SharedElementCallback, /) -> None: ...
    def setFeatureDrawable(self, featureId: int | java.jint | java.lang.Integer, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setFeatureDrawableAlpha(self, featureId: int | java.jint | java.lang.Integer, alpha: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFeatureDrawableResource(self, featureId: int | java.jint | java.lang.Integer, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFeatureDrawableUri(self, featureId: int | java.jint | java.lang.Integer, uri: android.net.Uri, /) -> None: ...
    def setFinishOnTouchOutside(self, finish: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setImmersive(self, i: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setInheritShowWhenLocked(self, inheritShowWhenLocked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setIntent(self, newIntent: android.content.Intent, /) -> None: ...
    @typing.overload
    def setIntent(self, newIntent: android.content.Intent, newCaller: ComponentCaller, /) -> None: ...
    def setLocusContext(self, locusId: android.content.LocusId, bundle: android.os.Bundle, /) -> None: ...
    def setMediaController(self, controller: android.media.session.MediaController, /) -> None: ...
    def setPictureInPictureParams(self, params: PictureInPictureParams, /) -> None: ...
    def setProgress(self, progress: int | java.jint | java.lang.Integer, /) -> None: ...
    def setProgressBarIndeterminate(self, indeterminate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setProgressBarIndeterminateVisibility(self, visible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setProgressBarVisibility(self, visible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRecentsScreenshotEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRequestedOrientation(self, requestedOrientation: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setResult(self, resultCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setResult(self, resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, /) -> None: ...
    def setSecondaryProgress(self, secondaryProgress: int | java.jint | java.lang.Integer, /) -> None: ...
    def setShouldDockBigOverlays(self, shouldDockBigOverlays: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShowWhenLocked(self, showWhenLocked: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTaskDescription(self, taskDescription: ActivityManager.TaskDescription, /) -> None: ...
    def setTheme(self, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, titleId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, title: java.lang.CharSequence, /) -> None: ...
    def setTitleColor(self, textColor: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTranslucent(self, translucent: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setTurnScreenOn(self, turnScreenOn: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setVisible(self, visible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setVolumeControlStream(self, streamType: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVrModeEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, requestedComponent: android.content.ComponentName, /) -> None: ...
    def shouldDockBigOverlays(self) -> bool: ...
    @typing.overload
    def shouldShowRequestPermissionRationale(self, permission: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def shouldShowRequestPermissionRationale(self, permission: str | java.lang.String, deviceId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def shouldUpRecreateTask(self, targetIntent: android.content.Intent, /) -> bool: ...
    def showAssist(self, args: android.os.Bundle, /) -> bool: ...
    @typing.overload
    def showDialog(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def showDialog(self, id: int | java.jint | java.lang.Integer, args: android.os.Bundle, /) -> bool: ...
    def showLockTaskEscapeMessage(self) -> None: ...
    @typing.overload
    def startActionMode(self, callback: android.view.ActionMode.Callback, /) -> android.view.ActionMode | None: ...
    @typing.overload
    def startActionMode(self, callback: android.view.ActionMode.Callback, type: int | java.jint | java.lang.Integer, /) -> android.view.ActionMode | None: ...
    @typing.overload
    def startActivities(self, intents: java.chaquopy.JavaArray[android.content.Intent], /) -> None: ...
    @typing.overload
    def startActivities(self, intents: java.chaquopy.JavaArray[android.content.Intent], options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startActivity(self, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def startActivity(self, intent: android.content.Intent, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startActivityForResult(self, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startActivityForResult(self, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startActivityFromChild(self, child: Activity, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startActivityFromChild(self, child: Activity, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startActivityFromFragment(self, fragment: Fragment, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startActivityFromFragment(self, fragment: Fragment, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startActivityIfNeeded(self, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def startActivityIfNeeded(self, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> bool: ...
    @typing.overload
    def startIntentSender(self, intent: android.content.IntentSender, fillInIntent: android.content.Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startIntentSender(self, intent: android.content.IntentSender, fillInIntent: android.content.Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startIntentSenderForResult(self, intent: android.content.IntentSender, requestCode: int | java.jint | java.lang.Integer, fillInIntent: android.content.Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startIntentSenderForResult(self, intent: android.content.IntentSender, requestCode: int | java.jint | java.lang.Integer, fillInIntent: android.content.Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startIntentSenderFromChild(self, child: Activity, intent: android.content.IntentSender, requestCode: int | java.jint | java.lang.Integer, fillInIntent: android.content.Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startIntentSenderFromChild(self, child: Activity, intent: android.content.IntentSender, requestCode: int | java.jint | java.lang.Integer, fillInIntent: android.content.Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def startLocalVoiceInteraction(self, privateOptions: android.os.Bundle, /) -> None: ...
    def startLockTask(self) -> None: ...
    def startManagingCursor(self, c: android.database.Cursor, /) -> None: ...
    @typing.overload
    def startNextMatchingActivity(self, intent: android.content.Intent, /) -> bool: ...
    @typing.overload
    def startNextMatchingActivity(self, intent: android.content.Intent, options: android.os.Bundle, /) -> bool: ...
    def startPostponedEnterTransition(self) -> None: ...
    def startSearch(self, initialQuery: str | java.lang.String, selectInitialQuery: bool | java.jboolean | java.lang.Boolean, appSearchData: android.os.Bundle, globalSearch: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def stopLocalVoiceInteraction(self) -> None: ...
    def stopLockTask(self) -> None: ...
    def stopManagingCursor(self, c: android.database.Cursor, /) -> None: ...
    def takeKeyEvents(self, get: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def triggerSearch(self, query: str | java.lang.String, appSearchData: android.os.Bundle, /) -> None: ...
    def unregisterActivityLifecycleCallbacks(self, callback: Application.ActivityLifecycleCallbacks, /) -> None: ...
    def unregisterComponentCallbacks(self, callback: android.content.ComponentCallbacks, /) -> None: ...
    def unregisterForContextMenu(self, view: android.view.View, /) -> None: ...
    def unregisterScreenCaptureCallback(self, callback: Activity.ScreenCaptureCallback, /) -> None: ...

    class ScreenCaptureCallback(java.lang.Object):
        def onScreenCaptured(self) -> None: ...

class ActivityGroup(Activity):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, singleActivityMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getCurrentActivity(self) -> Activity: ...
    def getLocalActivityManager(self) -> LocalActivityManager: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onDestroy(self) -> None: ...
    def onPause(self) -> None: ...
    def onResume(self) -> None: ...
    def onSaveInstanceState(self, outState: android.os.Bundle, /) -> None: ...
    def onStop(self) -> None: ...

class ActivityManager(java.lang.Object):
    ACTION_REPORT_HEAP_LIMIT: typing.ClassVar[str] = ...
    LOCK_TASK_MODE_LOCKED: typing.ClassVar[int] = ...
    LOCK_TASK_MODE_NONE: typing.ClassVar[int] = ...
    LOCK_TASK_MODE_PINNED: typing.ClassVar[int] = ...
    META_HOME_ALTERNATE: typing.ClassVar[str] = ...
    MOVE_TASK_NO_USER_ACTION: typing.ClassVar[int] = ...
    MOVE_TASK_WITH_HOME: typing.ClassVar[int] = ...
    RECENT_IGNORE_UNAVAILABLE: typing.ClassVar[int] = ...
    RECENT_WITH_EXCLUDED: typing.ClassVar[int] = ...
    def addAppTask(self, activity: Activity, intent: android.content.Intent, description: ActivityManager.TaskDescription, thumbnail: android.graphics.Bitmap, /) -> int: ...
    def addApplicationStartInfoCompletionListener(self, executor: java.util.concurrent.Executor, listener: java.util.function.Consumer[ApplicationStartInfo], /) -> None: ...
    def addStartInfoTimestamp(self, key: int | java.jint | java.lang.Integer, timestampNs: int | java.jlong | java.lang.Long, /) -> None: ...
    def appNotResponding(self, reason: str | java.lang.String, /) -> None: ...
    def clearApplicationUserData(self) -> bool: ...
    def clearWatchHeapLimit(self) -> None: ...
    def dumpPackageState(self, fd: java.io.FileDescriptor, packageName: str | java.lang.String, /) -> None: ...
    def getAppTaskThumbnailSize(self) -> android.util.Size: ...
    def getAppTasks(self) -> java.util.List[ActivityManager.AppTask]: ...
    def getDeviceConfigurationInfo(self) -> android.content.pm.ConfigurationInfo: ...
    def getHistoricalProcessExitReasons(self, packageName: str | java.lang.String, pid: int | java.jint | java.lang.Integer, maxNum: int | java.jint | java.lang.Integer, /) -> java.util.List[ApplicationExitInfo]: ...
    def getHistoricalProcessStartReasons(self, maxNum: int | java.jint | java.lang.Integer, /) -> java.util.List[ApplicationStartInfo]: ...
    def getLargeMemoryClass(self) -> int: ...
    def getLauncherLargeIconDensity(self) -> int: ...
    def getLauncherLargeIconSize(self) -> int: ...
    def getLockTaskModeState(self) -> int: ...
    def getMemoryClass(self) -> int: ...
    def getMemoryInfo(self, outInfo: ActivityManager.MemoryInfo, /) -> None: ...
    @staticmethod
    def getMyMemoryState(outState: ActivityManager.RunningAppProcessInfo, /) -> None: ...
    def getProcessMemoryInfo(self, pids: java.chaquopy.JavaArrayJInt, /) -> java.chaquopy.JavaArray[android.os.Debug.MemoryInfo]: ...
    def getProcessesInErrorState(self) -> java.util.List[ActivityManager.ProcessErrorStateInfo]: ...
    def getRecentTasks(self, maxNum: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> java.util.List[ActivityManager.RecentTaskInfo]: ...
    def getRunningAppProcesses(self) -> java.util.List[ActivityManager.RunningAppProcessInfo] | None: ...
    def getRunningServiceControlPanel(self, service: android.content.ComponentName, /) -> PendingIntent: ...
    def getRunningServices(self, maxNum: int | java.jint | java.lang.Integer, /) -> java.util.List[ActivityManager.RunningServiceInfo]: ...
    def getRunningTasks(self, maxNum: int | java.jint | java.lang.Integer, /) -> java.util.List[ActivityManager.RunningTaskInfo]: ...
    def isActivityStartAllowedOnDisplay(self, context: android.content.Context, displayId: int | java.jint | java.lang.Integer, intent: android.content.Intent, /) -> bool: ...
    def isBackgroundRestricted(self) -> bool: ...
    def isInLockTaskMode(self) -> bool: ...
    @staticmethod
    def isLowMemoryKillReportSupported() -> bool: ...
    def isLowRamDevice(self) -> bool: ...
    @staticmethod
    def isRunningInTestHarness() -> bool: ...
    @staticmethod
    def isRunningInUserTestHarness() -> bool: ...
    @staticmethod
    def isUserAMonkey() -> bool: ...
    def killBackgroundProcesses(self, packageName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def moveTaskToFront(self, taskId: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def moveTaskToFront(self, taskId: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def removeApplicationStartInfoCompletionListener(self, listener: java.util.function.Consumer[ApplicationStartInfo], /) -> None: ...
    def restartPackage(self, packageName: str | java.lang.String, /) -> None: ...
    def setProcessStateSummary(self, state: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @staticmethod
    def setVrThread(tid: int | java.jint | java.lang.Integer, /) -> None: ...
    def setWatchHeapLimit(self, pssSize: int | java.jlong | java.lang.Long, /) -> None: ...

    class TaskDescription(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ActivityManager.TaskDescription]] = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, td: ActivityManager.TaskDescription, /) -> None: ...
        @typing.overload
        def __init__(self, label: str | java.lang.String, /) -> None: ...
        @typing.overload
        def __init__(self, label: str | java.lang.String, iconRes: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, label: str | java.lang.String, icon: android.graphics.Bitmap, /) -> None: ...
        @typing.overload
        def __init__(self, label: str | java.lang.String, iconRes: int | java.jint | java.lang.Integer, colorPrimary: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, label: str | java.lang.String, icon: android.graphics.Bitmap, colorPrimary: int | java.jint | java.lang.Integer, /) -> None: ...
        def describeContents(self) -> int: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getBackgroundColor(self) -> int: ...
        def getIcon(self) -> android.graphics.Bitmap: ...
        def getLabel(self) -> str: ...
        def getNavigationBarColor(self) -> int: ...
        def getPrimaryColor(self) -> int: ...
        def getStatusBarColor(self) -> int: ...
        def hashCode(self) -> int: ...
        def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> ActivityManager.TaskDescription: ...
            def setBackgroundColor(self, color: int | java.jint | java.lang.Integer, /) -> ActivityManager.TaskDescription.Builder: ...
            def setIcon(self, iconRes: int | java.jint | java.lang.Integer, /) -> ActivityManager.TaskDescription.Builder: ...
            def setLabel(self, label: str | java.lang.String, /) -> ActivityManager.TaskDescription.Builder: ...
            def setNavigationBarColor(self, color: int | java.jint | java.lang.Integer, /) -> ActivityManager.TaskDescription.Builder: ...
            def setPrimaryColor(self, color: int | java.jint | java.lang.Integer, /) -> ActivityManager.TaskDescription.Builder: ...
            def setStatusBarColor(self, color: int | java.jint | java.lang.Integer, /) -> ActivityManager.TaskDescription.Builder: ...

    class RunningTaskInfo(TaskInfo, android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ActivityManager.RunningTaskInfo]] = ...
        description: java.lang.CharSequence = ...
        id: int = ...
        numRunning: int = ...
        thumbnail: android.graphics.Bitmap = ...
        def __init__(self) -> None: ...
        def describeContents(self) -> int: ...
        def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class RunningServiceInfo(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ActivityManager.RunningServiceInfo]] = ...
        FLAG_FOREGROUND: typing.ClassVar[int] = ...
        FLAG_PERSISTENT_PROCESS: typing.ClassVar[int] = ...
        FLAG_STARTED: typing.ClassVar[int] = ...
        FLAG_SYSTEM_PROCESS: typing.ClassVar[int] = ...
        activeSince: int = ...
        clientCount: int = ...
        clientLabel: int = ...
        clientPackage: str = ...
        crashCount: int = ...
        flags: int = ...
        foreground: bool = ...
        lastActivityTime: int = ...
        pid: int = ...
        process: str = ...
        restarting: int = ...
        service: android.content.ComponentName = ...
        started: bool = ...
        uid: int = ...
        def __init__(self) -> None: ...
        def describeContents(self) -> int: ...
        def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class RunningAppProcessInfo(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ActivityManager.RunningAppProcessInfo]] = ...
        IMPORTANCE_BACKGROUND: typing.ClassVar[int] = ...
        IMPORTANCE_CACHED: typing.ClassVar[int] = ...
        IMPORTANCE_CANT_SAVE_STATE: typing.ClassVar[int] = ...
        IMPORTANCE_EMPTY: typing.ClassVar[int] = ...
        IMPORTANCE_FOREGROUND: typing.ClassVar[int] = ...
        IMPORTANCE_FOREGROUND_SERVICE: typing.ClassVar[int] = ...
        IMPORTANCE_GONE: typing.ClassVar[int] = ...
        IMPORTANCE_PERCEPTIBLE: typing.ClassVar[int] = ...
        IMPORTANCE_PERCEPTIBLE_PRE_26: typing.ClassVar[int] = ...
        IMPORTANCE_SERVICE: typing.ClassVar[int] = ...
        IMPORTANCE_TOP_SLEEPING: typing.ClassVar[int] = ...
        IMPORTANCE_TOP_SLEEPING_PRE_28: typing.ClassVar[int] = ...
        IMPORTANCE_VISIBLE: typing.ClassVar[int] = ...
        REASON_PROVIDER_IN_USE: typing.ClassVar[int] = ...
        REASON_SERVICE_IN_USE: typing.ClassVar[int] = ...
        REASON_UNKNOWN: typing.ClassVar[int] = ...
        importance: int = ...
        importanceReasonCode: int = ...
        importanceReasonComponent: android.content.ComponentName = ...
        importanceReasonPid: int = ...
        lastTrimLevel: int = ...
        lru: int = ...
        pid: int = ...
        pkgList: java.chaquopy.JavaArray[java.lang.String] = ...
        processName: str = ...
        uid: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, pProcessName: str | java.lang.String, pPid: int | java.jint | java.lang.Integer, pArr: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
        def describeContents(self) -> int: ...
        def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class RecentTaskInfo(TaskInfo, android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ActivityManager.RecentTaskInfo]] = ...
        affiliatedTaskId: int = ...
        description: java.lang.CharSequence = ...
        id: int = ...
        persistentId: int = ...
        def __init__(self) -> None: ...
        def describeContents(self) -> int: ...
        def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class ProcessErrorStateInfo(android.os.Parcelable):
        CRASHED: typing.ClassVar[int] = ...
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ActivityManager.ProcessErrorStateInfo]] = ...
        NOT_RESPONDING: typing.ClassVar[int] = ...
        NO_ERROR: typing.ClassVar[int] = ...
        condition: int = ...
        crashData: java.chaquopy.JavaArrayJByte = ...
        longMsg: str = ...
        pid: int = ...
        processName: str = ...
        shortMsg: str = ...
        stackTrace: str = ...
        tag: str = ...
        uid: int = ...
        def __init__(self) -> None: ...
        def describeContents(self) -> int: ...
        def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class MemoryInfo(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ActivityManager.MemoryInfo]] = ...
        advertisedMem: int = ...
        availMem: int = ...
        lowMemory: bool = ...
        threshold: int = ...
        totalMem: int = ...
        def __init__(self) -> None: ...
        def describeContents(self) -> int: ...
        def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class AppTask(java.lang.Object):
        def finishAndRemoveTask(self) -> None: ...
        def getTaskInfo(self) -> ActivityManager.RecentTaskInfo: ...
        def moveToFront(self) -> None: ...
        def setExcludeFromRecents(self, exclude: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def startActivity(self, context: android.content.Context, intent: android.content.Intent, options: android.os.Bundle, /) -> None: ...

class ActivityOptions(java.lang.Object):
    EXTRA_USAGE_TIME_REPORT: typing.ClassVar[str] = ...
    EXTRA_USAGE_TIME_REPORT_PACKAGES: typing.ClassVar[str] = ...
    MODE_BACKGROUND_ACTIVITY_START_ALLOWED: typing.ClassVar[int] = ...
    MODE_BACKGROUND_ACTIVITY_START_ALLOW_ALWAYS: typing.ClassVar[int] = ...
    MODE_BACKGROUND_ACTIVITY_START_ALLOW_IF_VISIBLE: typing.ClassVar[int] = ...
    MODE_BACKGROUND_ACTIVITY_START_DENIED: typing.ClassVar[int] = ...
    MODE_BACKGROUND_ACTIVITY_START_SYSTEM_DEFINED: typing.ClassVar[int] = ...
    def getLaunchBounds(self) -> android.graphics.Rect | None: ...
    def getLaunchDisplayId(self) -> int: ...
    def getLockTaskMode(self) -> bool: ...
    def getPendingIntentBackgroundActivityStartMode(self) -> int: ...
    def getPendingIntentCreatorBackgroundActivityStartMode(self) -> int: ...
    def getSplashScreenStyle(self) -> int: ...
    def isAllowPassThroughOnTouchOutside(self) -> bool: ...
    def isPendingIntentBackgroundActivityLaunchAllowed(self) -> bool: ...
    def isShareIdentityEnabled(self) -> bool: ...
    @staticmethod
    def makeBasic() -> ActivityOptions: ...
    @staticmethod
    def makeClipRevealAnimation(source: android.view.View, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    @typing.overload
    @staticmethod
    def makeCustomAnimation(context: android.content.Context, enterResId: int | java.jint | java.lang.Integer, exitResId: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    @typing.overload
    @staticmethod
    def makeCustomAnimation(context: android.content.Context, enterResId: int | java.jint | java.lang.Integer, exitResId: int | java.jint | java.lang.Integer, backgroundColor: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    @staticmethod
    def makeLaunchIntoPip(pictureInPictureParams: PictureInPictureParams, /) -> ActivityOptions: ...
    @staticmethod
    def makeScaleUpAnimation(source: android.view.View, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    @typing.overload
    @staticmethod
    def makeSceneTransitionAnimation(activity: Activity, /, *sharedElements: android.util.Pair[android.view.View, java.lang.String]) -> ActivityOptions: ...
    @typing.overload
    @staticmethod
    def makeSceneTransitionAnimation(activity: Activity, sharedElement: android.view.View, sharedElementName: str | java.lang.String, /) -> ActivityOptions: ...
    @staticmethod
    def makeTaskLaunchBehind() -> ActivityOptions: ...
    @staticmethod
    def makeThumbnailScaleUpAnimation(source: android.view.View, thumbnail: android.graphics.Bitmap, startX: int | java.jint | java.lang.Integer, startY: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    def requestUsageTimeReport(self, receiver: PendingIntent, /) -> None: ...
    def setAllowPassThroughOnTouchOutside(self, allowed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAppVerificationBundle(self, bundle: android.os.Bundle, /) -> ActivityOptions: ...
    def setLaunchBounds(self, screenSpacePixelRect: android.graphics.Rect, /) -> ActivityOptions: ...
    def setLaunchDisplayId(self, launchDisplayId: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    def setLockTaskEnabled(self, lockTaskMode: bool | java.jboolean | java.lang.Boolean, /) -> ActivityOptions: ...
    def setPendingIntentBackgroundActivityLaunchAllowed(self, allowed: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPendingIntentBackgroundActivityStartMode(self, state: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    def setPendingIntentCreatorBackgroundActivityStartMode(self, mode: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    def setShareIdentityEnabled(self, shareIdentity: bool | java.jboolean | java.lang.Boolean, /) -> ActivityOptions: ...
    def setSplashScreenStyle(self, style: int | java.jint | java.lang.Integer, /) -> ActivityOptions: ...
    def toBundle(self) -> android.os.Bundle: ...
    def toString(self) -> str: ...
    def update(self, otherOptions: ActivityOptions, /) -> None: ...

class AlarmManager(java.lang.Object):
    ACTION_NEXT_ALARM_CLOCK_CHANGED: typing.ClassVar[str] = ...
    ACTION_SCHEDULE_EXACT_ALARM_PERMISSION_STATE_CHANGED: typing.ClassVar[str] = ...
    ELAPSED_REALTIME: typing.ClassVar[int] = ...
    ELAPSED_REALTIME_WAKEUP: typing.ClassVar[int] = ...
    INTERVAL_DAY: typing.ClassVar[int] = ...
    INTERVAL_FIFTEEN_MINUTES: typing.ClassVar[int] = ...
    INTERVAL_HALF_DAY: typing.ClassVar[int] = ...
    INTERVAL_HALF_HOUR: typing.ClassVar[int] = ...
    INTERVAL_HOUR: typing.ClassVar[int] = ...
    RTC: typing.ClassVar[int] = ...
    RTC_WAKEUP: typing.ClassVar[int] = ...
    def canScheduleExactAlarms(self) -> bool: ...
    @typing.overload
    def cancel(self, listener: AlarmManager.OnAlarmListener, /) -> None: ...
    @typing.overload
    def cancel(self, operation: PendingIntent, /) -> None: ...
    def cancelAll(self) -> None: ...
    def getNextAlarmClock(self) -> AlarmManager.AlarmClockInfo: ...
    @typing.overload
    def set(self, type: int | java.jint | java.lang.Integer, triggerAtMillis: int | java.jlong | java.lang.Long, operation: PendingIntent, /) -> None: ...
    @typing.overload
    def set(self, type: int | java.jint | java.lang.Integer, triggerAtMillis: int | java.jlong | java.lang.Long, tag: str | java.lang.String, listener: AlarmManager.OnAlarmListener, targetHandler: android.os.Handler, /) -> None: ...
    def setAlarmClock(self, info: AlarmManager.AlarmClockInfo, operation: PendingIntent, /) -> None: ...
    def setAndAllowWhileIdle(self, type: int | java.jint | java.lang.Integer, triggerAtMillis: int | java.jlong | java.lang.Long, operation: PendingIntent, /) -> None: ...
    @typing.overload
    def setExact(self, type: int | java.jint | java.lang.Integer, triggerAtMillis: int | java.jlong | java.lang.Long, operation: PendingIntent, /) -> None: ...
    @typing.overload
    def setExact(self, type: int | java.jint | java.lang.Integer, triggerAtMillis: int | java.jlong | java.lang.Long, tag: str | java.lang.String, listener: AlarmManager.OnAlarmListener, targetHandler: android.os.Handler, /) -> None: ...
    def setExactAndAllowWhileIdle(self, type: int | java.jint | java.lang.Integer, triggerAtMillis: int | java.jlong | java.lang.Long, operation: PendingIntent, /) -> None: ...
    def setInexactRepeating(self, type: int | java.jint | java.lang.Integer, triggerAtMillis: int | java.jlong | java.lang.Long, intervalMillis: int | java.jlong | java.lang.Long, operation: PendingIntent, /) -> None: ...
    def setRepeating(self, type: int | java.jint | java.lang.Integer, triggerAtMillis: int | java.jlong | java.lang.Long, intervalMillis: int | java.jlong | java.lang.Long, operation: PendingIntent, /) -> None: ...
    def setTime(self, millis: int | java.jlong | java.lang.Long, /) -> None: ...
    def setTimeZone(self, timeZone: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setWindow(self, type: int | java.jint | java.lang.Integer, windowStartMillis: int | java.jlong | java.lang.Long, windowLengthMillis: int | java.jlong | java.lang.Long, operation: PendingIntent, /) -> None: ...
    @typing.overload
    def setWindow(self, type: int | java.jint | java.lang.Integer, windowStartMillis: int | java.jlong | java.lang.Long, windowLengthMillis: int | java.jlong | java.lang.Long, tag: str | java.lang.String, listener: AlarmManager.OnAlarmListener, targetHandler: android.os.Handler, /) -> None: ...
    @typing.overload
    def setWindow(self, type: int | java.jint | java.lang.Integer, windowStartMillis: int | java.jlong | java.lang.Long, windowLengthMillis: int | java.jlong | java.lang.Long, tag: str | java.lang.String, executor: java.util.concurrent.Executor, listener: AlarmManager.OnAlarmListener, /) -> None: ...

    class OnAlarmListener(java.lang.Object):
        def onAlarm(self) -> None: ...

    class AlarmClockInfo(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AlarmManager.AlarmClockInfo]] = ...
        def __init__(self, triggerTime: int | java.jlong | java.lang.Long, showIntent: PendingIntent, /) -> None: ...
        def describeContents(self) -> int: ...
        def getShowIntent(self) -> PendingIntent: ...
        def getTriggerTime(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AlertDialog(Dialog, android.content.DialogInterface):
    THEME_DEVICE_DEFAULT_DARK: typing.ClassVar[int] = ...
    THEME_DEVICE_DEFAULT_LIGHT: typing.ClassVar[int] = ...
    THEME_HOLO_DARK: typing.ClassVar[int] = ...
    THEME_HOLO_LIGHT: typing.ClassVar[int] = ...
    THEME_TRADITIONAL: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, themeResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, cancelable: bool | java.jboolean | java.lang.Boolean, cancelListener: android.content.DialogInterface.OnCancelListener, /) -> None: ...
    def getButton(self, whichButton: int | java.jint | java.lang.Integer, /) -> android.widget.Button | None: ...
    def getListView(self) -> android.widget.ListView: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    @typing.overload
    def setButton(self, text: java.lang.CharSequence, listener: android.content.DialogInterface.OnClickListener, /) -> None: ...
    @typing.overload
    def setButton(self, text: java.lang.CharSequence, msg: android.os.Message, /) -> None: ...
    @typing.overload
    def setButton(self, whichButton: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, listener: android.content.DialogInterface.OnClickListener, /) -> None: ...
    @typing.overload
    def setButton(self, whichButton: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, msg: android.os.Message, /) -> None: ...
    @typing.overload
    def setButton2(self, text: java.lang.CharSequence, listener: android.content.DialogInterface.OnClickListener, /) -> None: ...
    @typing.overload
    def setButton2(self, text: java.lang.CharSequence, msg: android.os.Message, /) -> None: ...
    @typing.overload
    def setButton3(self, text: java.lang.CharSequence, listener: android.content.DialogInterface.OnClickListener, /) -> None: ...
    @typing.overload
    def setButton3(self, text: java.lang.CharSequence, msg: android.os.Message, /) -> None: ...
    def setCustomTitle(self, customTitleView: android.view.View, /) -> None: ...
    @typing.overload
    def setIcon(self, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setIcon(self, icon: android.graphics.drawable.Drawable, /) -> None: ...
    def setIconAttribute(self, attrId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setInverseBackgroundForced(self, forceInverseBackground: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMessage(self, message: java.lang.CharSequence, /) -> None: ...
    def setTitle(self, title: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def setView(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def setView(self, view: android.view.View, viewSpacingLeft: int | java.jint | java.lang.Integer, viewSpacingTop: int | java.jint | java.lang.Integer, viewSpacingRight: int | java.jint | java.lang.Integer, viewSpacingBottom: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, context: android.content.Context, /) -> None: ...
        @typing.overload
        def __init__(self, context: android.content.Context, themeResId: int | java.jint | java.lang.Integer, /) -> None: ...
        def create(self) -> AlertDialog: ...
        def getContext(self) -> android.content.Context: ...
        def setAdapter(self, adapter: android.widget.ListAdapter, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        def setCancelable(self, cancelable: bool | java.jboolean | java.lang.Boolean, /) -> AlertDialog.Builder: ...
        def setCursor(self, cursor: android.database.Cursor, listener: android.content.DialogInterface.OnClickListener, labelColumn: str | java.lang.String, /) -> AlertDialog.Builder: ...
        def setCustomTitle(self, customTitleView: android.view.View, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setIcon(self, iconId: int | java.jint | java.lang.Integer, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setIcon(self, icon: android.graphics.drawable.Drawable, /) -> AlertDialog.Builder: ...
        def setIconAttribute(self, attrId: int | java.jint | java.lang.Integer, /) -> AlertDialog.Builder: ...
        def setInverseBackgroundForced(self, useInverseBackground: bool | java.jboolean | java.lang.Boolean, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setItems(self, itemsId: int | java.jint | java.lang.Integer, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setItems(self, items: java.chaquopy.JavaArray[java.lang.CharSequence], listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setMessage(self, messageId: int | java.jint | java.lang.Integer, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setMessage(self, message: java.lang.CharSequence, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setMultiChoiceItems(self, itemsId: int | java.jint | java.lang.Integer, checkedItems: java.chaquopy.JavaArrayJBoolean, listener: android.content.DialogInterface.OnMultiChoiceClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setMultiChoiceItems(self, items: java.chaquopy.JavaArray[java.lang.CharSequence], checkedItems: java.chaquopy.JavaArrayJBoolean, listener: android.content.DialogInterface.OnMultiChoiceClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setMultiChoiceItems(self, cursor: android.database.Cursor, isCheckedColumn: str | java.lang.String, labelColumn: str | java.lang.String, listener: android.content.DialogInterface.OnMultiChoiceClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setNegativeButton(self, textId: int | java.jint | java.lang.Integer, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setNegativeButton(self, text: java.lang.CharSequence, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setNeutralButton(self, textId: int | java.jint | java.lang.Integer, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setNeutralButton(self, text: java.lang.CharSequence, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        def setOnCancelListener(self, onCancelListener: android.content.DialogInterface.OnCancelListener, /) -> AlertDialog.Builder: ...
        def setOnDismissListener(self, onDismissListener: android.content.DialogInterface.OnDismissListener, /) -> AlertDialog.Builder: ...
        def setOnItemSelectedListener(self, listener: android.widget.AdapterView.OnItemSelectedListener, /) -> AlertDialog.Builder: ...
        def setOnKeyListener(self, onKeyListener: android.content.DialogInterface.OnKeyListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setPositiveButton(self, textId: int | java.jint | java.lang.Integer, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setPositiveButton(self, text: java.lang.CharSequence, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setSingleChoiceItems(self, itemsId: int | java.jint | java.lang.Integer, checkedItem: int | java.jint | java.lang.Integer, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setSingleChoiceItems(self, adapter: android.widget.ListAdapter, checkedItem: int | java.jint | java.lang.Integer, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setSingleChoiceItems(self, items: java.chaquopy.JavaArray[java.lang.CharSequence], checkedItem: int | java.jint | java.lang.Integer, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setSingleChoiceItems(self, cursor: android.database.Cursor, checkedItem: int | java.jint | java.lang.Integer, labelColumn: str | java.lang.String, listener: android.content.DialogInterface.OnClickListener, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setTitle(self, titleId: int | java.jint | java.lang.Integer, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setTitle(self, title: java.lang.CharSequence, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setView(self, layoutResId: int | java.jint | java.lang.Integer, /) -> AlertDialog.Builder: ...
        @typing.overload
        def setView(self, view: android.view.View, /) -> AlertDialog.Builder: ...
        def show(self) -> AlertDialog: ...

class AliasActivity(Activity):
    def __init__(self) -> None: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...

class AppComponentFactory(java.lang.Object):
    def __init__(self) -> None: ...
    def instantiateActivity(self, cl: java.lang.ClassLoader, className: str | java.lang.String, intent: android.content.Intent, /) -> Activity: ...
    def instantiateApplication(self, cl: java.lang.ClassLoader, className: str | java.lang.String, /) -> Application: ...
    def instantiateClassLoader(self, cl: java.lang.ClassLoader, aInfo: android.content.pm.ApplicationInfo, /) -> java.lang.ClassLoader: ...
    def instantiateProvider(self, cl: java.lang.ClassLoader, className: str | java.lang.String, /) -> android.content.ContentProvider: ...
    def instantiateReceiver(self, cl: java.lang.ClassLoader, className: str | java.lang.String, intent: android.content.Intent, /) -> android.content.BroadcastReceiver: ...
    def instantiateService(self, cl: java.lang.ClassLoader, className: str | java.lang.String, intent: android.content.Intent, /) -> Service: ...

class AppOpsManager(java.lang.Object):
    MODE_ALLOWED: typing.ClassVar[int] = ...
    MODE_DEFAULT: typing.ClassVar[int] = ...
    MODE_ERRORED: typing.ClassVar[int] = ...
    MODE_FOREGROUND: typing.ClassVar[int] = ...
    MODE_IGNORED: typing.ClassVar[int] = ...
    OPSTR_ADD_VOICEMAIL: typing.ClassVar[str] = ...
    OPSTR_ANSWER_PHONE_CALLS: typing.ClassVar[str] = ...
    OPSTR_BODY_SENSORS: typing.ClassVar[str] = ...
    OPSTR_CALL_PHONE: typing.ClassVar[str] = ...
    OPSTR_CAMERA: typing.ClassVar[str] = ...
    OPSTR_COARSE_LOCATION: typing.ClassVar[str] = ...
    OPSTR_FINE_LOCATION: typing.ClassVar[str] = ...
    OPSTR_GET_USAGE_STATS: typing.ClassVar[str] = ...
    OPSTR_MOCK_LOCATION: typing.ClassVar[str] = ...
    OPSTR_MONITOR_HIGH_POWER_LOCATION: typing.ClassVar[str] = ...
    OPSTR_MONITOR_LOCATION: typing.ClassVar[str] = ...
    OPSTR_PICTURE_IN_PICTURE: typing.ClassVar[str] = ...
    OPSTR_PROCESS_OUTGOING_CALLS: typing.ClassVar[str] = ...
    OPSTR_READ_CALENDAR: typing.ClassVar[str] = ...
    OPSTR_READ_CALL_LOG: typing.ClassVar[str] = ...
    OPSTR_READ_CELL_BROADCASTS: typing.ClassVar[str] = ...
    OPSTR_READ_CONTACTS: typing.ClassVar[str] = ...
    OPSTR_READ_EXTERNAL_STORAGE: typing.ClassVar[str] = ...
    OPSTR_READ_PHONE_NUMBERS: typing.ClassVar[str] = ...
    OPSTR_READ_PHONE_STATE: typing.ClassVar[str] = ...
    OPSTR_READ_SMS: typing.ClassVar[str] = ...
    OPSTR_RECEIVE_MMS: typing.ClassVar[str] = ...
    OPSTR_RECEIVE_SMS: typing.ClassVar[str] = ...
    OPSTR_RECEIVE_WAP_PUSH: typing.ClassVar[str] = ...
    OPSTR_RECORD_AUDIO: typing.ClassVar[str] = ...
    OPSTR_SEND_SMS: typing.ClassVar[str] = ...
    OPSTR_SYSTEM_ALERT_WINDOW: typing.ClassVar[str] = ...
    OPSTR_USE_FINGERPRINT: typing.ClassVar[str] = ...
    OPSTR_USE_SIP: typing.ClassVar[str] = ...
    OPSTR_WRITE_CALENDAR: typing.ClassVar[str] = ...
    OPSTR_WRITE_CALL_LOG: typing.ClassVar[str] = ...
    OPSTR_WRITE_CONTACTS: typing.ClassVar[str] = ...
    OPSTR_WRITE_EXTERNAL_STORAGE: typing.ClassVar[str] = ...
    OPSTR_WRITE_SETTINGS: typing.ClassVar[str] = ...
    OP_NOTED_CALLBACK_FLAG_IGNORE_ASYNC: typing.ClassVar[int] = ...
    WATCH_FOREGROUND_CHANGES: typing.ClassVar[int] = ...
    @typing.overload
    def checkOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def checkOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, /) -> int: ...
    @typing.overload
    def checkOpNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def checkOpNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, /) -> int: ...
    def checkOpRawNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, /) -> int: ...
    def checkPackage(self, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def finishOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def finishOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, /) -> None: ...
    def finishProxyOp(self, op: str | java.lang.String, proxiedUid: int | java.jint | java.lang.Integer, proxiedPackageName: str | java.lang.String, proxiedAttributionTag: str | java.lang.String, /) -> None: ...
    def isOpActive(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def noteOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def noteOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, message: str | java.lang.String, /) -> int: ...
    @typing.overload
    def noteOpNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def noteOpNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, message: str | java.lang.String, /) -> int: ...
    @typing.overload
    def noteProxyOp(self, op: str | java.lang.String, proxiedPackageName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def noteProxyOp(self, op: str | java.lang.String, proxiedPackageName: str | java.lang.String, proxiedUid: int | java.jint | java.lang.Integer, proxiedAttributionTag: str | java.lang.String, message: str | java.lang.String, /) -> int: ...
    @typing.overload
    def noteProxyOpNoThrow(self, op: str | java.lang.String, proxiedPackageName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def noteProxyOpNoThrow(self, op: str | java.lang.String, proxiedPackageName: str | java.lang.String, proxiedUid: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def noteProxyOpNoThrow(self, op: str | java.lang.String, proxiedPackageName: str | java.lang.String, proxiedUid: int | java.jint | java.lang.Integer, proxiedAttributionTag: str | java.lang.String, message: str | java.lang.String, /) -> int: ...
    @staticmethod
    def permissionToOp(permission: str | java.lang.String, /) -> str | None: ...
    @typing.overload
    def setOnOpNotedCallback(self, asyncExecutor: java.util.concurrent.Executor, callback: AppOpsManager.OnOpNotedCallback, /) -> None: ...
    @typing.overload
    def setOnOpNotedCallback(self, asyncExecutor: java.util.concurrent.Executor, callback: AppOpsManager.OnOpNotedCallback, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def startOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, message: str | java.lang.String, /) -> int: ...
    @typing.overload
    def startOpNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    @typing.overload
    def startOpNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, message: str | java.lang.String, /) -> int: ...
    def startProxyOp(self, op: str | java.lang.String, proxiedUid: int | java.jint | java.lang.Integer, proxiedPackageName: str | java.lang.String, proxiedAttributionTag: str | java.lang.String, message: str | java.lang.String, /) -> int: ...
    def startProxyOpNoThrow(self, op: str | java.lang.String, proxiedUid: int | java.jint | java.lang.Integer, proxiedPackageName: str | java.lang.String, proxiedAttributionTag: str | java.lang.String, message: str | java.lang.String, /) -> int: ...
    def startWatchingActive(self, ops: java.chaquopy.JavaArray[java.lang.String], executor: java.util.concurrent.Executor, callback: AppOpsManager.OnOpActiveChangedListener, /) -> None: ...
    @typing.overload
    def startWatchingMode(self, op: str | java.lang.String, packageName: str | java.lang.String, callback: AppOpsManager.OnOpChangedListener, /) -> None: ...
    @typing.overload
    def startWatchingMode(self, op: str | java.lang.String, packageName: str | java.lang.String, flags: int | java.jint | java.lang.Integer, callback: AppOpsManager.OnOpChangedListener, /) -> None: ...
    def stopWatchingActive(self, callback: AppOpsManager.OnOpActiveChangedListener, /) -> None: ...
    def stopWatchingMode(self, callback: AppOpsManager.OnOpChangedListener, /) -> None: ...
    def unsafeCheckOp(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    def unsafeCheckOpNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    def unsafeCheckOpRaw(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...
    def unsafeCheckOpRawNoThrow(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> int: ...

    class OnOpNotedCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onAsyncNoted(self, arg1: AsyncNotedAppOp, /) -> None: ...
        def onNoted(self, arg1: SyncNotedAppOp, /) -> None: ...
        def onSelfNoted(self, arg1: SyncNotedAppOp, /) -> None: ...

    class OnOpChangedListener(java.lang.Object):
        @typing.overload
        def onOpChanged(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
        @typing.overload
        def onOpChanged(self, op: str | java.lang.String, packageName: str | java.lang.String, userId: int | java.jint | java.lang.Integer, persistentDeviceId: str | java.lang.String, /) -> None: ...

    class OnOpActiveChangedListener(java.lang.Object):
        @typing.overload
        def onOpActiveChanged(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, arg4: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        @typing.overload
        def onOpActiveChanged(self, op: str | java.lang.String, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, attributionTag: str | java.lang.String, virtualDeviceId: int | java.jint | java.lang.Integer, active: bool | java.jboolean | java.lang.Boolean, attributionFlags: int | java.jint | java.lang.Integer, attributionChainId: int | java.jint | java.lang.Integer, /) -> None: ...

class Application(android.content.ComponentCallbacks2, android.content.ContextWrapper):
    def __init__(self) -> None: ...
    @staticmethod
    def getProcessName() -> str: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreate(self) -> None: ...
    def onLowMemory(self) -> None: ...
    def onTerminate(self) -> None: ...
    def onTrimMemory(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def registerActivityLifecycleCallbacks(self, callback: Application.ActivityLifecycleCallbacks, /) -> None: ...
    def registerComponentCallbacks(self, callback: android.content.ComponentCallbacks, /) -> None: ...
    def registerOnProvideAssistDataListener(self, callback: Application.OnProvideAssistDataListener, /) -> None: ...
    def unregisterActivityLifecycleCallbacks(self, callback: Application.ActivityLifecycleCallbacks, /) -> None: ...
    def unregisterComponentCallbacks(self, callback: android.content.ComponentCallbacks, /) -> None: ...
    def unregisterOnProvideAssistDataListener(self, callback: Application.OnProvideAssistDataListener, /) -> None: ...

    class OnProvideAssistDataListener(java.lang.Object):
        def onProvideAssistData(self, arg1: Activity, arg2: android.os.Bundle, /) -> None: ...

    class ActivityLifecycleCallbacks(java.lang.Object):
        def onActivityCreated(self, arg1: Activity, arg2: android.os.Bundle, /) -> None: ...
        def onActivityDestroyed(self, arg1: Activity, /) -> None: ...
        def onActivityPaused(self, arg1: Activity, /) -> None: ...
        def onActivityPostCreated(self, activity: Activity, savedInstanceState: android.os.Bundle, /) -> None: ...
        def onActivityPostDestroyed(self, activity: Activity, /) -> None: ...
        def onActivityPostPaused(self, activity: Activity, /) -> None: ...
        def onActivityPostResumed(self, activity: Activity, /) -> None: ...
        def onActivityPostSaveInstanceState(self, activity: Activity, outState: android.os.Bundle, /) -> None: ...
        def onActivityPostStarted(self, activity: Activity, /) -> None: ...
        def onActivityPostStopped(self, activity: Activity, /) -> None: ...
        def onActivityPreCreated(self, activity: Activity, savedInstanceState: android.os.Bundle, /) -> None: ...
        def onActivityPreDestroyed(self, activity: Activity, /) -> None: ...
        def onActivityPrePaused(self, activity: Activity, /) -> None: ...
        def onActivityPreResumed(self, activity: Activity, /) -> None: ...
        def onActivityPreSaveInstanceState(self, activity: Activity, outState: android.os.Bundle, /) -> None: ...
        def onActivityPreStarted(self, activity: Activity, /) -> None: ...
        def onActivityPreStopped(self, activity: Activity, /) -> None: ...
        def onActivityResumed(self, arg1: Activity, /) -> None: ...
        def onActivitySaveInstanceState(self, arg1: Activity, arg2: android.os.Bundle, /) -> None: ...
        def onActivityStarted(self, arg1: Activity, /) -> None: ...
        def onActivityStopped(self, arg1: Activity, /) -> None: ...

class ApplicationErrorReport(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ApplicationErrorReport]] = ...
    TYPE_ANR: typing.ClassVar[int] = ...
    TYPE_BATTERY: typing.ClassVar[int] = ...
    TYPE_CRASH: typing.ClassVar[int] = ...
    TYPE_NONE: typing.ClassVar[int] = ...
    TYPE_RUNNING_SERVICE: typing.ClassVar[int] = ...
    anrInfo: ApplicationErrorReport.AnrInfo = ...
    batteryInfo: ApplicationErrorReport.BatteryInfo = ...
    crashInfo: ApplicationErrorReport.CrashInfo = ...
    installerPackageName: str = ...
    packageName: str = ...
    processName: str = ...
    runningServiceInfo: ApplicationErrorReport.RunningServiceInfo = ...
    systemApp: bool = ...
    time: int = ...
    type: int = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def dump(self, pw: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
    @staticmethod
    def getErrorReportReceiver(context: android.content.Context, packageName: str | java.lang.String, appFlags: int | java.jint | java.lang.Integer, /) -> android.content.ComponentName | None: ...
    def readFromParcel(self, in_: android.os.Parcel, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class RunningServiceInfo(java.lang.Object):
        durationMillis: int = ...
        serviceDetails: str = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, in_: android.os.Parcel, /) -> None: ...
        def dump(self, pw: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class CrashInfo(java.lang.Object):
        exceptionClassName: str = ...
        exceptionMessage: str = ...
        stackTrace: str = ...
        throwClassName: str = ...
        throwFileName: str = ...
        throwLineNumber: int = ...
        throwMethodName: str = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, in_: android.os.Parcel, /) -> None: ...
        @typing.overload
        def __init__(self, tr: java.lang.Throwable, /) -> None: ...
        def dump(self, pw: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class BatteryInfo(java.lang.Object):
        checkinDetails: str = ...
        durationMicros: int = ...
        usageDetails: str = ...
        usagePercent: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, in_: android.os.Parcel, /) -> None: ...
        def dump(self, pw: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class AnrInfo(java.lang.Object):
        activity: str = ...
        cause: str = ...
        info: str = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, in_: android.os.Parcel, /) -> None: ...
        def dump(self, pw: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ApplicationExitInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ApplicationExitInfo]] = ...
    REASON_ANR: typing.ClassVar[int] = ...
    REASON_CRASH: typing.ClassVar[int] = ...
    REASON_CRASH_NATIVE: typing.ClassVar[int] = ...
    REASON_DEPENDENCY_DIED: typing.ClassVar[int] = ...
    REASON_EXCESSIVE_RESOURCE_USAGE: typing.ClassVar[int] = ...
    REASON_EXIT_SELF: typing.ClassVar[int] = ...
    REASON_FREEZER: typing.ClassVar[int] = ...
    REASON_INITIALIZATION_FAILURE: typing.ClassVar[int] = ...
    REASON_LOW_MEMORY: typing.ClassVar[int] = ...
    REASON_OTHER: typing.ClassVar[int] = ...
    REASON_PACKAGE_STATE_CHANGE: typing.ClassVar[int] = ...
    REASON_PACKAGE_UPDATED: typing.ClassVar[int] = ...
    REASON_PERMISSION_CHANGE: typing.ClassVar[int] = ...
    REASON_SIGNALED: typing.ClassVar[int] = ...
    REASON_UNKNOWN: typing.ClassVar[int] = ...
    REASON_USER_REQUESTED: typing.ClassVar[int] = ...
    REASON_USER_STOPPED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDefiningUid(self) -> int: ...
    def getDescription(self) -> str | None: ...
    def getImportance(self) -> int: ...
    def getPackageUid(self) -> int: ...
    def getPid(self) -> int: ...
    def getProcessName(self) -> str: ...
    def getProcessStateSummary(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getPss(self) -> int: ...
    def getRealUid(self) -> int: ...
    def getReason(self) -> int: ...
    def getRss(self) -> int: ...
    def getStatus(self) -> int: ...
    def getTimestamp(self) -> int: ...
    def getTraceInputStream(self) -> java.io.InputStream | None: ...
    def getUserHandle(self) -> android.os.UserHandle: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ApplicationStartInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ApplicationStartInfo]] = ...
    LAUNCH_MODE_SINGLE_INSTANCE: typing.ClassVar[int] = ...
    LAUNCH_MODE_SINGLE_INSTANCE_PER_TASK: typing.ClassVar[int] = ...
    LAUNCH_MODE_SINGLE_TASK: typing.ClassVar[int] = ...
    LAUNCH_MODE_SINGLE_TOP: typing.ClassVar[int] = ...
    LAUNCH_MODE_STANDARD: typing.ClassVar[int] = ...
    STARTUP_STATE_ERROR: typing.ClassVar[int] = ...
    STARTUP_STATE_FIRST_FRAME_DRAWN: typing.ClassVar[int] = ...
    STARTUP_STATE_STARTED: typing.ClassVar[int] = ...
    START_COMPONENT_ACTIVITY: typing.ClassVar[int] = ...
    START_COMPONENT_BROADCAST: typing.ClassVar[int] = ...
    START_COMPONENT_CONTENT_PROVIDER: typing.ClassVar[int] = ...
    START_COMPONENT_OTHER: typing.ClassVar[int] = ...
    START_COMPONENT_SERVICE: typing.ClassVar[int] = ...
    START_REASON_ALARM: typing.ClassVar[int] = ...
    START_REASON_BACKUP: typing.ClassVar[int] = ...
    START_REASON_BOOT_COMPLETE: typing.ClassVar[int] = ...
    START_REASON_BROADCAST: typing.ClassVar[int] = ...
    START_REASON_CONTENT_PROVIDER: typing.ClassVar[int] = ...
    START_REASON_JOB: typing.ClassVar[int] = ...
    START_REASON_LAUNCHER: typing.ClassVar[int] = ...
    START_REASON_LAUNCHER_RECENTS: typing.ClassVar[int] = ...
    START_REASON_OTHER: typing.ClassVar[int] = ...
    START_REASON_PUSH: typing.ClassVar[int] = ...
    START_REASON_SERVICE: typing.ClassVar[int] = ...
    START_REASON_START_ACTIVITY: typing.ClassVar[int] = ...
    START_TIMESTAMP_APPLICATION_ONCREATE: typing.ClassVar[int] = ...
    START_TIMESTAMP_BIND_APPLICATION: typing.ClassVar[int] = ...
    START_TIMESTAMP_FIRST_FRAME: typing.ClassVar[int] = ...
    START_TIMESTAMP_FORK: typing.ClassVar[int] = ...
    START_TIMESTAMP_FULLY_DRAWN: typing.ClassVar[int] = ...
    START_TIMESTAMP_INITIAL_RENDERTHREAD_FRAME: typing.ClassVar[int] = ...
    START_TIMESTAMP_LAUNCH: typing.ClassVar[int] = ...
    START_TIMESTAMP_RESERVED_RANGE_DEVELOPER: typing.ClassVar[int] = ...
    START_TIMESTAMP_RESERVED_RANGE_DEVELOPER_START: typing.ClassVar[int] = ...
    START_TIMESTAMP_RESERVED_RANGE_SYSTEM: typing.ClassVar[int] = ...
    START_TIMESTAMP_SURFACEFLINGER_COMPOSITION_COMPLETE: typing.ClassVar[int] = ...
    START_TYPE_COLD: typing.ClassVar[int] = ...
    START_TYPE_HOT: typing.ClassVar[int] = ...
    START_TYPE_UNSET: typing.ClassVar[int] = ...
    START_TYPE_WARM: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDefiningUid(self) -> int: ...
    def getIntent(self) -> android.content.Intent | None: ...
    def getLaunchMode(self) -> int: ...
    def getPackageUid(self) -> int: ...
    def getPid(self) -> int: ...
    def getProcessName(self) -> str: ...
    def getRealUid(self) -> int: ...
    def getReason(self) -> int: ...
    def getStartComponent(self) -> int: ...
    def getStartType(self) -> int: ...
    def getStartupState(self) -> int: ...
    def getStartupTimestamps(self) -> java.util.Map[java.lang.Integer, java.lang.Long]: ...
    def hashCode(self) -> int: ...
    def wasForceStopped(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AsyncNotedAppOp(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AsyncNotedAppOp]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAttributionTag(self) -> str | None: ...
    def getMessage(self) -> str: ...
    def getNotingUid(self) -> int: ...
    def getOp(self) -> str: ...
    def getTime(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AuthenticationRequiredException(android.os.Parcelable, java.lang.SecurityException):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AuthenticationRequiredException]] = ...
    def __init__(self, cause: java.lang.Throwable, userAction: PendingIntent, /) -> None: ...
    def describeContents(self) -> int: ...
    def getUserAction(self) -> PendingIntent: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AutomaticZenRule(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AutomaticZenRule]] = ...
    TYPE_BEDTIME: typing.ClassVar[int] = ...
    TYPE_DRIVING: typing.ClassVar[int] = ...
    TYPE_IMMERSIVE: typing.ClassVar[int] = ...
    TYPE_MANAGED: typing.ClassVar[int] = ...
    TYPE_OTHER: typing.ClassVar[int] = ...
    TYPE_SCHEDULE_CALENDAR: typing.ClassVar[int] = ...
    TYPE_SCHEDULE_TIME: typing.ClassVar[int] = ...
    TYPE_THEATER: typing.ClassVar[int] = ...
    TYPE_UNKNOWN: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, owner: android.content.ComponentName, conditionId: android.net.Uri, interruptionFilter: int | java.jint | java.lang.Integer, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, owner: android.content.ComponentName, configurationActivity: android.content.ComponentName, conditionId: android.net.Uri, policy: android.service.notification.ZenPolicy, interruptionFilter: int | java.jint | java.lang.Integer, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getConditionId(self) -> android.net.Uri: ...
    def getConfigurationActivity(self) -> android.content.ComponentName | None: ...
    def getCreationTime(self) -> int: ...
    def getDeviceEffects(self) -> android.service.notification.ZenDeviceEffects | None: ...
    def getIconResId(self) -> int: ...
    def getInterruptionFilter(self) -> int: ...
    def getName(self) -> str: ...
    def getOwner(self) -> android.content.ComponentName: ...
    def getTriggerDescription(self) -> str | None: ...
    def getType(self) -> int: ...
    def getZenPolicy(self) -> android.service.notification.ZenPolicy | None: ...
    def hashCode(self) -> int: ...
    def isEnabled(self) -> bool: ...
    def isManualInvocationAllowed(self) -> bool: ...
    def setConditionId(self, conditionId: android.net.Uri, /) -> None: ...
    def setConfigurationActivity(self, componentName: android.content.ComponentName, /) -> None: ...
    def setDeviceEffects(self, deviceEffects: android.service.notification.ZenDeviceEffects, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setInterruptionFilter(self, interruptionFilter: int | java.jint | java.lang.Integer, /) -> None: ...
    def setName(self, name: str | java.lang.String, /) -> None: ...
    def setZenPolicy(self, zenPolicy: android.service.notification.ZenPolicy, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, rule: AutomaticZenRule, /) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, conditionId: android.net.Uri, /) -> None: ...
        def build(self) -> AutomaticZenRule: ...
        def setConditionId(self, conditionId: android.net.Uri, /) -> AutomaticZenRule.Builder: ...
        def setConfigurationActivity(self, configurationActivity: android.content.ComponentName, /) -> AutomaticZenRule.Builder: ...
        def setDeviceEffects(self, deviceEffects: android.service.notification.ZenDeviceEffects, /) -> AutomaticZenRule.Builder: ...
        def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> AutomaticZenRule.Builder: ...
        def setIconResId(self, iconResId: int | java.jint | java.lang.Integer, /) -> AutomaticZenRule.Builder: ...
        def setInterruptionFilter(self, interruptionFilter: int | java.jint | java.lang.Integer, /) -> AutomaticZenRule.Builder: ...
        def setManualInvocationAllowed(self, allowManualInvocation: bool | java.jboolean | java.lang.Boolean, /) -> AutomaticZenRule.Builder: ...
        def setName(self, name: str | java.lang.String, /) -> AutomaticZenRule.Builder: ...
        def setOwner(self, owner: android.content.ComponentName, /) -> AutomaticZenRule.Builder: ...
        def setTriggerDescription(self, description: str | java.lang.String, /) -> AutomaticZenRule.Builder: ...
        def setType(self, type: int | java.jint | java.lang.Integer, /) -> AutomaticZenRule.Builder: ...
        def setZenPolicy(self, policy: android.service.notification.ZenPolicy, /) -> AutomaticZenRule.Builder: ...

class BackgroundServiceStartNotAllowedException(ServiceStartNotAllowedException, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BackgroundServiceStartNotAllowedException]] = ...
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BroadcastOptions(java.lang.Object):
    DEFERRAL_POLICY_DEFAULT: typing.ClassVar[int] = ...
    DEFERRAL_POLICY_NONE: typing.ClassVar[int] = ...
    DEFERRAL_POLICY_UNTIL_ACTIVE: typing.ClassVar[int] = ...
    DELIVERY_GROUP_POLICY_ALL: typing.ClassVar[int] = ...
    DELIVERY_GROUP_POLICY_MOST_RECENT: typing.ClassVar[int] = ...
    def clearDeferralPolicy(self) -> None: ...
    def clearDeliveryGroupMatchingKey(self) -> None: ...
    def clearDeliveryGroupPolicy(self) -> None: ...
    @staticmethod
    def fromBundle(options: android.os.Bundle, /) -> BroadcastOptions: ...
    def getDeferralPolicy(self) -> int: ...
    def getDeliveryGroupMatchingKey(self) -> str | None: ...
    def getDeliveryGroupPolicy(self) -> int: ...
    def isShareIdentityEnabled(self) -> bool: ...
    @staticmethod
    def makeBasic() -> BroadcastOptions: ...
    def setDeferralPolicy(self, deferralPolicy: int | java.jint | java.lang.Integer, /) -> BroadcastOptions: ...
    def setDeliveryGroupMatchingKey(self, namespace: str | java.lang.String, key: str | java.lang.String, /) -> BroadcastOptions: ...
    def setDeliveryGroupPolicy(self, policy: int | java.jint | java.lang.Integer, /) -> BroadcastOptions: ...
    def setShareIdentityEnabled(self, shareIdentityEnabled: bool | java.jboolean | java.lang.Boolean, /) -> BroadcastOptions: ...
    def toBundle(self) -> android.os.Bundle: ...

class ComponentCaller(java.lang.Object):
    def checkContentUriPermission(self, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, /) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPackage(self) -> str | None: ...
    def getUid(self) -> int: ...
    def hashCode(self) -> int: ...

class DatePickerDialog(AlertDialog, android.content.DialogInterface.OnClickListener, android.widget.DatePicker.OnDateChangedListener):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, themeResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, listener: DatePickerDialog.OnDateSetListener, year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, themeResId: int | java.jint | java.lang.Integer, listener: DatePickerDialog.OnDateSetListener, year: int | java.jint | java.lang.Integer, monthOfYear: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDatePicker(self) -> android.widget.DatePicker: ...
    def onClick(self, dialog: android.content.DialogInterface, which: int | java.jint | java.lang.Integer, /) -> None: ...
    def onDateChanged(self, view: android.widget.DatePicker, year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRestoreInstanceState(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Bundle: ...
    def setOnDateSetListener(self, listener: DatePickerDialog.OnDateSetListener, /) -> None: ...
    def updateDate(self, year: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, dayOfMonth: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnDateSetListener(java.lang.Object):
        def onDateSet(self, arg1: android.widget.DatePicker, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class Dialog(android.content.DialogInterface, android.view.KeyEvent.Callback, android.view.View.OnCreateContextMenuListener, android.view.Window.Callback):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, themeResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, cancelable: bool | java.jboolean | java.lang.Boolean, cancelListener: android.content.DialogInterface.OnCancelListener, /) -> None: ...
    def addContentView(self, view: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def cancel(self) -> None: ...
    def closeOptionsMenu(self) -> None: ...
    def create(self) -> None: ...
    def dismiss(self) -> None: ...
    def dispatchGenericMotionEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchKeyShortcutEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchPopulateAccessibilityEvent(self, event: android.view.accessibility.AccessibilityEvent, /) -> bool: ...
    def dispatchTouchEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def dispatchTrackballEvent(self, ev: android.view.MotionEvent, /) -> bool: ...
    def findViewById(self, id: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def getActionBar(self) -> ActionBar | None: ...
    def getContext(self) -> android.content.Context: ...
    def getCurrentFocus(self) -> android.view.View | None: ...
    def getLayoutInflater(self) -> android.view.LayoutInflater: ...
    def getOnBackInvokedDispatcher(self) -> android.window.OnBackInvokedDispatcher: ...
    def getOwnerActivity(self) -> Activity | None: ...
    def getSearchEvent(self) -> android.view.SearchEvent | None: ...
    def getVolumeControlStream(self) -> int: ...
    def getWindow(self) -> android.view.Window | None: ...
    def hide(self) -> None: ...
    def invalidateOptionsMenu(self) -> None: ...
    def isShowing(self) -> bool: ...
    def onActionModeFinished(self, mode: android.view.ActionMode, /) -> None: ...
    def onActionModeStarted(self, mode: android.view.ActionMode, /) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onBackPressed(self) -> None: ...
    def onContentChanged(self) -> None: ...
    def onContextItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def onContextMenuClosed(self, menu: android.view.Menu, /) -> None: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onCreateContextMenu(self, menu: android.view.ContextMenu, v: android.view.View, menuInfo: android.view.ContextMenu.ContextMenuInfo, /) -> None: ...
    def onCreateOptionsMenu(self, menu: android.view.Menu, /) -> bool: ...
    def onCreatePanelMenu(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> bool: ...
    def onCreatePanelView(self, featureId: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def onDetachedFromWindow(self) -> None: ...
    def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyLongPress(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, repeatCount: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyShortcut(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
    def onMenuItemSelected(self, featureId: int | java.jint | java.lang.Integer, item: android.view.MenuItem, /) -> bool: ...
    def onMenuOpened(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> bool: ...
    def onOptionsItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def onOptionsMenuClosed(self, menu: android.view.Menu, /) -> None: ...
    def onPanelClosed(self, featureId: int | java.jint | java.lang.Integer, menu: android.view.Menu, /) -> None: ...
    def onPrepareOptionsMenu(self, menu: android.view.Menu, /) -> bool: ...
    def onPreparePanel(self, featureId: int | java.jint | java.lang.Integer, view: android.view.View, menu: android.view.Menu, /) -> bool: ...
    def onRestoreInstanceState(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Bundle: ...
    @typing.overload
    def onSearchRequested(self) -> bool: ...
    @typing.overload
    def onSearchRequested(self, searchEvent: android.view.SearchEvent, /) -> bool: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def onWindowAttributesChanged(self, params: android.view.WindowManager.LayoutParams, /) -> None: ...
    def onWindowFocusChanged(self, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onWindowStartingActionMode(self, callback: android.view.ActionMode.Callback, /) -> android.view.ActionMode: ...
    @typing.overload
    def onWindowStartingActionMode(self, callback: android.view.ActionMode.Callback, type: int | java.jint | java.lang.Integer, /) -> android.view.ActionMode: ...
    def openContextMenu(self, view: android.view.View, /) -> None: ...
    def openOptionsMenu(self) -> None: ...
    def registerForContextMenu(self, view: android.view.View, /) -> None: ...
    def requestWindowFeature(self, featureId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def requireViewById(self, id: int | java.jint | java.lang.Integer, /) -> android.view.View: ...
    def setCancelMessage(self, msg: android.os.Message, /) -> None: ...
    def setCancelable(self, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCanceledOnTouchOutside(self, cancel: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setContentView(self, layoutResID: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setContentView(self, view: android.view.View, /) -> None: ...
    @typing.overload
    def setContentView(self, view: android.view.View, params: android.view.ViewGroup.LayoutParams, /) -> None: ...
    def setDismissMessage(self, msg: android.os.Message, /) -> None: ...
    def setFeatureDrawable(self, featureId: int | java.jint | java.lang.Integer, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    def setFeatureDrawableAlpha(self, featureId: int | java.jint | java.lang.Integer, alpha: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFeatureDrawableResource(self, featureId: int | java.jint | java.lang.Integer, resId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setFeatureDrawableUri(self, featureId: int | java.jint | java.lang.Integer, uri: android.net.Uri, /) -> None: ...
    def setOnCancelListener(self, listener: android.content.DialogInterface.OnCancelListener, /) -> None: ...
    def setOnDismissListener(self, listener: android.content.DialogInterface.OnDismissListener, /) -> None: ...
    def setOnKeyListener(self, onKeyListener: android.content.DialogInterface.OnKeyListener, /) -> None: ...
    def setOnShowListener(self, listener: android.content.DialogInterface.OnShowListener, /) -> None: ...
    def setOwnerActivity(self, activity: Activity, /) -> None: ...
    @typing.overload
    def setTitle(self, titleId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, title: java.lang.CharSequence, /) -> None: ...
    def setVolumeControlStream(self, streamType: int | java.jint | java.lang.Integer, /) -> None: ...
    def show(self) -> None: ...
    def takeKeyEvents(self, get: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def unregisterForContextMenu(self, view: android.view.View, /) -> None: ...

class DialogFragment(Fragment, android.content.DialogInterface.OnCancelListener, android.content.DialogInterface.OnDismissListener):
    STYLE_NORMAL: typing.ClassVar[int] = ...
    STYLE_NO_FRAME: typing.ClassVar[int] = ...
    STYLE_NO_INPUT: typing.ClassVar[int] = ...
    STYLE_NO_TITLE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def dismiss(self) -> None: ...
    def dismissAllowingStateLoss(self) -> None: ...
    def dump(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def getDialog(self) -> Dialog: ...
    def getShowsDialog(self) -> bool: ...
    def getTheme(self) -> int: ...
    def isCancelable(self) -> bool: ...
    def onActivityCreated(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onAttach(self, context: android.content.Context, /) -> None: ...
    def onCancel(self, dialog: android.content.DialogInterface, /) -> None: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onCreateDialog(self, savedInstanceState: android.os.Bundle, /) -> Dialog: ...
    def onDestroyView(self) -> None: ...
    def onDetach(self) -> None: ...
    def onDismiss(self, dialog: android.content.DialogInterface, /) -> None: ...
    def onGetLayoutInflater(self, savedInstanceState: android.os.Bundle, /) -> android.view.LayoutInflater: ...
    def onSaveInstanceState(self, outState: android.os.Bundle, /) -> None: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def setCancelable(self, cancelable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShowsDialog(self, showsDialog: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStyle(self, style: int | java.jint | java.lang.Integer, theme: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def show(self, manager: FragmentManager, tag: str | java.lang.String, /) -> None: ...
    @typing.overload
    def show(self, transaction: FragmentTransaction, tag: str | java.lang.String, /) -> int: ...

class DirectAction(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DirectAction]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getExtras(self) -> android.os.Bundle | None: ...
    def getId(self) -> str: ...
    def getLocusId(self) -> android.content.LocusId | None: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, id: str | java.lang.String, /) -> None: ...
        def build(self) -> DirectAction: ...
        def setExtras(self, extras: android.os.Bundle, /) -> DirectAction.Builder: ...
        def setLocusId(self, locusId: android.content.LocusId, /) -> DirectAction.Builder: ...

class DownloadManager(java.lang.Object):
    ACTION_DOWNLOAD_COMPLETE: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_CLICKED: typing.ClassVar[str] = ...
    ACTION_VIEW_DOWNLOADS: typing.ClassVar[str] = ...
    COLUMN_BYTES_DOWNLOADED_SO_FAR: typing.ClassVar[str] = ...
    COLUMN_DESCRIPTION: typing.ClassVar[str] = ...
    COLUMN_ID: typing.ClassVar[str] = ...
    COLUMN_LAST_MODIFIED_TIMESTAMP: typing.ClassVar[str] = ...
    COLUMN_LOCAL_FILENAME: typing.ClassVar[str] = ...
    COLUMN_LOCAL_URI: typing.ClassVar[str] = ...
    COLUMN_MEDIAPROVIDER_URI: typing.ClassVar[str] = ...
    COLUMN_MEDIA_TYPE: typing.ClassVar[str] = ...
    COLUMN_REASON: typing.ClassVar[str] = ...
    COLUMN_STATUS: typing.ClassVar[str] = ...
    COLUMN_TITLE: typing.ClassVar[str] = ...
    COLUMN_TOTAL_SIZE_BYTES: typing.ClassVar[str] = ...
    COLUMN_URI: typing.ClassVar[str] = ...
    ERROR_CANNOT_RESUME: typing.ClassVar[int] = ...
    ERROR_DEVICE_NOT_FOUND: typing.ClassVar[int] = ...
    ERROR_FILE_ALREADY_EXISTS: typing.ClassVar[int] = ...
    ERROR_FILE_ERROR: typing.ClassVar[int] = ...
    ERROR_HTTP_DATA_ERROR: typing.ClassVar[int] = ...
    ERROR_INSUFFICIENT_SPACE: typing.ClassVar[int] = ...
    ERROR_TOO_MANY_REDIRECTS: typing.ClassVar[int] = ...
    ERROR_UNHANDLED_HTTP_CODE: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    EXTRA_DOWNLOAD_ID: typing.ClassVar[str] = ...
    EXTRA_NOTIFICATION_CLICK_DOWNLOAD_IDS: typing.ClassVar[str] = ...
    INTENT_EXTRAS_SORT_BY_SIZE: typing.ClassVar[str] = ...
    PAUSED_QUEUED_FOR_WIFI: typing.ClassVar[int] = ...
    PAUSED_UNKNOWN: typing.ClassVar[int] = ...
    PAUSED_WAITING_FOR_NETWORK: typing.ClassVar[int] = ...
    PAUSED_WAITING_TO_RETRY: typing.ClassVar[int] = ...
    STATUS_FAILED: typing.ClassVar[int] = ...
    STATUS_PAUSED: typing.ClassVar[int] = ...
    STATUS_PENDING: typing.ClassVar[int] = ...
    STATUS_RUNNING: typing.ClassVar[int] = ...
    STATUS_SUCCESSFUL: typing.ClassVar[int] = ...
    @typing.overload
    def addCompletedDownload(self, title: str | java.lang.String, description: str | java.lang.String, isMediaScannerScannable: bool | java.jboolean | java.lang.Boolean, mimeType: str | java.lang.String, path: str | java.lang.String, length: int | java.jlong | java.lang.Long, showNotification: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    @typing.overload
    def addCompletedDownload(self, title: str | java.lang.String, description: str | java.lang.String, isMediaScannerScannable: bool | java.jboolean | java.lang.Boolean, mimeType: str | java.lang.String, path: str | java.lang.String, length: int | java.jlong | java.lang.Long, showNotification: bool | java.jboolean | java.lang.Boolean, uri: android.net.Uri, referer: android.net.Uri, /) -> int: ...
    def enqueue(self, request: DownloadManager.Request, /) -> int: ...
    @staticmethod
    def getMaxBytesOverMobile(context: android.content.Context, /) -> int | None: ...
    def getMimeTypeForDownloadedFile(self, id: int | java.jlong | java.lang.Long, /) -> str: ...
    @staticmethod
    def getRecommendedMaxBytesOverMobile(context: android.content.Context, /) -> int | None: ...
    def getUriForDownloadedFile(self, id: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    def openDownloadedFile(self, id: int | java.jlong | java.lang.Long, /) -> android.os.ParcelFileDescriptor: ...
    def query(self, query: DownloadManager.Query, /) -> android.database.Cursor: ...
    def remove(self, *ids: java.jlong) -> int: ...

    class Request(java.lang.Object):
        NETWORK_MOBILE: typing.ClassVar[int] = ...
        NETWORK_WIFI: typing.ClassVar[int] = ...
        VISIBILITY_HIDDEN: typing.ClassVar[int] = ...
        VISIBILITY_VISIBLE: typing.ClassVar[int] = ...
        VISIBILITY_VISIBLE_NOTIFY_COMPLETED: typing.ClassVar[int] = ...
        VISIBILITY_VISIBLE_NOTIFY_ONLY_COMPLETION: typing.ClassVar[int] = ...
        def __init__(self, uri: android.net.Uri, /) -> None: ...
        def addRequestHeader(self, header: str | java.lang.String, value: str | java.lang.String, /) -> DownloadManager.Request: ...
        def allowScanningByMediaScanner(self) -> None: ...
        def setAllowedNetworkTypes(self, flags: int | java.jint | java.lang.Integer, /) -> DownloadManager.Request: ...
        def setAllowedOverMetered(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> DownloadManager.Request: ...
        def setAllowedOverRoaming(self, allowed: bool | java.jboolean | java.lang.Boolean, /) -> DownloadManager.Request: ...
        def setDescription(self, description: java.lang.CharSequence, /) -> DownloadManager.Request: ...
        def setDestinationInExternalFilesDir(self, context: android.content.Context, dirType: str | java.lang.String, subPath: str | java.lang.String, /) -> DownloadManager.Request: ...
        def setDestinationInExternalPublicDir(self, dirType: str | java.lang.String, subPath: str | java.lang.String, /) -> DownloadManager.Request: ...
        def setDestinationUri(self, uri: android.net.Uri, /) -> DownloadManager.Request: ...
        def setMimeType(self, mimeType: str | java.lang.String, /) -> DownloadManager.Request: ...
        def setNotificationVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> DownloadManager.Request: ...
        def setRequiresCharging(self, requiresCharging: bool | java.jboolean | java.lang.Boolean, /) -> DownloadManager.Request: ...
        def setRequiresDeviceIdle(self, requiresDeviceIdle: bool | java.jboolean | java.lang.Boolean, /) -> DownloadManager.Request: ...
        def setShowRunningNotification(self, show: bool | java.jboolean | java.lang.Boolean, /) -> DownloadManager.Request: ...
        def setTitle(self, title: java.lang.CharSequence, /) -> DownloadManager.Request: ...
        def setVisibleInDownloadsUi(self, isVisible: bool | java.jboolean | java.lang.Boolean, /) -> DownloadManager.Request: ...

    class Query(java.lang.Object):
        def __init__(self) -> None: ...
        def setFilterById(self, *ids: java.jlong) -> DownloadManager.Query: ...
        def setFilterByStatus(self, flags: int | java.jint | java.lang.Integer, /) -> DownloadManager.Query: ...

class ExpandableListActivity(Activity, android.view.View.OnCreateContextMenuListener, android.widget.ExpandableListView.OnChildClickListener, android.widget.ExpandableListView.OnGroupCollapseListener, android.widget.ExpandableListView.OnGroupExpandListener):
    def __init__(self) -> None: ...
    def getExpandableListAdapter(self) -> android.widget.ExpandableListAdapter: ...
    def getExpandableListView(self) -> android.widget.ExpandableListView: ...
    def getSelectedId(self) -> int: ...
    def getSelectedPosition(self) -> int: ...
    def onChildClick(self, parent: android.widget.ExpandableListView, v: android.view.View, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> bool: ...
    def onContentChanged(self) -> None: ...
    def onCreateContextMenu(self, menu: android.view.ContextMenu, v: android.view.View, menuInfo: android.view.ContextMenu.ContextMenuInfo, /) -> None: ...
    def onGroupCollapse(self, groupPosition: int | java.jint | java.lang.Integer, /) -> None: ...
    def onGroupExpand(self, groupPosition: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Bundle, /) -> None: ...
    def setListAdapter(self, adapter: android.widget.ExpandableListAdapter, /) -> None: ...
    def setSelectedChild(self, groupPosition: int | java.jint | java.lang.Integer, childPosition: int | java.jint | java.lang.Integer, shouldExpandGroup: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def setSelectedGroup(self, groupPosition: int | java.jint | java.lang.Integer, /) -> None: ...

class ForegroundServiceStartNotAllowedException(ServiceStartNotAllowedException, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ForegroundServiceStartNotAllowedException]] = ...
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ForegroundServiceTypeException(ServiceStartNotAllowedException):
    def __init__(self, message: str | java.lang.String, /) -> None: ...

class Fragment(android.content.ComponentCallbacks2, android.view.View.OnCreateContextMenuListener):
    def __init__(self) -> None: ...
    def dump(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getActivity(self) -> Activity: ...
    def getAllowEnterTransitionOverlap(self) -> bool: ...
    def getAllowReturnTransitionOverlap(self) -> bool: ...
    def getArguments(self) -> android.os.Bundle: ...
    def getChildFragmentManager(self) -> FragmentManager: ...
    def getContext(self) -> android.content.Context: ...
    def getEnterTransition(self) -> android.transition.Transition: ...
    def getExitTransition(self) -> android.transition.Transition: ...
    def getFragmentManager(self) -> FragmentManager: ...
    def getHost(self) -> java.lang.Object | None: ...
    def getId(self) -> int: ...
    def getLayoutInflater(self) -> android.view.LayoutInflater: ...
    def getLoaderManager(self) -> LoaderManager: ...
    def getParentFragment(self) -> Fragment: ...
    def getReenterTransition(self) -> android.transition.Transition: ...
    def getResources(self) -> android.content.res.Resources: ...
    def getRetainInstance(self) -> bool: ...
    def getReturnTransition(self) -> android.transition.Transition: ...
    def getSharedElementEnterTransition(self) -> android.transition.Transition: ...
    def getSharedElementReturnTransition(self) -> android.transition.Transition: ...
    @typing.overload
    def getString(self, resId: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getString(self, resId: int | java.jint | java.lang.Integer, /, *formatArgs: java.lang.Object) -> str: ...
    def getTag(self) -> str: ...
    def getTargetFragment(self) -> Fragment: ...
    def getTargetRequestCode(self) -> int: ...
    def getText(self, resId: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def getUserVisibleHint(self) -> bool: ...
    def getView(self) -> android.view.View | None: ...
    def hashCode(self) -> int: ...
    @typing.overload
    @staticmethod
    def instantiate(context: android.content.Context, fname: str | java.lang.String, /) -> Fragment: ...
    @typing.overload
    @staticmethod
    def instantiate(context: android.content.Context, fname: str | java.lang.String, args: android.os.Bundle, /) -> Fragment: ...
    def isAdded(self) -> bool: ...
    def isDetached(self) -> bool: ...
    def isHidden(self) -> bool: ...
    def isInLayout(self) -> bool: ...
    def isRemoving(self) -> bool: ...
    def isResumed(self) -> bool: ...
    def isStateSaved(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def onActivityCreated(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onActivityResult(self, requestCode: int | java.jint | java.lang.Integer, resultCode: int | java.jint | java.lang.Integer, data: android.content.Intent, /) -> None: ...
    @typing.overload
    def onAttach(self, activity: Activity, /) -> None: ...
    @typing.overload
    def onAttach(self, context: android.content.Context, /) -> None: ...
    def onAttachFragment(self, childFragment: Fragment, /) -> None: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onContextItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onCreateAnimator(self, transit: int | java.jint | java.lang.Integer, enter: bool | java.jboolean | java.lang.Boolean, nextAnim: int | java.jint | java.lang.Integer, /) -> android.animation.Animator: ...
    def onCreateContextMenu(self, menu: android.view.ContextMenu, v: android.view.View, menuInfo: android.view.ContextMenu.ContextMenuInfo, /) -> None: ...
    def onCreateOptionsMenu(self, menu: android.view.Menu, inflater: android.view.MenuInflater, /) -> None: ...
    def onCreateView(self, inflater: android.view.LayoutInflater, container: android.view.ViewGroup, savedInstanceState: android.os.Bundle, /) -> android.view.View | None: ...
    def onDestroy(self) -> None: ...
    def onDestroyOptionsMenu(self) -> None: ...
    def onDestroyView(self) -> None: ...
    def onDetach(self) -> None: ...
    def onGetLayoutInflater(self, savedInstanceState: android.os.Bundle, /) -> android.view.LayoutInflater: ...
    def onHiddenChanged(self, hidden: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onInflate(self, attrs: android.util.AttributeSet, savedInstanceState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def onInflate(self, activity: Activity, attrs: android.util.AttributeSet, savedInstanceState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def onInflate(self, context: android.content.Context, attrs: android.util.AttributeSet, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onLowMemory(self) -> None: ...
    @typing.overload
    def onMultiWindowModeChanged(self, isInMultiWindowMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onMultiWindowModeChanged(self, isInMultiWindowMode: bool | java.jboolean | java.lang.Boolean, newConfig: android.content.res.Configuration, /) -> None: ...
    def onOptionsItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def onOptionsMenuClosed(self, menu: android.view.Menu, /) -> None: ...
    def onPause(self) -> None: ...
    @typing.overload
    def onPictureInPictureModeChanged(self, isInPictureInPictureMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def onPictureInPictureModeChanged(self, isInPictureInPictureMode: bool | java.jboolean | java.lang.Boolean, newConfig: android.content.res.Configuration, /) -> None: ...
    def onPrepareOptionsMenu(self, menu: android.view.Menu, /) -> None: ...
    def onRequestPermissionsResult(self, requestCode: int | java.jint | java.lang.Integer, permissions: java.chaquopy.JavaArray[java.lang.String], grantResults: java.chaquopy.JavaArrayJInt, /) -> None: ...
    def onResume(self) -> None: ...
    def onSaveInstanceState(self, outState: android.os.Bundle, /) -> None: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def onTrimMemory(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def onViewCreated(self, view: android.view.View, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onViewStateRestored(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def postponeEnterTransition(self) -> None: ...
    def registerForContextMenu(self, view: android.view.View, /) -> None: ...
    def requestPermissions(self, permissions: java.chaquopy.JavaArray[java.lang.String], requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setAllowEnterTransitionOverlap(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setAllowReturnTransitionOverlap(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setArguments(self, args: android.os.Bundle, /) -> None: ...
    def setEnterSharedElementCallback(self, callback: SharedElementCallback, /) -> None: ...
    def setEnterTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setExitSharedElementCallback(self, callback: SharedElementCallback, /) -> None: ...
    def setExitTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setHasOptionsMenu(self, hasMenu: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setInitialSavedState(self, state: Fragment.SavedState, /) -> None: ...
    def setMenuVisibility(self, menuVisible: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setReenterTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setRetainInstance(self, retain: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setReturnTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setSharedElementEnterTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setSharedElementReturnTransition(self, transition: android.transition.Transition, /) -> None: ...
    def setTargetFragment(self, fragment: Fragment, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setUserVisibleHint(self, isVisibleToUser: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def shouldShowRequestPermissionRationale(self, permission: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def startActivity(self, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def startActivity(self, intent: android.content.Intent, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startActivityForResult(self, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startActivityForResult(self, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def startIntentSenderForResult(self, intent: android.content.IntentSender, requestCode: int | java.jint | java.lang.Integer, fillInIntent: android.content.Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def startPostponedEnterTransition(self) -> None: ...
    def toString(self) -> str: ...
    def unregisterForContextMenu(self, view: android.view.View, /) -> None: ...

    class SavedState(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.ClassLoaderCreator[Fragment.SavedState]] = ...
        def describeContents(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class InstantiationException(android.util.AndroidRuntimeException):
        def __init__(self, msg: str | java.lang.String, cause: java.lang.Exception, /) -> None: ...

class FragmentBreadCrumbs(FragmentManager.OnBackStackChangedListener, android.view.ViewGroup):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    def onBackStackChanged(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, l: int | java.jint | java.lang.Integer, t: int | java.jint | java.lang.Integer, r: int | java.jint | java.lang.Integer, b: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def setActivity(self, a: Activity, /) -> None: ...
    def setMaxVisible(self, visibleCrumbs: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOnBreadCrumbClickListener(self, listener: FragmentBreadCrumbs.OnBreadCrumbClickListener, /) -> None: ...
    def setParentTitle(self, title: java.lang.CharSequence, shortTitle: java.lang.CharSequence, listener: android.view.View.OnClickListener, /) -> None: ...
    def setTitle(self, title: java.lang.CharSequence, shortTitle: java.lang.CharSequence, /) -> None: ...

    class OnBreadCrumbClickListener(java.lang.Object):
        def onBreadCrumbClick(self, arg1: FragmentManager.BackStackEntry, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...

class FragmentContainer(java.lang.Object):
    def __init__(self) -> None: ...
    def onFindViewById(self, arg1: int | java.jint | java.lang.Integer, /) -> android.view.View | None: ...
    def onHasView(self) -> bool: ...

class FragmentController(java.lang.Object):
    def attachHost(self, parent: Fragment, /) -> None: ...
    @staticmethod
    def createController(callbacks: FragmentHostCallback[java.lang.Object], /) -> FragmentController: ...
    def dispatchActivityCreated(self) -> None: ...
    def dispatchConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def dispatchContextItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def dispatchCreate(self) -> None: ...
    def dispatchCreateOptionsMenu(self, menu: android.view.Menu, inflater: android.view.MenuInflater, /) -> bool: ...
    def dispatchDestroy(self) -> None: ...
    def dispatchDestroyView(self) -> None: ...
    def dispatchLowMemory(self) -> None: ...
    @typing.overload
    def dispatchMultiWindowModeChanged(self, isInMultiWindowMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def dispatchMultiWindowModeChanged(self, isInMultiWindowMode: bool | java.jboolean | java.lang.Boolean, newConfig: android.content.res.Configuration, /) -> None: ...
    def dispatchOptionsItemSelected(self, item: android.view.MenuItem, /) -> bool: ...
    def dispatchOptionsMenuClosed(self, menu: android.view.Menu, /) -> None: ...
    def dispatchPause(self) -> None: ...
    @typing.overload
    def dispatchPictureInPictureModeChanged(self, isInPictureInPictureMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def dispatchPictureInPictureModeChanged(self, isInPictureInPictureMode: bool | java.jboolean | java.lang.Boolean, newConfig: android.content.res.Configuration, /) -> None: ...
    def dispatchPrepareOptionsMenu(self, menu: android.view.Menu, /) -> bool: ...
    def dispatchResume(self) -> None: ...
    def dispatchStart(self) -> None: ...
    def dispatchStop(self) -> None: ...
    def dispatchTrimMemory(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def doLoaderDestroy(self) -> None: ...
    def doLoaderStart(self) -> None: ...
    def doLoaderStop(self, retain: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dumpLoaders(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def execPendingActions(self) -> bool: ...
    def findFragmentByWho(self, who: str | java.lang.String, /) -> Fragment | None: ...
    def getFragmentManager(self) -> FragmentManager: ...
    def getLoaderManager(self) -> LoaderManager: ...
    def noteStateNotSaved(self) -> None: ...
    def onCreateView(self, parent: android.view.View, name: str | java.lang.String, context: android.content.Context, attrs: android.util.AttributeSet, /) -> android.view.View: ...
    def reportLoaderStart(self) -> None: ...
    @typing.overload
    def restoreAllState(self, state: android.os.Parcelable, nonConfig: FragmentManagerNonConfig, /) -> None: ...
    @typing.overload
    def restoreAllState(self, state: android.os.Parcelable, nonConfigList: java.util.List[Fragment], /) -> None: ...
    def restoreLoaderNonConfig(self, loaderManagers: android.util.ArrayMap[java.lang.String, LoaderManager], /) -> None: ...
    def retainLoaderNonConfig(self) -> android.util.ArrayMap[java.lang.String, LoaderManager]: ...
    def retainNestedNonConfig(self) -> FragmentManagerNonConfig: ...
    def retainNonConfig(self) -> java.util.List[Fragment]: ...
    def saveAllState(self) -> android.os.Parcelable: ...

_FragmentHostCallback__E = typing.TypeVar('_FragmentHostCallback__E')  # <E>
class FragmentHostCallback(FragmentContainer, typing.Generic[_FragmentHostCallback__E]):
    def __init__(self, context: android.content.Context, handler: android.os.Handler, windowAnimations: int | java.jint | java.lang.Integer, /) -> None: ...
    def onAttachFragment(self, fragment: Fragment, /) -> None: ...
    def onDump(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def onFindViewById(self, id: int | java.jint | java.lang.Integer, /) -> android.view.View | None: ...
    def onGetHost(self) -> _FragmentHostCallback__E | None: ...
    def onGetLayoutInflater(self) -> android.view.LayoutInflater: ...
    def onGetWindowAnimations(self) -> int: ...
    def onHasView(self) -> bool: ...
    def onHasWindowAnimations(self) -> bool: ...
    def onInvalidateOptionsMenu(self) -> None: ...
    def onRequestPermissionsFromFragment(self, fragment: Fragment, permissions: java.chaquopy.JavaArray[java.lang.String], requestCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def onShouldSaveFragmentState(self, fragment: Fragment, /) -> bool: ...
    def onStartActivityFromFragment(self, fragment: Fragment, intent: android.content.Intent, requestCode: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def onStartIntentSenderFromFragment(self, fragment: Fragment, intent: android.content.IntentSender, requestCode: int | java.jint | java.lang.Integer, fillInIntent: android.content.Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def onUseFragmentManagerInflaterFactory(self) -> bool: ...

class FragmentManager(java.lang.Object):
    POP_BACK_STACK_INCLUSIVE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def addOnBackStackChangedListener(self, arg1: FragmentManager.OnBackStackChangedListener, /) -> None: ...
    def beginTransaction(self) -> FragmentTransaction: ...
    def dump(self, arg1: str | java.lang.String, arg2: java.io.FileDescriptor, arg3: java.io.PrintWriter, arg4: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @staticmethod
    def enableDebugLogging(enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def executePendingTransactions(self) -> bool: ...
    def findFragmentById(self, arg1: int | java.jint | java.lang.Integer, /) -> Fragment | None: ...
    def findFragmentByTag(self, arg1: str | java.lang.String, /) -> Fragment | None: ...
    def getBackStackEntryAt(self, arg1: int | java.jint | java.lang.Integer, /) -> FragmentManager.BackStackEntry: ...
    def getBackStackEntryCount(self) -> int: ...
    def getFragment(self, arg1: android.os.Bundle, arg2: str | java.lang.String, /) -> Fragment: ...
    def getFragments(self) -> java.util.List[Fragment]: ...
    def getPrimaryNavigationFragment(self) -> Fragment: ...
    def invalidateOptionsMenu(self) -> None: ...
    def isDestroyed(self) -> bool: ...
    def isStateSaved(self) -> bool: ...
    @typing.overload
    def popBackStack(self) -> None: ...
    @typing.overload
    def popBackStack(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def popBackStack(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def popBackStackImmediate(self) -> bool: ...
    @typing.overload
    def popBackStackImmediate(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def popBackStackImmediate(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> bool: ...
    def putFragment(self, arg1: android.os.Bundle, arg2: str | java.lang.String, arg3: Fragment, /) -> None: ...
    def registerFragmentLifecycleCallbacks(self, arg1: FragmentManager.FragmentLifecycleCallbacks, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def removeOnBackStackChangedListener(self, arg1: FragmentManager.OnBackStackChangedListener, /) -> None: ...
    def saveFragmentInstanceState(self, arg1: Fragment, /) -> Fragment.SavedState | None: ...
    def unregisterFragmentLifecycleCallbacks(self, arg1: FragmentManager.FragmentLifecycleCallbacks, /) -> None: ...

    class OnBackStackChangedListener(java.lang.Object):
        def onBackStackChanged(self) -> None: ...

    class FragmentLifecycleCallbacks(java.lang.Object):
        def __init__(self) -> None: ...
        def onFragmentActivityCreated(self, fm: FragmentManager, f: Fragment, savedInstanceState: android.os.Bundle, /) -> None: ...
        def onFragmentAttached(self, fm: FragmentManager, f: Fragment, context: android.content.Context, /) -> None: ...
        def onFragmentCreated(self, fm: FragmentManager, f: Fragment, savedInstanceState: android.os.Bundle, /) -> None: ...
        def onFragmentDestroyed(self, fm: FragmentManager, f: Fragment, /) -> None: ...
        def onFragmentDetached(self, fm: FragmentManager, f: Fragment, /) -> None: ...
        def onFragmentPaused(self, fm: FragmentManager, f: Fragment, /) -> None: ...
        def onFragmentPreAttached(self, fm: FragmentManager, f: Fragment, context: android.content.Context, /) -> None: ...
        def onFragmentPreCreated(self, fm: FragmentManager, f: Fragment, savedInstanceState: android.os.Bundle, /) -> None: ...
        def onFragmentResumed(self, fm: FragmentManager, f: Fragment, /) -> None: ...
        def onFragmentSaveInstanceState(self, fm: FragmentManager, f: Fragment, outState: android.os.Bundle, /) -> None: ...
        def onFragmentStarted(self, fm: FragmentManager, f: Fragment, /) -> None: ...
        def onFragmentStopped(self, fm: FragmentManager, f: Fragment, /) -> None: ...
        def onFragmentViewCreated(self, fm: FragmentManager, f: Fragment, v: android.view.View, savedInstanceState: android.os.Bundle, /) -> None: ...
        def onFragmentViewDestroyed(self, fm: FragmentManager, f: Fragment, /) -> None: ...

    class BackStackEntry(java.lang.Object):
        def getBreadCrumbShortTitle(self) -> java.lang.CharSequence: ...
        def getBreadCrumbShortTitleRes(self) -> int: ...
        def getBreadCrumbTitle(self) -> java.lang.CharSequence: ...
        def getBreadCrumbTitleRes(self) -> int: ...
        def getId(self) -> int: ...
        def getName(self) -> str: ...

class FragmentManagerNonConfig(java.lang.Object): ...

class FragmentTransaction(java.lang.Object):
    TRANSIT_ENTER_MASK: typing.ClassVar[int] = ...
    TRANSIT_EXIT_MASK: typing.ClassVar[int] = ...
    TRANSIT_FRAGMENT_CLOSE: typing.ClassVar[int] = ...
    TRANSIT_FRAGMENT_FADE: typing.ClassVar[int] = ...
    TRANSIT_FRAGMENT_OPEN: typing.ClassVar[int] = ...
    TRANSIT_NONE: typing.ClassVar[int] = ...
    TRANSIT_UNSET: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @typing.overload
    def add(self, arg1: int | java.jint | java.lang.Integer, arg2: Fragment, /) -> FragmentTransaction: ...
    @typing.overload
    def add(self, arg1: Fragment, arg2: str | java.lang.String, /) -> FragmentTransaction: ...
    @typing.overload
    def add(self, arg1: int | java.jint | java.lang.Integer, arg2: Fragment, arg3: str | java.lang.String, /) -> FragmentTransaction: ...
    def addSharedElement(self, arg1: android.view.View, arg2: str | java.lang.String, /) -> FragmentTransaction: ...
    def addToBackStack(self, arg1: str | java.lang.String, /) -> FragmentTransaction: ...
    def attach(self, arg1: Fragment, /) -> FragmentTransaction: ...
    def commit(self) -> int: ...
    def commitAllowingStateLoss(self) -> int: ...
    def commitNow(self) -> None: ...
    def commitNowAllowingStateLoss(self) -> None: ...
    def detach(self, arg1: Fragment, /) -> FragmentTransaction: ...
    def disallowAddToBackStack(self) -> FragmentTransaction: ...
    def hide(self, arg1: Fragment, /) -> FragmentTransaction: ...
    def isAddToBackStackAllowed(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def remove(self, arg1: Fragment, /) -> FragmentTransaction: ...
    @typing.overload
    def replace(self, arg1: int | java.jint | java.lang.Integer, arg2: Fragment, /) -> FragmentTransaction: ...
    @typing.overload
    def replace(self, arg1: int | java.jint | java.lang.Integer, arg2: Fragment, arg3: str | java.lang.String, /) -> FragmentTransaction: ...
    def runOnCommit(self, arg1: java.lang.Runnable, /) -> FragmentTransaction: ...
    @typing.overload
    def setBreadCrumbShortTitle(self, arg1: int | java.jint | java.lang.Integer, /) -> FragmentTransaction: ...
    @typing.overload
    def setBreadCrumbShortTitle(self, arg1: java.lang.CharSequence, /) -> FragmentTransaction: ...
    @typing.overload
    def setBreadCrumbTitle(self, arg1: int | java.jint | java.lang.Integer, /) -> FragmentTransaction: ...
    @typing.overload
    def setBreadCrumbTitle(self, arg1: java.lang.CharSequence, /) -> FragmentTransaction: ...
    @typing.overload
    def setCustomAnimations(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> FragmentTransaction: ...
    @typing.overload
    def setCustomAnimations(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> FragmentTransaction: ...
    def setPrimaryNavigationFragment(self, arg1: Fragment, /) -> FragmentTransaction: ...
    def setReorderingAllowed(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> FragmentTransaction: ...
    def setTransition(self, arg1: int | java.jint | java.lang.Integer, /) -> FragmentTransaction: ...
    def setTransitionStyle(self, arg1: int | java.jint | java.lang.Integer, /) -> FragmentTransaction: ...
    def show(self, arg1: Fragment, /) -> FragmentTransaction: ...

class GameManager(java.lang.Object):
    GAME_MODE_BATTERY: typing.ClassVar[int] = ...
    GAME_MODE_CUSTOM: typing.ClassVar[int] = ...
    GAME_MODE_PERFORMANCE: typing.ClassVar[int] = ...
    GAME_MODE_STANDARD: typing.ClassVar[int] = ...
    GAME_MODE_UNSUPPORTED: typing.ClassVar[int] = ...
    def getGameMode(self) -> int: ...
    def setGameState(self, gameState: GameState, /) -> None: ...

class GameState(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[GameState]] = ...
    MODE_CONTENT: typing.ClassVar[int] = ...
    MODE_GAMEPLAY_INTERRUPTIBLE: typing.ClassVar[int] = ...
    MODE_GAMEPLAY_UNINTERRUPTIBLE: typing.ClassVar[int] = ...
    MODE_NONE: typing.ClassVar[int] = ...
    MODE_UNKNOWN: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, isLoading: bool | java.jboolean | java.lang.Boolean, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, isLoading: bool | java.jboolean | java.lang.Boolean, mode: int | java.jint | java.lang.Integer, label: int | java.jint | java.lang.Integer, quality: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getLabel(self) -> int: ...
    def getMode(self) -> int: ...
    def getQuality(self) -> int: ...
    def isLoading(self) -> bool: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class GrammaticalInflectionManager(java.lang.Object):
    def getApplicationGrammaticalGender(self) -> int: ...
    def getSystemGrammaticalGender(self) -> int: ...
    def setRequestedApplicationGrammaticalGender(self, grammaticalGender: int | java.jint | java.lang.Integer, /) -> None: ...

class Instrumentation(java.lang.Object):
    REPORT_KEY_IDENTIFIER: typing.ClassVar[str] = ...
    REPORT_KEY_STREAMRESULT: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def acquireLooperManager(self, looper: android.os.Looper, /) -> android.os.TestLooperManager: ...
    @typing.overload
    def addMonitor(self, monitor: Instrumentation.ActivityMonitor, /) -> None: ...
    @typing.overload
    def addMonitor(self, filter: android.content.IntentFilter, result: Instrumentation.ActivityResult, block: bool | java.jboolean | java.lang.Boolean, /) -> Instrumentation.ActivityMonitor: ...
    @typing.overload
    def addMonitor(self, cls: str | java.lang.String, result: Instrumentation.ActivityResult, block: bool | java.jboolean | java.lang.Boolean, /) -> Instrumentation.ActivityMonitor: ...
    def addResults(self, results: android.os.Bundle, /) -> None: ...
    @typing.overload
    def callActivityOnCreate(self, activity: Activity, icicle: android.os.Bundle, /) -> None: ...
    @typing.overload
    def callActivityOnCreate(self, activity: Activity, icicle: android.os.Bundle, persistentState: android.os.PersistableBundle, /) -> None: ...
    def callActivityOnDestroy(self, activity: Activity, /) -> None: ...
    @typing.overload
    def callActivityOnNewIntent(self, activity: Activity, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def callActivityOnNewIntent(self, activity: Activity, intent: android.content.Intent, caller: ComponentCaller, /) -> None: ...
    def callActivityOnPause(self, activity: Activity, /) -> None: ...
    def callActivityOnPictureInPictureRequested(self, activity: Activity, /) -> None: ...
    @typing.overload
    def callActivityOnPostCreate(self, activity: Activity, savedInstanceState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def callActivityOnPostCreate(self, activity: Activity, savedInstanceState: android.os.Bundle, persistentState: android.os.PersistableBundle, /) -> None: ...
    def callActivityOnRestart(self, activity: Activity, /) -> None: ...
    @typing.overload
    def callActivityOnRestoreInstanceState(self, activity: Activity, savedInstanceState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def callActivityOnRestoreInstanceState(self, activity: Activity, savedInstanceState: android.os.Bundle, persistentState: android.os.PersistableBundle, /) -> None: ...
    def callActivityOnResume(self, activity: Activity, /) -> None: ...
    @typing.overload
    def callActivityOnSaveInstanceState(self, activity: Activity, outState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def callActivityOnSaveInstanceState(self, activity: Activity, outState: android.os.Bundle, outPersistentState: android.os.PersistableBundle, /) -> None: ...
    def callActivityOnStart(self, activity: Activity, /) -> None: ...
    def callActivityOnStop(self, activity: Activity, /) -> None: ...
    def callActivityOnUserLeaving(self, activity: Activity, /) -> None: ...
    def callApplicationOnCreate(self, app: Application, /) -> None: ...
    def checkMonitorHit(self, monitor: Instrumentation.ActivityMonitor, minHits: int | java.jint | java.lang.Integer, /) -> bool: ...
    def endPerformanceSnapshot(self) -> None: ...
    def finish(self, resultCode: int | java.jint | java.lang.Integer, results: android.os.Bundle, /) -> None: ...
    def getAllocCounts(self) -> android.os.Bundle: ...
    def getBinderCounts(self) -> android.os.Bundle: ...
    def getComponentName(self) -> android.content.ComponentName: ...
    def getContext(self) -> android.content.Context: ...
    def getProcessName(self) -> str: ...
    def getTargetContext(self) -> android.content.Context: ...
    @typing.overload
    def getUiAutomation(self) -> UiAutomation: ...
    @typing.overload
    def getUiAutomation(self, flags: int | java.jint | java.lang.Integer, /) -> UiAutomation: ...
    def invokeContextMenuAction(self, targetActivity: Activity, id: int | java.jint | java.lang.Integer, flag: int | java.jint | java.lang.Integer, /) -> bool: ...
    def invokeMenuActionSync(self, targetActivity: Activity, id: int | java.jint | java.lang.Integer, flag: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isProfiling(self) -> bool: ...
    @typing.overload
    def newActivity(self, cl: java.lang.ClassLoader, className: str | java.lang.String, intent: android.content.Intent, /) -> Activity: ...
    @typing.overload
    def newActivity(self, clazz: typing.Type[java.lang.Object], context: android.content.Context, token: android.os.IBinder, application: Application, intent: android.content.Intent, info: android.content.pm.ActivityInfo, title: java.lang.CharSequence, parent: Activity, id: str | java.lang.String, lastNonConfigurationInstance: java.lang.Object | int | bool | float | str, /) -> Activity: ...
    @typing.overload
    @staticmethod
    def newApplication(clazz: typing.Type[java.lang.Object], context: android.content.Context, /) -> Application: ...
    @typing.overload
    def newApplication(self, cl: java.lang.ClassLoader, className: str | java.lang.String, context: android.content.Context, /) -> Application: ...
    def onCreate(self, arguments: android.os.Bundle, /) -> None: ...
    def onDestroy(self) -> None: ...
    def onException(self, obj: java.lang.Object | int | bool | float | str, e: java.lang.Throwable, /) -> bool: ...
    def onStart(self) -> None: ...
    def removeMonitor(self, monitor: Instrumentation.ActivityMonitor, /) -> None: ...
    def resetInTouchMode(self) -> None: ...
    def runOnMainSync(self, runner: java.lang.Runnable, /) -> None: ...
    def sendCharacterSync(self, keyCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def sendKeyDownUpSync(self, keyCode: int | java.jint | java.lang.Integer, /) -> None: ...
    def sendKeySync(self, event: android.view.KeyEvent, /) -> None: ...
    def sendPointerSync(self, event: android.view.MotionEvent, /) -> None: ...
    def sendStatus(self, resultCode: int | java.jint | java.lang.Integer, results: android.os.Bundle, /) -> None: ...
    def sendStringSync(self, text: str | java.lang.String, /) -> None: ...
    def sendTrackballEventSync(self, event: android.view.MotionEvent, /) -> None: ...
    def setAutomaticPerformanceSnapshots(self) -> None: ...
    def setInTouchMode(self, inTouch: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def start(self) -> None: ...
    @typing.overload
    def startActivitySync(self, intent: android.content.Intent, /) -> Activity: ...
    @typing.overload
    def startActivitySync(self, intent: android.content.Intent, options: android.os.Bundle, /) -> Activity: ...
    def startAllocCounting(self) -> None: ...
    def startPerformanceSnapshot(self) -> None: ...
    def startProfiling(self) -> None: ...
    def stopAllocCounting(self) -> None: ...
    def stopProfiling(self) -> None: ...
    def waitForIdle(self, recipient: java.lang.Runnable, /) -> None: ...
    def waitForIdleSync(self) -> None: ...
    def waitForMonitor(self, monitor: Instrumentation.ActivityMonitor, /) -> Activity: ...
    def waitForMonitorWithTimeout(self, monitor: Instrumentation.ActivityMonitor, timeOut: int | java.jlong | java.lang.Long, /) -> Activity: ...

    class ActivityResult(java.lang.Object):
        def __init__(self, resultCode: int | java.jint | java.lang.Integer, resultData: android.content.Intent, /) -> None: ...
        def getResultCode(self) -> int: ...
        def getResultData(self) -> android.content.Intent: ...

    class ActivityMonitor(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, which: android.content.IntentFilter, result: Instrumentation.ActivityResult, block: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        @typing.overload
        def __init__(self, cls: str | java.lang.String, result: Instrumentation.ActivityResult, block: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def getFilter(self) -> android.content.IntentFilter: ...
        def getHits(self) -> int: ...
        def getLastActivity(self) -> Activity: ...
        def getResult(self) -> Instrumentation.ActivityResult: ...
        def isBlocking(self) -> bool: ...
        def onStartActivity(self, intent: android.content.Intent, /) -> Instrumentation.ActivityResult: ...
        def waitForActivity(self) -> Activity: ...
        def waitForActivityWithTimeout(self, timeOut: int | java.jlong | java.lang.Long, /) -> Activity: ...

class IntentService(Service):
    def __init__(self, name: str | java.lang.String, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder | None: ...
    def onCreate(self) -> None: ...
    def onDestroy(self) -> None: ...
    def onHandleIntent(self, arg1: android.content.Intent, /) -> None: ...
    def onStart(self, intent: android.content.Intent, startId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartCommand(self, intent: android.content.Intent, flags: int | java.jint | java.lang.Integer, startId: int | java.jint | java.lang.Integer, /) -> int: ...
    def setIntentRedelivery(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class InvalidForegroundServiceTypeException(ForegroundServiceTypeException, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[InvalidForegroundServiceTypeException]] = ...
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class KeyguardManager(java.lang.Object):
    def addKeyguardLockedStateListener(self, executor: java.util.concurrent.Executor, listener: KeyguardManager.KeyguardLockedStateListener, /) -> None: ...
    def createConfirmDeviceCredentialIntent(self, title: java.lang.CharSequence, description: java.lang.CharSequence, /) -> android.content.Intent | None: ...
    def exitKeyguardSecurely(self, callback: KeyguardManager.OnKeyguardExitResult, /) -> None: ...
    def inKeyguardRestrictedInputMode(self) -> bool: ...
    def isDeviceLocked(self) -> bool: ...
    def isDeviceSecure(self) -> bool: ...
    def isKeyguardLocked(self) -> bool: ...
    def isKeyguardSecure(self) -> bool: ...
    def newKeyguardLock(self, tag: str | java.lang.String, /) -> KeyguardManager.KeyguardLock: ...
    def removeKeyguardLockedStateListener(self, listener: KeyguardManager.KeyguardLockedStateListener, /) -> None: ...
    def requestDismissKeyguard(self, activity: Activity, callback: KeyguardManager.KeyguardDismissCallback, /) -> None: ...

    class OnKeyguardExitResult(java.lang.Object):
        def onKeyguardExitResult(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class KeyguardLockedStateListener(java.lang.Object):
        def onKeyguardLockedStateChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class KeyguardLock(java.lang.Object):
        def disableKeyguard(self) -> None: ...
        def reenableKeyguard(self) -> None: ...

    class KeyguardDismissCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onDismissCancelled(self) -> None: ...
        def onDismissError(self) -> None: ...
        def onDismissSucceeded(self) -> None: ...

class LauncherActivity(ListActivity):
    def __init__(self) -> None: ...
    def getTargetIntent(self) -> android.content.Intent: ...
    def intentForPosition(self, position: int | java.jint | java.lang.Integer, /) -> android.content.Intent: ...
    def itemForPosition(self, position: int | java.jint | java.lang.Integer, /) -> LauncherActivity.ListItem: ...
    def makeListItems(self) -> java.util.List[LauncherActivity.ListItem]: ...
    def onCreate(self, icicle: android.os.Bundle, /) -> None: ...
    def onListItemClick(self, l: android.widget.ListView, v: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> None: ...
    def onQueryPackageManager(self, queryIntent: android.content.Intent, /) -> java.util.List[android.content.pm.ResolveInfo]: ...
    def onSetContentView(self) -> None: ...
    @typing.overload
    def setTitle(self, titleId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setTitle(self, title: java.lang.CharSequence, /) -> None: ...

    class ListItem(java.lang.Object):
        className: str = ...
        extras: android.os.Bundle = ...
        icon: android.graphics.drawable.Drawable = ...
        label: java.lang.CharSequence = ...
        packageName: str = ...
        resolveInfo: android.content.pm.ResolveInfo = ...
        def __init__(self) -> None: ...

    class IconResizer(java.lang.Object):
        def __init__(self, this_0: LauncherActivity, /) -> None: ...
        def createIconThumbnail(self, icon: android.graphics.drawable.Drawable, /) -> android.graphics.drawable.Drawable: ...

class ListActivity(Activity):
    def __init__(self) -> None: ...
    def getListAdapter(self) -> android.widget.ListAdapter: ...
    def getListView(self) -> android.widget.ListView: ...
    def getSelectedItemId(self) -> int: ...
    def getSelectedItemPosition(self) -> int: ...
    def onContentChanged(self) -> None: ...
    def onDestroy(self) -> None: ...
    def onListItemClick(self, l: android.widget.ListView, v: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Bundle, /) -> None: ...
    def setListAdapter(self, adapter: android.widget.ListAdapter, /) -> None: ...
    def setSelection(self, position: int | java.jint | java.lang.Integer, /) -> None: ...

class ListFragment(Fragment):
    def __init__(self) -> None: ...
    def getListAdapter(self) -> android.widget.ListAdapter: ...
    def getListView(self) -> android.widget.ListView: ...
    def getSelectedItemId(self) -> int: ...
    def getSelectedItemPosition(self) -> int: ...
    def onCreateView(self, inflater: android.view.LayoutInflater, container: android.view.ViewGroup, savedInstanceState: android.os.Bundle, /) -> android.view.View: ...
    def onDestroyView(self) -> None: ...
    def onListItemClick(self, l: android.widget.ListView, v: android.view.View, position: int | java.jint | java.lang.Integer, id: int | java.jlong | java.lang.Long, /) -> None: ...
    def onViewCreated(self, view: android.view.View, savedInstanceState: android.os.Bundle, /) -> None: ...
    def setEmptyText(self, text: java.lang.CharSequence, /) -> None: ...
    def setListAdapter(self, adapter: android.widget.ListAdapter, /) -> None: ...
    def setListShown(self, shown: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setListShownNoAnimation(self, shown: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelection(self, position: int | java.jint | java.lang.Integer, /) -> None: ...


_LoaderManager__LoaderCallbacks__D = typing.TypeVar('_LoaderManager__LoaderCallbacks__D')  # <D>
class LoaderManager(java.lang.Object):
    def __init__(self) -> None: ...
    def destroyLoader(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def dump(self, arg1: str | java.lang.String, arg2: java.io.FileDescriptor, arg3: java.io.PrintWriter, arg4: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @staticmethod
    def enableDebugLogging(enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getLoader(self, arg1: int | java.jint | java.lang.Integer, /) -> android.content.Loader[java.lang.Object]: ...
    _initLoader__D = typing.TypeVar('_initLoader__D')  # <D>
    def initLoader(self, arg1: int | java.jint | java.lang.Integer, arg2: android.os.Bundle, arg3: LoaderManager.LoaderCallbacks[_initLoader__D], /) -> android.content.Loader[_initLoader__D]: ...
    _restartLoader__D = typing.TypeVar('_restartLoader__D')  # <D>
    def restartLoader(self, arg1: int | java.jint | java.lang.Integer, arg2: android.os.Bundle, arg3: LoaderManager.LoaderCallbacks[_restartLoader__D], /) -> android.content.Loader[_restartLoader__D]: ...
    class LoaderCallbacks(java.lang.Object, typing.Generic[_LoaderManager__LoaderCallbacks__D]):
        def onCreateLoader(self, arg1: int | java.jint | java.lang.Integer, arg2: android.os.Bundle, /) -> android.content.Loader[_LoaderManager__LoaderCallbacks__D]: ...
        def onLoadFinished(self, arg1: android.content.Loader[_LoaderManager__LoaderCallbacks__D], arg2: _LoaderManager__LoaderCallbacks__D, /) -> None: ...
        def onLoaderReset(self, arg1: android.content.Loader[_LoaderManager__LoaderCallbacks__D], /) -> None: ...

class LocalActivityManager(java.lang.Object):
    def __init__(self, parent: Activity, singleMode: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def destroyActivity(self, id: str | java.lang.String, finish: bool | java.jboolean | java.lang.Boolean, /) -> android.view.Window | None: ...
    def dispatchCreate(self, state: android.os.Bundle, /) -> None: ...
    def dispatchDestroy(self, finishing: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchPause(self, finishing: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def dispatchResume(self) -> None: ...
    def dispatchStop(self) -> None: ...
    def getActivity(self, id: str | java.lang.String, /) -> Activity | None: ...
    def getCurrentActivity(self) -> Activity | None: ...
    def getCurrentId(self) -> str | None: ...
    def removeAllActivities(self) -> None: ...
    def saveInstanceState(self) -> android.os.Bundle: ...
    def startActivity(self, id: str | java.lang.String, intent: android.content.Intent, /) -> android.view.Window: ...

class LocaleConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[LocaleConfig]] = ...
    STATUS_NOT_SPECIFIED: typing.ClassVar[int] = ...
    STATUS_PARSING_FAILED: typing.ClassVar[int] = ...
    STATUS_SUCCESS: typing.ClassVar[int] = ...
    TAG_LOCALE: typing.ClassVar[str] = ...
    TAG_LOCALE_CONFIG: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, locales: android.os.LocaleList, /) -> None: ...
    def describeContents(self) -> int: ...
    @staticmethod
    def fromContextIgnoringOverride(context: android.content.Context, /) -> LocaleConfig: ...
    def getDefaultLocale(self) -> java.util.Locale | None: ...
    def getStatus(self) -> int: ...
    def getSupportedLocales(self) -> android.os.LocaleList | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LocaleManager(java.lang.Object):
    @typing.overload
    def getApplicationLocales(self) -> android.os.LocaleList: ...
    @typing.overload
    def getApplicationLocales(self, appPackageName: str | java.lang.String, /) -> android.os.LocaleList: ...
    def getOverrideLocaleConfig(self) -> LocaleConfig | None: ...
    def getSystemLocales(self) -> android.os.LocaleList: ...
    def setApplicationLocales(self, locales: android.os.LocaleList, /) -> None: ...
    def setOverrideLocaleConfig(self, localeConfig: LocaleConfig, /) -> None: ...

class MediaRouteActionProvider(android.view.ActionProvider):
    def __init__(self, context: android.content.Context, /) -> None: ...
    def isVisible(self) -> bool: ...
    @typing.overload
    def onCreateActionView(self) -> android.view.View: ...
    @typing.overload
    def onCreateActionView(self, item: android.view.MenuItem, /) -> android.view.View: ...
    def onPerformDefaultAction(self) -> bool: ...
    def overridesItemVisibility(self) -> bool: ...
    def setExtendedSettingsClickListener(self, listener: android.view.View.OnClickListener, /) -> None: ...
    def setRouteTypes(self, types: int | java.jint | java.lang.Integer, /) -> None: ...

class MediaRouteButton(android.view.View):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> None: ...
    def drawableStateChanged(self) -> None: ...
    def getRouteTypes(self) -> int: ...
    def jumpDrawablesToCurrentState(self) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onCreateDrawableState(self, extraSpace: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def onDetachedFromWindow(self) -> None: ...
    def onDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def performClick(self) -> bool: ...
    def setContentDescription(self, contentDescription: java.lang.CharSequence, /) -> None: ...
    def setExtendedSettingsClickListener(self, listener: android.view.View.OnClickListener, /) -> None: ...
    def setRouteTypes(self, types: int | java.jint | java.lang.Integer, /) -> None: ...
    def setVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def showDialog(self) -> None: ...
    def verifyDrawable(self, who: android.graphics.drawable.Drawable, /) -> bool: ...

class MissingForegroundServiceTypeException(ForegroundServiceTypeException, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MissingForegroundServiceTypeException]] = ...
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class NativeActivity(Activity, android.view.InputQueue.Callback, android.view.SurfaceHolder.Callback2, android.view.ViewTreeObserver.OnGlobalLayoutListener):
    META_DATA_FUNC_NAME: typing.ClassVar[str] = ...
    META_DATA_LIB_NAME: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onDestroy(self) -> None: ...
    def onGlobalLayout(self) -> None: ...
    def onInputQueueCreated(self, queue: android.view.InputQueue, /) -> None: ...
    def onInputQueueDestroyed(self, queue: android.view.InputQueue, /) -> None: ...
    def onLowMemory(self) -> None: ...
    def onPause(self) -> None: ...
    def onResume(self) -> None: ...
    def onSaveInstanceState(self, outState: android.os.Bundle, /) -> None: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def onWindowFocusChanged(self, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def surfaceChanged(self, holder: android.view.SurfaceHolder, format: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
    def surfaceCreated(self, holder: android.view.SurfaceHolder, /) -> None: ...
    def surfaceDestroyed(self, holder: android.view.SurfaceHolder, /) -> None: ...
    def surfaceRedrawNeeded(self, holder: android.view.SurfaceHolder, /) -> None: ...

class Notification(android.os.Parcelable):
    AUDIO_ATTRIBUTES_DEFAULT: typing.ClassVar[android.media.AudioAttributes] = ...
    BADGE_ICON_LARGE: typing.ClassVar[int] = ...
    BADGE_ICON_NONE: typing.ClassVar[int] = ...
    BADGE_ICON_SMALL: typing.ClassVar[int] = ...
    CATEGORY_ALARM: typing.ClassVar[str] = ...
    CATEGORY_CALL: typing.ClassVar[str] = ...
    CATEGORY_EMAIL: typing.ClassVar[str] = ...
    CATEGORY_ERROR: typing.ClassVar[str] = ...
    CATEGORY_EVENT: typing.ClassVar[str] = ...
    CATEGORY_LOCATION_SHARING: typing.ClassVar[str] = ...
    CATEGORY_MESSAGE: typing.ClassVar[str] = ...
    CATEGORY_MISSED_CALL: typing.ClassVar[str] = ...
    CATEGORY_NAVIGATION: typing.ClassVar[str] = ...
    CATEGORY_PROGRESS: typing.ClassVar[str] = ...
    CATEGORY_PROMO: typing.ClassVar[str] = ...
    CATEGORY_RECOMMENDATION: typing.ClassVar[str] = ...
    CATEGORY_REMINDER: typing.ClassVar[str] = ...
    CATEGORY_SERVICE: typing.ClassVar[str] = ...
    CATEGORY_SOCIAL: typing.ClassVar[str] = ...
    CATEGORY_STATUS: typing.ClassVar[str] = ...
    CATEGORY_STOPWATCH: typing.ClassVar[str] = ...
    CATEGORY_SYSTEM: typing.ClassVar[str] = ...
    CATEGORY_TRANSPORT: typing.ClassVar[str] = ...
    CATEGORY_VOICEMAIL: typing.ClassVar[str] = ...
    CATEGORY_WORKOUT: typing.ClassVar[str] = ...
    COLOR_DEFAULT: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Notification]] = ...
    DEFAULT_ALL: typing.ClassVar[int] = ...
    DEFAULT_LIGHTS: typing.ClassVar[int] = ...
    DEFAULT_SOUND: typing.ClassVar[int] = ...
    DEFAULT_VIBRATE: typing.ClassVar[int] = ...
    EXTRA_ANSWER_COLOR: typing.ClassVar[str] = ...
    EXTRA_ANSWER_INTENT: typing.ClassVar[str] = ...
    EXTRA_AUDIO_CONTENTS_URI: typing.ClassVar[str] = ...
    EXTRA_BACKGROUND_IMAGE_URI: typing.ClassVar[str] = ...
    EXTRA_BIG_TEXT: typing.ClassVar[str] = ...
    EXTRA_CALL_IS_VIDEO: typing.ClassVar[str] = ...
    EXTRA_CALL_PERSON: typing.ClassVar[str] = ...
    EXTRA_CALL_TYPE: typing.ClassVar[str] = ...
    EXTRA_CHANNEL_GROUP_ID: typing.ClassVar[str] = ...
    EXTRA_CHANNEL_ID: typing.ClassVar[str] = ...
    EXTRA_CHRONOMETER_COUNT_DOWN: typing.ClassVar[str] = ...
    EXTRA_COLORIZED: typing.ClassVar[str] = ...
    EXTRA_COMPACT_ACTIONS: typing.ClassVar[str] = ...
    EXTRA_CONVERSATION_TITLE: typing.ClassVar[str] = ...
    EXTRA_DECLINE_COLOR: typing.ClassVar[str] = ...
    EXTRA_DECLINE_INTENT: typing.ClassVar[str] = ...
    EXTRA_HANG_UP_INTENT: typing.ClassVar[str] = ...
    EXTRA_HISTORIC_MESSAGES: typing.ClassVar[str] = ...
    EXTRA_INFO_TEXT: typing.ClassVar[str] = ...
    EXTRA_IS_GROUP_CONVERSATION: typing.ClassVar[str] = ...
    EXTRA_LARGE_ICON: typing.ClassVar[str] = ...
    EXTRA_LARGE_ICON_BIG: typing.ClassVar[str] = ...
    EXTRA_MEDIA_SESSION: typing.ClassVar[str] = ...
    EXTRA_MESSAGES: typing.ClassVar[str] = ...
    EXTRA_MESSAGING_PERSON: typing.ClassVar[str] = ...
    EXTRA_NOTIFICATION_ID: typing.ClassVar[str] = ...
    EXTRA_NOTIFICATION_TAG: typing.ClassVar[str] = ...
    EXTRA_PEOPLE: typing.ClassVar[str] = ...
    EXTRA_PEOPLE_LIST: typing.ClassVar[str] = ...
    EXTRA_PICTURE: typing.ClassVar[str] = ...
    EXTRA_PICTURE_CONTENT_DESCRIPTION: typing.ClassVar[str] = ...
    EXTRA_PICTURE_ICON: typing.ClassVar[str] = ...
    EXTRA_PROGRESS: typing.ClassVar[str] = ...
    EXTRA_PROGRESS_INDETERMINATE: typing.ClassVar[str] = ...
    EXTRA_PROGRESS_MAX: typing.ClassVar[str] = ...
    EXTRA_REMOTE_INPUT_DRAFT: typing.ClassVar[str] = ...
    EXTRA_REMOTE_INPUT_HISTORY: typing.ClassVar[str] = ...
    EXTRA_SELF_DISPLAY_NAME: typing.ClassVar[str] = ...
    EXTRA_SHOW_BIG_PICTURE_WHEN_COLLAPSED: typing.ClassVar[str] = ...
    EXTRA_SHOW_CHRONOMETER: typing.ClassVar[str] = ...
    EXTRA_SHOW_WHEN: typing.ClassVar[str] = ...
    EXTRA_SMALL_ICON: typing.ClassVar[str] = ...
    EXTRA_SUB_TEXT: typing.ClassVar[str] = ...
    EXTRA_SUMMARY_TEXT: typing.ClassVar[str] = ...
    EXTRA_TEMPLATE: typing.ClassVar[str] = ...
    EXTRA_TEXT: typing.ClassVar[str] = ...
    EXTRA_TEXT_LINES: typing.ClassVar[str] = ...
    EXTRA_TITLE: typing.ClassVar[str] = ...
    EXTRA_TITLE_BIG: typing.ClassVar[str] = ...
    EXTRA_VERIFICATION_ICON: typing.ClassVar[str] = ...
    EXTRA_VERIFICATION_TEXT: typing.ClassVar[str] = ...
    FLAG_AUTO_CANCEL: typing.ClassVar[int] = ...
    FLAG_BUBBLE: typing.ClassVar[int] = ...
    FLAG_FOREGROUND_SERVICE: typing.ClassVar[int] = ...
    FLAG_GROUP_SUMMARY: typing.ClassVar[int] = ...
    FLAG_HIGH_PRIORITY: typing.ClassVar[int] = ...
    FLAG_INSISTENT: typing.ClassVar[int] = ...
    FLAG_LOCAL_ONLY: typing.ClassVar[int] = ...
    FLAG_NO_CLEAR: typing.ClassVar[int] = ...
    FLAG_ONGOING_EVENT: typing.ClassVar[int] = ...
    FLAG_ONLY_ALERT_ONCE: typing.ClassVar[int] = ...
    FLAG_PROMOTED_ONGOING: typing.ClassVar[int] = ...
    FLAG_SHOW_LIGHTS: typing.ClassVar[int] = ...
    FOREGROUND_SERVICE_DEFAULT: typing.ClassVar[int] = ...
    FOREGROUND_SERVICE_DEFERRED: typing.ClassVar[int] = ...
    FOREGROUND_SERVICE_IMMEDIATE: typing.ClassVar[int] = ...
    GROUP_ALERT_ALL: typing.ClassVar[int] = ...
    GROUP_ALERT_CHILDREN: typing.ClassVar[int] = ...
    GROUP_ALERT_SUMMARY: typing.ClassVar[int] = ...
    INTENT_CATEGORY_NOTIFICATION_PREFERENCES: typing.ClassVar[str] = ...
    PRIORITY_DEFAULT: typing.ClassVar[int] = ...
    PRIORITY_HIGH: typing.ClassVar[int] = ...
    PRIORITY_LOW: typing.ClassVar[int] = ...
    PRIORITY_MAX: typing.ClassVar[int] = ...
    PRIORITY_MIN: typing.ClassVar[int] = ...
    STREAM_DEFAULT: typing.ClassVar[int] = ...
    VISIBILITY_PRIVATE: typing.ClassVar[int] = ...
    VISIBILITY_PUBLIC: typing.ClassVar[int] = ...
    VISIBILITY_SECRET: typing.ClassVar[int] = ...
    actions: java.chaquopy.JavaArray[Notification.Action] = ...
    audioAttributes: android.media.AudioAttributes = ...
    audioStreamType: int = ...
    bigContentView: android.widget.RemoteViews = ...
    category: str = ...
    color: int = ...
    contentIntent: PendingIntent = ...
    contentView: android.widget.RemoteViews = ...
    defaults: int = ...
    deleteIntent: PendingIntent = ...
    extras: android.os.Bundle = ...
    flags: int = ...
    fullScreenIntent: PendingIntent = ...
    headsUpContentView: android.widget.RemoteViews = ...
    icon: int = ...
    iconLevel: int = ...
    largeIcon: android.graphics.Bitmap = ...
    ledARGB: int = ...
    ledOffMS: int = ...
    ledOnMS: int = ...
    number: int = ...
    priority: int = ...
    publicVersion: Notification = ...
    sound: android.net.Uri = ...
    tickerText: java.lang.CharSequence = ...
    tickerView: android.widget.RemoteViews = ...
    vibrate: java.chaquopy.JavaArrayJLong = ...
    visibility: int = ...
    when: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, parcel: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, icon: int | java.jint | java.lang.Integer, tickerText: java.lang.CharSequence, when: int | java.jlong | java.lang.Long, /) -> None: ...
    def clone(self) -> Notification: ...
    def describeContents(self) -> int: ...
    def findRemoteInputActionPair(self, requiresFreeform: bool | java.jboolean | java.lang.Boolean, /) -> android.util.Pair[RemoteInput, Notification.Action] | None: ...
    def getAllowSystemGeneratedContextualActions(self) -> bool: ...
    def getBadgeIconType(self) -> int: ...
    def getBubbleMetadata(self) -> Notification.BubbleMetadata | None: ...
    def getChannelId(self) -> str | None: ...
    def getContextualActions(self) -> java.util.List[Notification.Action]: ...
    def getGroup(self) -> str: ...
    def getGroupAlertBehavior(self) -> int: ...
    def getLargeIcon(self) -> android.graphics.drawable.Icon: ...
    def getLocusId(self) -> android.content.LocusId | None: ...
    def getSettingsText(self) -> java.lang.CharSequence: ...
    def getShortCriticalText(self) -> str: ...
    def getShortcutId(self) -> str | None: ...
    def getSmallIcon(self) -> android.graphics.drawable.Icon: ...
    def getSortKey(self) -> str: ...
    def getTimeoutAfter(self) -> int: ...
    def hasImage(self) -> bool: ...
    def hasPromotableCharacteristics(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class WearableExtender(Notification.Extender):
        SCREEN_TIMEOUT_LONG: typing.ClassVar[int] = ...
        SCREEN_TIMEOUT_SHORT: typing.ClassVar[int] = ...
        SIZE_DEFAULT: typing.ClassVar[int] = ...
        SIZE_FULL_SCREEN: typing.ClassVar[int] = ...
        SIZE_LARGE: typing.ClassVar[int] = ...
        SIZE_MEDIUM: typing.ClassVar[int] = ...
        SIZE_SMALL: typing.ClassVar[int] = ...
        SIZE_XSMALL: typing.ClassVar[int] = ...
        UNSET_ACTION_INDEX: typing.ClassVar[int] = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, notif: Notification, /) -> None: ...
        def addAction(self, action: Notification.Action, /) -> Notification.WearableExtender: ...
        def addActions(self, actions: java.util.List[Notification.Action], /) -> Notification.WearableExtender: ...
        def addPage(self, page: Notification, /) -> Notification.WearableExtender: ...
        def addPages(self, pages: java.util.List[Notification], /) -> Notification.WearableExtender: ...
        def clearActions(self) -> Notification.WearableExtender: ...
        def clearPages(self) -> Notification.WearableExtender: ...
        def clone(self) -> Notification.WearableExtender: ...
        def extend(self, builder: Notification.Builder, /) -> Notification.Builder: ...
        def getActions(self) -> java.util.List[Notification.Action]: ...
        def getBridgeTag(self) -> str: ...
        def getContentAction(self) -> int: ...
        def getContentIcon(self) -> int: ...
        def getContentIconGravity(self) -> int: ...
        def getContentIntentAvailableOffline(self) -> bool: ...
        def getCustomContentHeight(self) -> int: ...
        def getCustomSizePreset(self) -> int: ...
        def getDismissalId(self) -> str: ...
        def getDisplayIntent(self) -> PendingIntent: ...
        def getGravity(self) -> int: ...
        def getHintAmbientBigPicture(self) -> bool: ...
        def getHintAvoidBackgroundClipping(self) -> bool: ...
        def getHintContentIntentLaunchesActivity(self) -> bool: ...
        def getHintHideIcon(self) -> bool: ...
        def getHintScreenTimeout(self) -> int: ...
        def getHintShowBackgroundOnly(self) -> bool: ...
        def getPages(self) -> java.util.List[Notification]: ...
        def getStartScrollBottom(self) -> bool: ...
        def setBridgeTag(self, bridgeTag: str | java.lang.String, /) -> Notification.WearableExtender: ...
        def setContentAction(self, actionIndex: int | java.jint | java.lang.Integer, /) -> Notification.WearableExtender: ...
        def setContentIcon(self, icon: int | java.jint | java.lang.Integer, /) -> Notification.WearableExtender: ...
        def setContentIconGravity(self, contentIconGravity: int | java.jint | java.lang.Integer, /) -> Notification.WearableExtender: ...
        def setContentIntentAvailableOffline(self, contentIntentAvailableOffline: bool | java.jboolean | java.lang.Boolean, /) -> Notification.WearableExtender: ...
        def setCustomContentHeight(self, height: int | java.jint | java.lang.Integer, /) -> Notification.WearableExtender: ...
        def setCustomSizePreset(self, sizePreset: int | java.jint | java.lang.Integer, /) -> Notification.WearableExtender: ...
        def setDismissalId(self, dismissalId: str | java.lang.String, /) -> Notification.WearableExtender: ...
        def setDisplayIntent(self, intent: PendingIntent, /) -> Notification.WearableExtender: ...
        def setGravity(self, gravity: int | java.jint | java.lang.Integer, /) -> Notification.WearableExtender: ...
        def setHintAmbientBigPicture(self, hintAmbientBigPicture: bool | java.jboolean | java.lang.Boolean, /) -> Notification.WearableExtender: ...
        def setHintAvoidBackgroundClipping(self, hintAvoidBackgroundClipping: bool | java.jboolean | java.lang.Boolean, /) -> Notification.WearableExtender: ...
        def setHintContentIntentLaunchesActivity(self, hintContentIntentLaunchesActivity: bool | java.jboolean | java.lang.Boolean, /) -> Notification.WearableExtender: ...
        def setHintHideIcon(self, hintHideIcon: bool | java.jboolean | java.lang.Boolean, /) -> Notification.WearableExtender: ...
        def setHintScreenTimeout(self, timeout: int | java.jint | java.lang.Integer, /) -> Notification.WearableExtender: ...
        def setHintShowBackgroundOnly(self, hintShowBackgroundOnly: bool | java.jboolean | java.lang.Boolean, /) -> Notification.WearableExtender: ...
        def setStartScrollBottom(self, startScrollBottom: bool | java.jboolean | java.lang.Boolean, /) -> Notification.WearableExtender: ...

    class TvExtender(Notification.Extender):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, notif: Notification, /) -> None: ...
        def extend(self, builder: Notification.Builder, /) -> Notification.Builder: ...
        def getChannelId(self) -> str: ...
        def getContentIntent(self) -> PendingIntent: ...
        def getDeleteIntent(self) -> PendingIntent: ...
        def isAvailableOnTv(self) -> bool: ...
        def isSuppressShowOverApps(self) -> bool: ...
        def setChannelId(self, channelId: str | java.lang.String, /) -> Notification.TvExtender: ...
        def setContentIntent(self, intent: PendingIntent, /) -> Notification.TvExtender: ...
        def setDeleteIntent(self, intent: PendingIntent, /) -> Notification.TvExtender: ...
        def setSuppressShowOverApps(self, suppress: bool | java.jboolean | java.lang.Boolean, /) -> Notification.TvExtender: ...

    class Style(java.lang.Object):
        mBuilder: Notification.Builder = ...
        def __init__(self) -> None: ...
        def build(self) -> Notification: ...
        def checkBuilder(self) -> None: ...
        def getStandardView(self, layoutId: int | java.jint | java.lang.Integer, /) -> android.widget.RemoteViews: ...
        def internalSetBigContentTitle(self, title: java.lang.CharSequence, /) -> None: ...
        def internalSetSummaryText(self, cs: java.lang.CharSequence, /) -> None: ...
        def setBuilder(self, builder: Notification.Builder, /) -> None: ...

    class ProgressStyle(Notification.Style):
        def __init__(self) -> None: ...
        def addProgressPoint(self, point: Notification.ProgressStyle.Point, /) -> Notification.ProgressStyle: ...
        def addProgressSegment(self, segment: Notification.ProgressStyle.Segment, /) -> Notification.ProgressStyle: ...
        def getProgress(self) -> int: ...
        def getProgressEndIcon(self) -> android.graphics.drawable.Icon: ...
        def getProgressMax(self) -> int: ...
        def getProgressPoints(self) -> java.util.List[Notification.ProgressStyle.Point]: ...
        def getProgressSegments(self) -> java.util.List[Notification.ProgressStyle.Segment]: ...
        def getProgressStartIcon(self) -> android.graphics.drawable.Icon: ...
        def getProgressTrackerIcon(self) -> android.graphics.drawable.Icon: ...
        def isProgressIndeterminate(self) -> bool: ...
        def isStyledByProgress(self) -> bool: ...
        def setProgress(self, progress: int | java.jint | java.lang.Integer, /) -> Notification.ProgressStyle: ...
        def setProgressEndIcon(self, endIcon: android.graphics.drawable.Icon, /) -> Notification.ProgressStyle: ...
        def setProgressIndeterminate(self, indeterminate: bool | java.jboolean | java.lang.Boolean, /) -> Notification.ProgressStyle: ...
        def setProgressPoints(self, points: java.util.List[Notification.ProgressStyle.Point], /) -> Notification.ProgressStyle: ...
        def setProgressSegments(self, progressSegments: java.util.List[Notification.ProgressStyle.Segment], /) -> Notification.ProgressStyle: ...
        def setProgressStartIcon(self, startIcon: android.graphics.drawable.Icon, /) -> Notification.ProgressStyle: ...
        def setProgressTrackerIcon(self, trackerIcon: android.graphics.drawable.Icon, /) -> Notification.ProgressStyle: ...
        def setStyledByProgress(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> Notification.ProgressStyle: ...

        class Segment(java.lang.Object):
            def __init__(self, length: int | java.jint | java.lang.Integer, /) -> None: ...
            def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
            def getColor(self) -> int: ...
            def getId(self) -> int: ...
            def getLength(self) -> int: ...
            def hashCode(self) -> int: ...
            def setColor(self, color: int | java.jint | java.lang.Integer, /) -> Notification.ProgressStyle.Segment: ...
            def setId(self, id: int | java.jint | java.lang.Integer, /) -> Notification.ProgressStyle.Segment: ...

        class Point(java.lang.Object):
            def __init__(self, position: int | java.jint | java.lang.Integer, /) -> None: ...
            def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
            def getColor(self) -> int: ...
            def getId(self) -> int: ...
            def getPosition(self) -> int: ...
            def hashCode(self) -> int: ...
            def setColor(self, color: int | java.jint | java.lang.Integer, /) -> Notification.ProgressStyle.Point: ...
            def setId(self, id: int | java.jint | java.lang.Integer, /) -> Notification.ProgressStyle.Point: ...

    class MessagingStyle(Notification.Style):
        MAXIMUM_RETAINED_MESSAGES: typing.ClassVar[int] = ...
        @typing.overload
        def __init__(self, user: Person, /) -> None: ...
        @typing.overload
        def __init__(self, userDisplayName: java.lang.CharSequence, /) -> None: ...
        def addHistoricMessage(self, message: Notification.MessagingStyle.Message, /) -> Notification.MessagingStyle: ...
        @typing.overload
        def addMessage(self, message: Notification.MessagingStyle.Message, /) -> Notification.MessagingStyle: ...
        @typing.overload
        def addMessage(self, text: java.lang.CharSequence, timestamp: int | java.jlong | java.lang.Long, sender: Person, /) -> Notification.MessagingStyle: ...
        @typing.overload
        def addMessage(self, text: java.lang.CharSequence, timestamp: int | java.jlong | java.lang.Long, sender: java.lang.CharSequence, /) -> Notification.MessagingStyle: ...
        def getConversationTitle(self) -> java.lang.CharSequence: ...
        def getHistoricMessages(self) -> java.util.List[Notification.MessagingStyle.Message]: ...
        def getMessages(self) -> java.util.List[Notification.MessagingStyle.Message]: ...
        def getUser(self) -> Person: ...
        def getUserDisplayName(self) -> java.lang.CharSequence: ...
        def isGroupConversation(self) -> bool: ...
        def setConversationTitle(self, conversationTitle: java.lang.CharSequence, /) -> Notification.MessagingStyle: ...
        def setGroupConversation(self, isGroupConversation: bool | java.jboolean | java.lang.Boolean, /) -> Notification.MessagingStyle: ...

        class Message(java.lang.Object):
            @typing.overload
            def __init__(self, text: java.lang.CharSequence, timestamp: int | java.jlong | java.lang.Long, sender: Person, /) -> None: ...
            @typing.overload
            def __init__(self, text: java.lang.CharSequence, timestamp: int | java.jlong | java.lang.Long, sender: java.lang.CharSequence, /) -> None: ...
            def getDataMimeType(self) -> str: ...
            def getDataUri(self) -> android.net.Uri: ...
            def getExtras(self) -> android.os.Bundle: ...
            @staticmethod
            def getMessagesFromBundleArray(bundles: java.chaquopy.JavaArray[android.os.Parcelable], /) -> java.util.List[Notification.MessagingStyle.Message]: ...
            def getSender(self) -> java.lang.CharSequence: ...
            def getSenderPerson(self) -> Person: ...
            def getText(self) -> java.lang.CharSequence: ...
            def getTimestamp(self) -> int: ...
            def setData(self, dataMimeType: str | java.lang.String, dataUri: android.net.Uri, /) -> Notification.MessagingStyle.Message: ...

    class MediaStyle(Notification.Style):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, builder: Notification.Builder, /) -> None: ...
        def setMediaSession(self, token: android.media.session.MediaSession.Token, /) -> Notification.MediaStyle: ...
        def setRemotePlaybackInfo(self, deviceName: java.lang.CharSequence, iconResource: int | java.jint | java.lang.Integer, chipIntent: PendingIntent, /) -> Notification.MediaStyle: ...
        def setShowActionsInCompactView(self, *actions: java.jint) -> Notification.MediaStyle: ...

    class InboxStyle(Notification.Style):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, builder: Notification.Builder, /) -> None: ...
        def addLine(self, cs: java.lang.CharSequence, /) -> Notification.InboxStyle: ...
        def setBigContentTitle(self, title: java.lang.CharSequence, /) -> Notification.InboxStyle: ...
        def setSummaryText(self, cs: java.lang.CharSequence, /) -> Notification.InboxStyle: ...

    class Extender(java.lang.Object):
        def extend(self, arg1: Notification.Builder, /) -> Notification.Builder: ...

    class DecoratedMediaCustomViewStyle(Notification.MediaStyle):
        def __init__(self) -> None: ...

    class DecoratedCustomViewStyle(Notification.Style):
        def __init__(self) -> None: ...

    class CarExtender(Notification.Extender):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, notif: Notification, /) -> None: ...
        def extend(self, builder: Notification.Builder, /) -> Notification.Builder: ...
        def getColor(self) -> int: ...
        def getLargeIcon(self) -> android.graphics.Bitmap: ...
        def getUnreadConversation(self) -> Notification.CarExtender.UnreadConversation: ...
        def setColor(self, color: int | java.jint | java.lang.Integer, /) -> Notification.CarExtender: ...
        def setLargeIcon(self, largeIcon: android.graphics.Bitmap, /) -> Notification.CarExtender: ...
        def setUnreadConversation(self, unreadConversation: Notification.CarExtender.UnreadConversation, /) -> Notification.CarExtender: ...

        class UnreadConversation(java.lang.Object):
            def getLatestTimestamp(self) -> int: ...
            def getMessages(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
            def getParticipant(self) -> str: ...
            def getParticipants(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
            def getReadPendingIntent(self) -> PendingIntent: ...
            def getRemoteInput(self) -> RemoteInput: ...
            def getReplyPendingIntent(self) -> PendingIntent: ...

        class Builder(java.lang.Object):
            def __init__(self, name: str | java.lang.String, /) -> None: ...
            def addMessage(self, message: str | java.lang.String, /) -> Notification.CarExtender.Builder: ...
            def build(self) -> Notification.CarExtender.UnreadConversation: ...
            def setLatestTimestamp(self, timestamp: int | java.jlong | java.lang.Long, /) -> Notification.CarExtender.Builder: ...
            def setReadPendingIntent(self, pendingIntent: PendingIntent, /) -> Notification.CarExtender.Builder: ...
            def setReplyAction(self, pendingIntent: PendingIntent, remoteInput: RemoteInput, /) -> Notification.CarExtender.Builder: ...

    class CallStyle(Notification.Style):
        CALL_TYPE_INCOMING: typing.ClassVar[int] = ...
        CALL_TYPE_ONGOING: typing.ClassVar[int] = ...
        CALL_TYPE_SCREENING: typing.ClassVar[int] = ...
        CALL_TYPE_UNKNOWN: typing.ClassVar[int] = ...
        @staticmethod
        def forIncomingCall(person: Person, declineIntent: PendingIntent, answerIntent: PendingIntent, /) -> Notification.CallStyle: ...
        @staticmethod
        def forOngoingCall(person: Person, hangUpIntent: PendingIntent, /) -> Notification.CallStyle: ...
        @staticmethod
        def forScreeningCall(person: Person, hangUpIntent: PendingIntent, answerIntent: PendingIntent, /) -> Notification.CallStyle: ...
        def setAnswerButtonColorHint(self, color: int | java.jint | java.lang.Integer, /) -> Notification.CallStyle: ...
        def setDeclineButtonColorHint(self, color: int | java.jint | java.lang.Integer, /) -> Notification.CallStyle: ...
        def setIsVideo(self, isVideo: bool | java.jboolean | java.lang.Boolean, /) -> Notification.CallStyle: ...
        def setVerificationIcon(self, verificationIcon: android.graphics.drawable.Icon, /) -> Notification.CallStyle: ...
        def setVerificationText(self, verificationText: java.lang.CharSequence, /) -> Notification.CallStyle: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, context: android.content.Context, /) -> None: ...
        @typing.overload
        def __init__(self, context: android.content.Context, channelId: str | java.lang.String, /) -> None: ...
        @typing.overload
        def addAction(self, action: Notification.Action, /) -> Notification.Builder: ...
        @typing.overload
        def addAction(self, icon: int | java.jint | java.lang.Integer, title: java.lang.CharSequence, intent: PendingIntent, /) -> Notification.Builder: ...
        def addExtras(self, extras: android.os.Bundle, /) -> Notification.Builder: ...
        @typing.overload
        def addPerson(self, person: Person, /) -> Notification.Builder: ...
        @typing.overload
        def addPerson(self, uri: str | java.lang.String, /) -> Notification.Builder: ...
        def build(self) -> Notification: ...
        def createBigContentView(self) -> android.widget.RemoteViews: ...
        def createContentView(self) -> android.widget.RemoteViews: ...
        def createHeadsUpContentView(self) -> android.widget.RemoteViews: ...
        def extend(self, extender: Notification.Extender, /) -> Notification.Builder: ...
        def getExtras(self) -> android.os.Bundle: ...
        def getNotification(self) -> Notification: ...
        def getStyle(self) -> Notification.Style: ...
        @staticmethod
        def recoverBuilder(context: android.content.Context, n: Notification, /) -> Notification.Builder: ...
        def setActions(self, *actions: Notification.Action) -> Notification.Builder: ...
        def setAllowSystemGeneratedContextualActions(self, allowed: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setAutoCancel(self, autoCancel: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setBadgeIconType(self, icon: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setBubbleMetadata(self, data: Notification.BubbleMetadata, /) -> Notification.Builder: ...
        def setCategory(self, category: str | java.lang.String, /) -> Notification.Builder: ...
        def setChannelId(self, channelId: str | java.lang.String, /) -> Notification.Builder: ...
        def setChronometerCountDown(self, countDown: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setColor(self, argb: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setColorized(self, colorize: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setContent(self, views: android.widget.RemoteViews, /) -> Notification.Builder: ...
        def setContentInfo(self, info: java.lang.CharSequence, /) -> Notification.Builder: ...
        def setContentIntent(self, intent: PendingIntent, /) -> Notification.Builder: ...
        def setContentText(self, text: java.lang.CharSequence, /) -> Notification.Builder: ...
        def setContentTitle(self, title: java.lang.CharSequence, /) -> Notification.Builder: ...
        def setCustomBigContentView(self, contentView: android.widget.RemoteViews, /) -> Notification.Builder: ...
        def setCustomContentView(self, contentView: android.widget.RemoteViews, /) -> Notification.Builder: ...
        def setCustomHeadsUpContentView(self, contentView: android.widget.RemoteViews, /) -> Notification.Builder: ...
        def setDefaults(self, defaults: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setDeleteIntent(self, intent: PendingIntent, /) -> Notification.Builder: ...
        def setExtras(self, extras: android.os.Bundle, /) -> Notification.Builder: ...
        def setFlag(self, mask: int | java.jint | java.lang.Integer, value: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setForegroundServiceBehavior(self, behavior: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setFullScreenIntent(self, intent: PendingIntent, highPriority: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setGroup(self, groupKey: str | java.lang.String, /) -> Notification.Builder: ...
        def setGroupAlertBehavior(self, groupAlertBehavior: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setGroupSummary(self, isGroupSummary: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        @typing.overload
        def setLargeIcon(self, b: android.graphics.Bitmap, /) -> Notification.Builder: ...
        @typing.overload
        def setLargeIcon(self, icon: android.graphics.drawable.Icon, /) -> Notification.Builder: ...
        def setLights(self, argb: int | java.jint | java.lang.Integer, onMs: int | java.jint | java.lang.Integer, offMs: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setLocalOnly(self, localOnly: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setLocusId(self, locusId: android.content.LocusId, /) -> Notification.Builder: ...
        def setNumber(self, number: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setOngoing(self, ongoing: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setOnlyAlertOnce(self, onlyAlertOnce: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setPriority(self, pri: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setProgress(self, max: int | java.jint | java.lang.Integer, progress: int | java.jint | java.lang.Integer, indeterminate: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setPublicVersion(self, n: Notification, /) -> Notification.Builder: ...
        def setRemoteInputHistory(self, text: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> Notification.Builder: ...
        def setSettingsText(self, text: java.lang.CharSequence, /) -> Notification.Builder: ...
        def setShortCriticalText(self, shortCriticalText: str | java.lang.String, /) -> Notification.Builder: ...
        def setShortcutId(self, shortcutId: str | java.lang.String, /) -> Notification.Builder: ...
        def setShowWhen(self, show: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        @typing.overload
        def setSmallIcon(self, icon: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        @typing.overload
        def setSmallIcon(self, icon: android.graphics.drawable.Icon, /) -> Notification.Builder: ...
        @typing.overload
        def setSmallIcon(self, icon: int | java.jint | java.lang.Integer, level: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setSortKey(self, sortKey: str | java.lang.String, /) -> Notification.Builder: ...
        @typing.overload
        def setSound(self, sound: android.net.Uri, /) -> Notification.Builder: ...
        @typing.overload
        def setSound(self, sound: android.net.Uri, streamType: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        @typing.overload
        def setSound(self, sound: android.net.Uri, audioAttributes: android.media.AudioAttributes, /) -> Notification.Builder: ...
        def setStyle(self, style: Notification.Style, /) -> Notification.Builder: ...
        def setSubText(self, text: java.lang.CharSequence, /) -> Notification.Builder: ...
        @typing.overload
        def setTicker(self, tickerText: java.lang.CharSequence, /) -> Notification.Builder: ...
        @typing.overload
        def setTicker(self, tickerText: java.lang.CharSequence, views: android.widget.RemoteViews, /) -> Notification.Builder: ...
        def setTimeoutAfter(self, durationMs: int | java.jlong | java.lang.Long, /) -> Notification.Builder: ...
        def setUsesChronometer(self, b: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Builder: ...
        def setVibrate(self, pattern: java.chaquopy.JavaArrayJLong, /) -> Notification.Builder: ...
        def setVisibility(self, visibility: int | java.jint | java.lang.Integer, /) -> Notification.Builder: ...
        def setWhen(self, when: int | java.jlong | java.lang.Long, /) -> Notification.Builder: ...

    class BubbleMetadata(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Notification.BubbleMetadata]] = ...
        def describeContents(self) -> int: ...
        def getAutoExpandBubble(self) -> bool: ...
        def getDeleteIntent(self) -> PendingIntent: ...
        def getDesiredHeight(self) -> int: ...
        def getDesiredHeightResId(self) -> int: ...
        def getIcon(self) -> android.graphics.drawable.Icon: ...
        def getIntent(self) -> PendingIntent: ...
        def getShortcutId(self) -> str: ...
        def isBubbleSuppressable(self) -> bool: ...
        def isBubbleSuppressed(self) -> bool: ...
        def isNotificationSuppressed(self) -> bool: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

        class Builder(java.lang.Object):
            @typing.overload
            def __init__(self) -> None: ...
            @typing.overload
            def __init__(self, shortcutId: str | java.lang.String, /) -> None: ...
            @typing.overload
            def __init__(self, intent: PendingIntent, icon: android.graphics.drawable.Icon, /) -> None: ...
            def build(self) -> Notification.BubbleMetadata: ...
            def setAutoExpandBubble(self, shouldExpand: bool | java.jboolean | java.lang.Boolean, /) -> Notification.BubbleMetadata.Builder: ...
            def setDeleteIntent(self, deleteIntent: PendingIntent, /) -> Notification.BubbleMetadata.Builder: ...
            def setDesiredHeight(self, height: int | java.jint | java.lang.Integer, /) -> Notification.BubbleMetadata.Builder: ...
            def setDesiredHeightResId(self, heightResId: int | java.jint | java.lang.Integer, /) -> Notification.BubbleMetadata.Builder: ...
            def setIcon(self, icon: android.graphics.drawable.Icon, /) -> Notification.BubbleMetadata.Builder: ...
            def setIntent(self, intent: PendingIntent, /) -> Notification.BubbleMetadata.Builder: ...
            def setSuppressNotification(self, shouldSuppressNotif: bool | java.jboolean | java.lang.Boolean, /) -> Notification.BubbleMetadata.Builder: ...
            def setSuppressableBubble(self, suppressBubble: bool | java.jboolean | java.lang.Boolean, /) -> Notification.BubbleMetadata.Builder: ...

    class BigTextStyle(Notification.Style):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, builder: Notification.Builder, /) -> None: ...
        def bigText(self, cs: java.lang.CharSequence, /) -> Notification.BigTextStyle: ...
        def setBigContentTitle(self, title: java.lang.CharSequence, /) -> Notification.BigTextStyle: ...
        def setSummaryText(self, cs: java.lang.CharSequence, /) -> Notification.BigTextStyle: ...

    class BigPictureStyle(Notification.Style):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, builder: Notification.Builder, /) -> None: ...
        @typing.overload
        def bigLargeIcon(self, b: android.graphics.Bitmap, /) -> Notification.BigPictureStyle: ...
        @typing.overload
        def bigLargeIcon(self, icon: android.graphics.drawable.Icon, /) -> Notification.BigPictureStyle: ...
        @typing.overload
        def bigPicture(self, b: android.graphics.Bitmap, /) -> Notification.BigPictureStyle: ...
        @typing.overload
        def bigPicture(self, icon: android.graphics.drawable.Icon, /) -> Notification.BigPictureStyle: ...
        def setBigContentTitle(self, title: java.lang.CharSequence, /) -> Notification.BigPictureStyle: ...
        def setContentDescription(self, contentDescription: java.lang.CharSequence, /) -> Notification.BigPictureStyle: ...
        def setSummaryText(self, cs: java.lang.CharSequence, /) -> Notification.BigPictureStyle: ...
        def showBigPictureWhenCollapsed(self, show: bool | java.jboolean | java.lang.Boolean, /) -> Notification.BigPictureStyle: ...

    class Action(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Notification.Action]] = ...
        SEMANTIC_ACTION_ARCHIVE: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_CALL: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_DELETE: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_MARK_AS_READ: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_MARK_AS_UNREAD: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_MUTE: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_NONE: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_REPLY: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_THUMBS_DOWN: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_THUMBS_UP: typing.ClassVar[int] = ...
        SEMANTIC_ACTION_UNMUTE: typing.ClassVar[int] = ...
        actionIntent: PendingIntent = ...
        icon: int = ...
        title: java.lang.CharSequence = ...
        def __init__(self, icon: int | java.jint | java.lang.Integer, title: java.lang.CharSequence, intent: PendingIntent, /) -> None: ...
        def clone(self) -> Notification.Action: ...
        def describeContents(self) -> int: ...
        def getAllowGeneratedReplies(self) -> bool: ...
        def getDataOnlyRemoteInputs(self) -> java.chaquopy.JavaArray[RemoteInput]: ...
        def getExtras(self) -> android.os.Bundle: ...
        def getIcon(self) -> android.graphics.drawable.Icon: ...
        def getRemoteInputs(self) -> java.chaquopy.JavaArray[RemoteInput]: ...
        def getSemanticAction(self) -> int: ...
        def isAuthenticationRequired(self) -> bool: ...
        def isContextual(self) -> bool: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

        class WearableExtender(Notification.Action.Extender):
            @typing.overload
            def __init__(self) -> None: ...
            @typing.overload
            def __init__(self, action: Notification.Action, /) -> None: ...
            def clone(self) -> Notification.Action.WearableExtender: ...
            def extend(self, builder: Notification.Action.Builder, /) -> Notification.Action.Builder: ...
            def getCancelLabel(self) -> java.lang.CharSequence: ...
            def getConfirmLabel(self) -> java.lang.CharSequence: ...
            def getHintDisplayActionInline(self) -> bool: ...
            def getHintLaunchesActivity(self) -> bool: ...
            def getInProgressLabel(self) -> java.lang.CharSequence: ...
            def isAvailableOffline(self) -> bool: ...
            def setAvailableOffline(self, availableOffline: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Action.WearableExtender: ...
            def setCancelLabel(self, label: java.lang.CharSequence, /) -> Notification.Action.WearableExtender: ...
            def setConfirmLabel(self, label: java.lang.CharSequence, /) -> Notification.Action.WearableExtender: ...
            def setHintDisplayActionInline(self, hintDisplayInline: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Action.WearableExtender: ...
            def setHintLaunchesActivity(self, hintLaunchesActivity: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Action.WearableExtender: ...
            def setInProgressLabel(self, label: java.lang.CharSequence, /) -> Notification.Action.WearableExtender: ...

        class Extender(java.lang.Object):
            def extend(self, arg1: Notification.Action.Builder, /) -> Notification.Action.Builder: ...

        class Builder(java.lang.Object):
            @typing.overload
            def __init__(self, action: Notification.Action, /) -> None: ...
            @typing.overload
            def __init__(self, icon: int | java.jint | java.lang.Integer, title: java.lang.CharSequence, intent: PendingIntent, /) -> None: ...
            @typing.overload
            def __init__(self, icon: android.graphics.drawable.Icon, title: java.lang.CharSequence, intent: PendingIntent, /) -> None: ...
            def addExtras(self, extras: android.os.Bundle, /) -> Notification.Action.Builder: ...
            def addRemoteInput(self, remoteInput: RemoteInput, /) -> Notification.Action.Builder: ...
            def build(self) -> Notification.Action: ...
            def extend(self, extender: Notification.Action.Extender, /) -> Notification.Action.Builder: ...
            def getExtras(self) -> android.os.Bundle: ...
            def setAllowGeneratedReplies(self, allowGeneratedReplies: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Action.Builder: ...
            def setAuthenticationRequired(self, authenticationRequired: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Action.Builder: ...
            def setContextual(self, isContextual: bool | java.jboolean | java.lang.Boolean, /) -> Notification.Action.Builder: ...
            def setSemanticAction(self, semanticAction: int | java.jint | java.lang.Integer, /) -> Notification.Action.Builder: ...

class NotificationChannel(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NotificationChannel]] = ...
    DEFAULT_CHANNEL_ID: typing.ClassVar[str] = ...
    EDIT_CONVERSATION: typing.ClassVar[str] = ...
    EDIT_IMPORTANCE: typing.ClassVar[str] = ...
    EDIT_LAUNCHER: typing.ClassVar[str] = ...
    EDIT_LOCKED_DEVICE: typing.ClassVar[str] = ...
    EDIT_SOUND: typing.ClassVar[str] = ...
    EDIT_VIBRATION: typing.ClassVar[str] = ...
    EDIT_ZEN: typing.ClassVar[str] = ...
    def __init__(self, id: str | java.lang.String, name: java.lang.CharSequence, importance: int | java.jint | java.lang.Integer, /) -> None: ...
    def canBubble(self) -> bool: ...
    def canBypassDnd(self) -> bool: ...
    def canShowBadge(self) -> bool: ...
    def describeContents(self) -> int: ...
    def enableLights(self, lights: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def enableVibration(self, vibration: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAudioAttributes(self) -> android.media.AudioAttributes: ...
    def getConversationId(self) -> str | None: ...
    def getDescription(self) -> str: ...
    def getGroup(self) -> str: ...
    def getId(self) -> str: ...
    def getImportance(self) -> int: ...
    def getLightColor(self) -> int: ...
    def getLockscreenVisibility(self) -> int: ...
    def getName(self) -> java.lang.CharSequence: ...
    def getParentChannelId(self) -> str | None: ...
    def getSound(self) -> android.net.Uri: ...
    def getVibrationEffect(self) -> android.os.VibrationEffect | None: ...
    def getVibrationPattern(self) -> java.chaquopy.JavaArrayJLong: ...
    def hasUserSetImportance(self) -> bool: ...
    def hasUserSetSound(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isBlockable(self) -> bool: ...
    def isConversation(self) -> bool: ...
    def isDemoted(self) -> bool: ...
    def isImportantConversation(self) -> bool: ...
    def setAllowBubbles(self, allowBubbles: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBlockable(self, blockable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setBypassDnd(self, bypassDnd: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setConversationId(self, parentChannelId: str | java.lang.String, conversationId: str | java.lang.String, /) -> None: ...
    def setDescription(self, description: str | java.lang.String, /) -> None: ...
    def setGroup(self, groupId: str | java.lang.String, /) -> None: ...
    def setImportance(self, importance: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLightColor(self, argb: int | java.jint | java.lang.Integer, /) -> None: ...
    def setLockscreenVisibility(self, lockscreenVisibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def setName(self, name: java.lang.CharSequence, /) -> None: ...
    def setShowBadge(self, showBadge: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSound(self, sound: android.net.Uri, audioAttributes: android.media.AudioAttributes, /) -> None: ...
    def setVibrationEffect(self, effect: android.os.VibrationEffect, /) -> None: ...
    def setVibrationPattern(self, vibrationPattern: java.chaquopy.JavaArrayJLong, /) -> None: ...
    def shouldShowLights(self) -> bool: ...
    def shouldVibrate(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class NotificationChannelGroup(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NotificationChannelGroup]] = ...
    def __init__(self, id: str | java.lang.String, name: java.lang.CharSequence, /) -> None: ...
    def clone(self) -> NotificationChannelGroup: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChannels(self) -> java.util.List[NotificationChannel]: ...
    def getDescription(self) -> str: ...
    def getId(self) -> str: ...
    def getName(self) -> java.lang.CharSequence: ...
    def hashCode(self) -> int: ...
    def isBlocked(self) -> bool: ...
    def setDescription(self, description: str | java.lang.String, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class NotificationManager(java.lang.Object):
    ACTION_APP_BLOCK_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_AUTOMATIC_ZEN_RULE: typing.ClassVar[str] = ...
    ACTION_AUTOMATIC_ZEN_RULE_STATUS_CHANGED: typing.ClassVar[str] = ...
    ACTION_CONSOLIDATED_NOTIFICATION_POLICY_CHANGED: typing.ClassVar[str] = ...
    ACTION_INTERRUPTION_FILTER_CHANGED: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_CHANNEL_BLOCK_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_CHANNEL_GROUP_BLOCK_STATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_POLICY_ACCESS_GRANTED_CHANGED: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_POLICY_CHANGED: typing.ClassVar[str] = ...
    AUTOMATIC_RULE_STATUS_ACTIVATED: typing.ClassVar[int] = ...
    AUTOMATIC_RULE_STATUS_DEACTIVATED: typing.ClassVar[int] = ...
    AUTOMATIC_RULE_STATUS_DISABLED: typing.ClassVar[int] = ...
    AUTOMATIC_RULE_STATUS_ENABLED: typing.ClassVar[int] = ...
    AUTOMATIC_RULE_STATUS_REMOVED: typing.ClassVar[int] = ...
    AUTOMATIC_RULE_STATUS_UNKNOWN: typing.ClassVar[int] = ...
    BUBBLE_PREFERENCE_ALL: typing.ClassVar[int] = ...
    BUBBLE_PREFERENCE_NONE: typing.ClassVar[int] = ...
    BUBBLE_PREFERENCE_SELECTED: typing.ClassVar[int] = ...
    EXTRA_AUTOMATIC_RULE_ID: typing.ClassVar[str] = ...
    EXTRA_AUTOMATIC_ZEN_RULE_ID: typing.ClassVar[str] = ...
    EXTRA_AUTOMATIC_ZEN_RULE_STATUS: typing.ClassVar[str] = ...
    EXTRA_BLOCKED_STATE: typing.ClassVar[str] = ...
    EXTRA_NOTIFICATION_CHANNEL_GROUP_ID: typing.ClassVar[str] = ...
    EXTRA_NOTIFICATION_CHANNEL_ID: typing.ClassVar[str] = ...
    EXTRA_NOTIFICATION_POLICY: typing.ClassVar[str] = ...
    IMPORTANCE_DEFAULT: typing.ClassVar[int] = ...
    IMPORTANCE_HIGH: typing.ClassVar[int] = ...
    IMPORTANCE_LOW: typing.ClassVar[int] = ...
    IMPORTANCE_MAX: typing.ClassVar[int] = ...
    IMPORTANCE_MIN: typing.ClassVar[int] = ...
    IMPORTANCE_NONE: typing.ClassVar[int] = ...
    IMPORTANCE_UNSPECIFIED: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_ALARMS: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_ALL: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_NONE: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_PRIORITY: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_UNKNOWN: typing.ClassVar[int] = ...
    META_DATA_AUTOMATIC_RULE_TYPE: typing.ClassVar[str] = ...
    META_DATA_RULE_INSTANCE_LIMIT: typing.ClassVar[str] = ...
    def addAutomaticZenRule(self, automaticZenRule: AutomaticZenRule, /) -> str | None: ...
    def areAutomaticZenRulesUserManaged(self) -> bool: ...
    def areBubblesAllowed(self) -> bool: ...
    def areBubblesEnabled(self) -> bool: ...
    def areNotificationsEnabled(self) -> bool: ...
    def areNotificationsPaused(self) -> bool: ...
    def canNotifyAsPackage(self, pkg: str | java.lang.String, /) -> bool: ...
    def canPostPromotedNotifications(self) -> bool: ...
    def canUseFullScreenIntent(self) -> bool: ...
    @typing.overload
    def cancel(self, id: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def cancel(self, tag: str | java.lang.String, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def cancelAll(self) -> None: ...
    def cancelAsPackage(self, targetPackage: str | java.lang.String, tag: str | java.lang.String, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def createNotificationChannel(self, channel: NotificationChannel, /) -> None: ...
    def createNotificationChannelGroup(self, group: NotificationChannelGroup, /) -> None: ...
    def createNotificationChannelGroups(self, groups: java.util.List[NotificationChannelGroup], /) -> None: ...
    def createNotificationChannels(self, channels: java.util.List[NotificationChannel], /) -> None: ...
    def deleteNotificationChannel(self, channelId: str | java.lang.String, /) -> None: ...
    def deleteNotificationChannelGroup(self, groupId: str | java.lang.String, /) -> None: ...
    def getActiveNotifications(self) -> java.chaquopy.JavaArray[android.service.notification.StatusBarNotification]: ...
    def getAutomaticZenRule(self, id: str | java.lang.String, /) -> AutomaticZenRule: ...
    def getAutomaticZenRuleState(self, id: str | java.lang.String, /) -> int: ...
    def getAutomaticZenRules(self) -> java.util.Map[java.lang.String, AutomaticZenRule]: ...
    def getBubblePreference(self) -> int: ...
    def getConsolidatedNotificationPolicy(self) -> NotificationManager.Policy: ...
    def getCurrentInterruptionFilter(self) -> int: ...
    def getImportance(self) -> int: ...
    @typing.overload
    def getNotificationChannel(self, channelId: str | java.lang.String, /) -> NotificationChannel | None: ...
    @typing.overload
    def getNotificationChannel(self, channelId: str | java.lang.String, conversationId: str | java.lang.String, /) -> NotificationChannel | None: ...
    def getNotificationChannelGroup(self, channelGroupId: str | java.lang.String, /) -> NotificationChannelGroup: ...
    def getNotificationChannelGroups(self) -> java.util.List[NotificationChannelGroup]: ...
    def getNotificationChannels(self) -> java.util.List[NotificationChannel]: ...
    def getNotificationDelegate(self) -> str | None: ...
    def getNotificationPolicy(self) -> NotificationManager.Policy: ...
    def isNotificationListenerAccessGranted(self, listener: android.content.ComponentName, /) -> bool: ...
    def isNotificationPolicyAccessGranted(self) -> bool: ...
    def matchesCallFilter(self, uri: android.net.Uri, /) -> bool: ...
    @typing.overload
    def notify(self, id: int | java.jint | java.lang.Integer, notification: Notification, /) -> None: ...
    @typing.overload
    def notify(self, tag: str | java.lang.String, id: int | java.jint | java.lang.Integer, notification: Notification, /) -> None: ...
    def notifyAsPackage(self, targetPackage: str | java.lang.String, tag: str | java.lang.String, id: int | java.jint | java.lang.Integer, notification: Notification, /) -> None: ...
    def removeAutomaticZenRule(self, id: str | java.lang.String, /) -> bool: ...
    def setAutomaticZenRuleState(self, id: str | java.lang.String, condition: android.service.notification.Condition, /) -> None: ...
    def setInterruptionFilter(self, interruptionFilter: int | java.jint | java.lang.Integer, /) -> None: ...
    def setNotificationDelegate(self, delegate: str | java.lang.String, /) -> None: ...
    def setNotificationPolicy(self, policy: NotificationManager.Policy, /) -> None: ...
    def shouldHideSilentStatusBarIcons(self) -> bool: ...
    def updateAutomaticZenRule(self, id: str | java.lang.String, automaticZenRule: AutomaticZenRule, /) -> bool: ...

    class Policy(android.os.Parcelable):
        CONVERSATION_SENDERS_ANYONE: typing.ClassVar[int] = ...
        CONVERSATION_SENDERS_IMPORTANT: typing.ClassVar[int] = ...
        CONVERSATION_SENDERS_NONE: typing.ClassVar[int] = ...
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NotificationManager.Policy]] = ...
        PRIORITY_CATEGORY_ALARMS: typing.ClassVar[int] = ...
        PRIORITY_CATEGORY_CALLS: typing.ClassVar[int] = ...
        PRIORITY_CATEGORY_CONVERSATIONS: typing.ClassVar[int] = ...
        PRIORITY_CATEGORY_EVENTS: typing.ClassVar[int] = ...
        PRIORITY_CATEGORY_MEDIA: typing.ClassVar[int] = ...
        PRIORITY_CATEGORY_MESSAGES: typing.ClassVar[int] = ...
        PRIORITY_CATEGORY_REMINDERS: typing.ClassVar[int] = ...
        PRIORITY_CATEGORY_REPEAT_CALLERS: typing.ClassVar[int] = ...
        PRIORITY_CATEGORY_SYSTEM: typing.ClassVar[int] = ...
        PRIORITY_SENDERS_ANY: typing.ClassVar[int] = ...
        PRIORITY_SENDERS_CONTACTS: typing.ClassVar[int] = ...
        PRIORITY_SENDERS_STARRED: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_AMBIENT: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_BADGE: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_FULL_SCREEN_INTENT: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_LIGHTS: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_NOTIFICATION_LIST: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_PEEK: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_SCREEN_OFF: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_SCREEN_ON: typing.ClassVar[int] = ...
        SUPPRESSED_EFFECT_STATUS_BAR: typing.ClassVar[int] = ...
        priorityCallSenders: int = ...
        priorityCategories: int = ...
        priorityConversationSenders: int = ...
        priorityMessageSenders: int = ...
        suppressedVisualEffects: int = ...
        @typing.overload
        def __init__(self, priorityCategories: int | java.jint | java.lang.Integer, priorityCallSenders: int | java.jint | java.lang.Integer, priorityMessageSenders: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, priorityCategories: int | java.jint | java.lang.Integer, priorityCallSenders: int | java.jint | java.lang.Integer, priorityMessageSenders: int | java.jint | java.lang.Integer, suppressedVisualEffects: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, priorityCategories: int | java.jint | java.lang.Integer, priorityCallSenders: int | java.jint | java.lang.Integer, priorityMessageSenders: int | java.jint | java.lang.Integer, suppressedVisualEffects: int | java.jint | java.lang.Integer, priorityConversationSenders: int | java.jint | java.lang.Integer, /) -> None: ...
        def describeContents(self) -> int: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...
        @staticmethod
        def priorityCategoriesToString(priorityCategories: int | java.jint | java.lang.Integer, /) -> str: ...
        @staticmethod
        def prioritySendersToString(prioritySenders: int | java.jint | java.lang.Integer, /) -> str: ...
        @staticmethod
        def suppressedEffectsToString(effects: int | java.jint | java.lang.Integer, /) -> str: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PendingIntent(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PendingIntent]] = ...
    FLAG_ALLOW_UNSAFE_IMPLICIT_INTENT: typing.ClassVar[int] = ...
    FLAG_CANCEL_CURRENT: typing.ClassVar[int] = ...
    FLAG_IMMUTABLE: typing.ClassVar[int] = ...
    FLAG_MUTABLE: typing.ClassVar[int] = ...
    FLAG_NO_CREATE: typing.ClassVar[int] = ...
    FLAG_ONE_SHOT: typing.ClassVar[int] = ...
    FLAG_UPDATE_CURRENT: typing.ClassVar[int] = ...
    def cancel(self) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, otherObj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @typing.overload
    @staticmethod
    def getActivities(context: android.content.Context, requestCode: int | java.jint | java.lang.Integer, intents: java.chaquopy.JavaArray[android.content.Intent], flags: int | java.jint | java.lang.Integer, /) -> PendingIntent | None: ...
    @typing.overload
    @staticmethod
    def getActivities(context: android.content.Context, requestCode: int | java.jint | java.lang.Integer, intents: java.chaquopy.JavaArray[android.content.Intent], flags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> PendingIntent | None: ...
    @typing.overload
    @staticmethod
    def getActivity(context: android.content.Context, requestCode: int | java.jint | java.lang.Integer, intent: android.content.Intent, flags: int | java.jint | java.lang.Integer, /) -> PendingIntent | None: ...
    @typing.overload
    @staticmethod
    def getActivity(context: android.content.Context, requestCode: int | java.jint | java.lang.Integer, intent: android.content.Intent, flags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> PendingIntent | None: ...
    @staticmethod
    def getBroadcast(context: android.content.Context, requestCode: int | java.jint | java.lang.Integer, intent: android.content.Intent, flags: int | java.jint | java.lang.Integer, /) -> PendingIntent | None: ...
    def getCreatorPackage(self) -> str | None: ...
    def getCreatorUid(self) -> int: ...
    def getCreatorUserHandle(self) -> android.os.UserHandle: ...
    @staticmethod
    def getForegroundService(context: android.content.Context, requestCode: int | java.jint | java.lang.Integer, intent: android.content.Intent, flags: int | java.jint | java.lang.Integer, /) -> PendingIntent | None: ...
    def getIntentSender(self) -> android.content.IntentSender: ...
    @staticmethod
    def getService(context: android.content.Context, requestCode: int | java.jint | java.lang.Integer, intent: android.content.Intent, flags: int | java.jint | java.lang.Integer, /) -> PendingIntent | None: ...
    def getTargetPackage(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def isActivity(self) -> bool: ...
    def isBroadcast(self) -> bool: ...
    def isForegroundService(self) -> bool: ...
    def isImmutable(self) -> bool: ...
    def isService(self) -> bool: ...
    @staticmethod
    def readPendingIntentOrNullFromParcel(in_: android.os.Parcel, /) -> PendingIntent | None: ...
    @typing.overload
    def send(self) -> None: ...
    @typing.overload
    def send(self, code: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def send(self, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def send(self, code: int | java.jint | java.lang.Integer, onFinished: PendingIntent.OnFinished, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def send(self, context: android.content.Context, code: int | java.jint | java.lang.Integer, intent: android.content.Intent, /) -> None: ...
    @typing.overload
    def send(self, context: android.content.Context, code: int | java.jint | java.lang.Integer, intent: android.content.Intent, onFinished: PendingIntent.OnFinished, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def send(self, context: android.content.Context, code: int | java.jint | java.lang.Integer, intent: android.content.Intent, onFinished: PendingIntent.OnFinished, handler: android.os.Handler, requiredPermission: str | java.lang.String, /) -> None: ...
    @typing.overload
    def send(self, context: android.content.Context, code: int | java.jint | java.lang.Integer, intent: android.content.Intent, onFinished: PendingIntent.OnFinished, handler: android.os.Handler, requiredPermission: str | java.lang.String, options: android.os.Bundle, /) -> None: ...
    def toString(self) -> str: ...
    @staticmethod
    def writePendingIntentOrNullToParcel(sender: PendingIntent, out: android.os.Parcel, /) -> None: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnFinished(java.lang.Object):
        def onSendFinished(self, arg1: PendingIntent, arg2: android.content.Intent, arg3: int | java.jint | java.lang.Integer, arg4: str | java.lang.String, arg5: android.os.Bundle, /) -> None: ...

    class CanceledException(android.util.AndroidException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, cause: java.lang.Exception, /) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...

class Person(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Person]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getIcon(self) -> android.graphics.drawable.Icon | None: ...
    def getKey(self) -> str | None: ...
    def getName(self) -> java.lang.CharSequence | None: ...
    def getUri(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def isBot(self) -> bool: ...
    def isImportant(self) -> bool: ...
    def toBuilder(self) -> Person.Builder: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> Person: ...
        def setBot(self, isBot: bool | java.jboolean | java.lang.Boolean, /) -> Person.Builder: ...
        def setIcon(self, icon: android.graphics.drawable.Icon, /) -> Person.Builder: ...
        def setImportant(self, isImportant: bool | java.jboolean | java.lang.Boolean, /) -> Person.Builder: ...
        def setKey(self, key: str | java.lang.String, /) -> Person.Builder: ...
        def setName(self, name: java.lang.CharSequence, /) -> Person.Builder: ...
        def setUri(self, uri: str | java.lang.String, /) -> Person.Builder: ...

class PictureInPictureParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PictureInPictureParams]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getActions(self) -> java.util.List[RemoteAction]: ...
    def getAspectRatio(self) -> android.util.Rational | None: ...
    def getCloseAction(self) -> RemoteAction | None: ...
    def getExpandedAspectRatio(self) -> android.util.Rational | None: ...
    def getSourceRectHint(self) -> android.graphics.Rect | None: ...
    def getSubtitle(self) -> java.lang.CharSequence | None: ...
    def getTitle(self) -> java.lang.CharSequence | None: ...
    def hashCode(self) -> int: ...
    def isAutoEnterEnabled(self) -> bool: ...
    def isSeamlessResizeEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, original: PictureInPictureParams, /) -> None: ...
        def build(self) -> PictureInPictureParams: ...
        def setActions(self, actions: java.util.List[RemoteAction], /) -> PictureInPictureParams.Builder: ...
        def setAspectRatio(self, aspectRatio: android.util.Rational, /) -> PictureInPictureParams.Builder: ...
        def setAutoEnterEnabled(self, autoEnterEnabled: bool | java.jboolean | java.lang.Boolean, /) -> PictureInPictureParams.Builder: ...
        def setCloseAction(self, action: RemoteAction, /) -> PictureInPictureParams.Builder: ...
        def setExpandedAspectRatio(self, expandedAspectRatio: android.util.Rational, /) -> PictureInPictureParams.Builder: ...
        def setSeamlessResizeEnabled(self, seamlessResizeEnabled: bool | java.jboolean | java.lang.Boolean, /) -> PictureInPictureParams.Builder: ...
        def setSourceRectHint(self, launchBounds: android.graphics.Rect, /) -> PictureInPictureParams.Builder: ...
        def setSubtitle(self, subtitle: java.lang.CharSequence, /) -> PictureInPictureParams.Builder: ...
        def setTitle(self, title: java.lang.CharSequence, /) -> PictureInPictureParams.Builder: ...

class PictureInPictureUiState(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PictureInPictureUiState]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def isStashed(self) -> bool: ...
    def isTransitioningToPip(self) -> bool: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Presentation(Dialog):
    @typing.overload
    def __init__(self, outerContext: android.content.Context, display: android.view.Display, /) -> None: ...
    @typing.overload
    def __init__(self, outerContext: android.content.Context, display: android.view.Display, theme: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDisplay(self) -> android.view.Display: ...
    def getResources(self) -> android.content.res.Resources: ...
    def onDisplayChanged(self) -> None: ...
    def onDisplayRemoved(self) -> None: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def show(self) -> None: ...

class ProgressDialog(AlertDialog):
    STYLE_HORIZONTAL: typing.ClassVar[int] = ...
    STYLE_SPINNER: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, theme: int | java.jint | java.lang.Integer, /) -> None: ...
    def getMax(self) -> int: ...
    def getProgress(self) -> int: ...
    def getSecondaryProgress(self) -> int: ...
    def incrementProgressBy(self, diff: int | java.jint | java.lang.Integer, /) -> None: ...
    def incrementSecondaryProgressBy(self, diff: int | java.jint | java.lang.Integer, /) -> None: ...
    def isIndeterminate(self) -> bool: ...
    def onCreate(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...
    def setIndeterminate(self, indeterminate: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIndeterminateDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setMax(self, max: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMessage(self, message: java.lang.CharSequence, /) -> None: ...
    def setProgress(self, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def setProgressDrawable(self, d: android.graphics.drawable.Drawable, /) -> None: ...
    def setProgressNumberFormat(self, format: str | java.lang.String, /) -> None: ...
    def setProgressPercentFormat(self, format: java.text.NumberFormat, /) -> None: ...
    def setProgressStyle(self, style: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSecondaryProgress(self, secondaryProgress: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def show(context: android.content.Context, title: java.lang.CharSequence, message: java.lang.CharSequence, /) -> ProgressDialog: ...
    @typing.overload
    @staticmethod
    def show(context: android.content.Context, title: java.lang.CharSequence, message: java.lang.CharSequence, indeterminate: bool | java.jboolean | java.lang.Boolean, /) -> ProgressDialog: ...
    @typing.overload
    @staticmethod
    def show(context: android.content.Context, title: java.lang.CharSequence, message: java.lang.CharSequence, indeterminate: bool | java.jboolean | java.lang.Boolean, cancelable: bool | java.jboolean | java.lang.Boolean, /) -> ProgressDialog: ...
    @typing.overload
    @staticmethod
    def show(context: android.content.Context, title: java.lang.CharSequence, message: java.lang.CharSequence, indeterminate: bool | java.jboolean | java.lang.Boolean, cancelable: bool | java.jboolean | java.lang.Boolean, cancelListener: android.content.DialogInterface.OnCancelListener, /) -> ProgressDialog: ...

class RecoverableSecurityException(android.os.Parcelable, java.lang.SecurityException):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RecoverableSecurityException]] = ...
    def __init__(self, cause: java.lang.Throwable, userMessage: java.lang.CharSequence, userAction: RemoteAction, /) -> None: ...
    def describeContents(self) -> int: ...
    def getUserAction(self) -> RemoteAction: ...
    def getUserMessage(self) -> java.lang.CharSequence: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RemoteAction(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RemoteAction]] = ...
    def __init__(self, icon: android.graphics.drawable.Icon, title: java.lang.CharSequence, contentDescription: java.lang.CharSequence, intent: PendingIntent, /) -> None: ...
    def clone(self) -> RemoteAction: ...
    def describeContents(self) -> int: ...
    def dump(self, prefix: str | java.lang.String, pw: java.io.PrintWriter, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getActionIntent(self) -> PendingIntent: ...
    def getContentDescription(self) -> java.lang.CharSequence: ...
    def getIcon(self) -> android.graphics.drawable.Icon: ...
    def getTitle(self) -> java.lang.CharSequence: ...
    def hashCode(self) -> int: ...
    def isEnabled(self) -> bool: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setShouldShowIcon(self, shouldShowIcon: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def shouldShowIcon(self) -> bool: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RemoteInput(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RemoteInput]] = ...
    EDIT_CHOICES_BEFORE_SENDING_AUTO: typing.ClassVar[int] = ...
    EDIT_CHOICES_BEFORE_SENDING_DISABLED: typing.ClassVar[int] = ...
    EDIT_CHOICES_BEFORE_SENDING_ENABLED: typing.ClassVar[int] = ...
    EXTRA_RESULTS_DATA: typing.ClassVar[str] = ...
    RESULTS_CLIP_LABEL: typing.ClassVar[str] = ...
    SOURCE_CHOICE: typing.ClassVar[int] = ...
    SOURCE_FREE_FORM_INPUT: typing.ClassVar[int] = ...
    @staticmethod
    def addDataResultToIntent(remoteInput: RemoteInput, intent: android.content.Intent, results: java.util.Map[java.lang.String, android.net.Uri], /) -> None: ...
    @staticmethod
    def addResultsToIntent(remoteInputs: java.chaquopy.JavaArray[RemoteInput], intent: android.content.Intent, results: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getAllowFreeFormInput(self) -> bool: ...
    def getAllowedDataTypes(self) -> java.util.Set[java.lang.String]: ...
    def getChoices(self) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    @staticmethod
    def getDataResultsFromIntent(intent: android.content.Intent, remoteInputResultKey: str | java.lang.String, /) -> java.util.Map[java.lang.String, android.net.Uri]: ...
    def getEditChoicesBeforeSending(self) -> int: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getLabel(self) -> java.lang.CharSequence: ...
    def getResultKey(self) -> str: ...
    @staticmethod
    def getResultsFromIntent(intent: android.content.Intent, /) -> android.os.Bundle: ...
    @staticmethod
    def getResultsSource(intent: android.content.Intent, /) -> int: ...
    def isDataOnly(self) -> bool: ...
    @staticmethod
    def setResultsSource(intent: android.content.Intent, source: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, resultKey: str | java.lang.String, /) -> None: ...
        def addExtras(self, extras: android.os.Bundle, /) -> RemoteInput.Builder: ...
        def build(self) -> RemoteInput: ...
        def getExtras(self) -> android.os.Bundle: ...
        def setAllowDataType(self, mimeType: str | java.lang.String, doAllow: bool | java.jboolean | java.lang.Boolean, /) -> RemoteInput.Builder: ...
        def setAllowFreeFormInput(self, allowFreeFormTextInput: bool | java.jboolean | java.lang.Boolean, /) -> RemoteInput.Builder: ...
        def setChoices(self, choices: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> RemoteInput.Builder: ...
        def setEditChoicesBeforeSending(self, editChoicesBeforeSending: int | java.jint | java.lang.Integer, /) -> RemoteInput.Builder: ...
        def setLabel(self, label: java.lang.CharSequence, /) -> RemoteInput.Builder: ...

class SearchManager(android.content.DialogInterface.OnCancelListener, android.content.DialogInterface.OnDismissListener):
    ACTION_KEY: typing.ClassVar[str] = ...
    ACTION_MSG: typing.ClassVar[str] = ...
    APP_DATA: typing.ClassVar[str] = ...
    CURSOR_EXTRA_KEY_IN_PROGRESS: typing.ClassVar[str] = ...
    EXTRA_DATA_KEY: typing.ClassVar[str] = ...
    EXTRA_NEW_SEARCH: typing.ClassVar[str] = ...
    EXTRA_SELECT_QUERY: typing.ClassVar[str] = ...
    EXTRA_WEB_SEARCH_PENDINGINTENT: typing.ClassVar[str] = ...
    FLAG_QUERY_REFINEMENT: typing.ClassVar[int] = ...
    INTENT_ACTION_GLOBAL_SEARCH: typing.ClassVar[str] = ...
    INTENT_ACTION_SEARCHABLES_CHANGED: typing.ClassVar[str] = ...
    INTENT_ACTION_SEARCH_SETTINGS: typing.ClassVar[str] = ...
    INTENT_ACTION_SEARCH_SETTINGS_CHANGED: typing.ClassVar[str] = ...
    INTENT_ACTION_WEB_SEARCH_SETTINGS: typing.ClassVar[str] = ...
    INTENT_GLOBAL_SEARCH_ACTIVITY_CHANGED: typing.ClassVar[str] = ...
    MENU_KEY: typing.ClassVar[str] = ...
    MENU_KEYCODE: typing.ClassVar[int] = ...
    QUERY: typing.ClassVar[str] = ...
    SHORTCUT_MIME_TYPE: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_AUDIO_CHANNEL_CONFIG: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_CONTENT_TYPE: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_DURATION: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_FLAGS: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_FORMAT: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_ICON_1: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_ICON_2: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_INTENT_ACTION: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_INTENT_DATA: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_INTENT_DATA_ID: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_INTENT_EXTRA_DATA: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_IS_LIVE: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_LAST_ACCESS_HINT: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_PRODUCTION_YEAR: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_PURCHASE_PRICE: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_QUERY: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_RATING_SCORE: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_RATING_STYLE: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_RENTAL_PRICE: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_RESULT_CARD_IMAGE: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_SHORTCUT_ID: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_SPINNER_WHILE_REFRESHING: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_TEXT_1: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_TEXT_2: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_TEXT_2_URL: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_VIDEO_HEIGHT: typing.ClassVar[str] = ...
    SUGGEST_COLUMN_VIDEO_WIDTH: typing.ClassVar[str] = ...
    SUGGEST_MIME_TYPE: typing.ClassVar[str] = ...
    SUGGEST_NEVER_MAKE_SHORTCUT: typing.ClassVar[str] = ...
    SUGGEST_PARAMETER_LIMIT: typing.ClassVar[str] = ...
    SUGGEST_URI_PATH_QUERY: typing.ClassVar[str] = ...
    SUGGEST_URI_PATH_SHORTCUT: typing.ClassVar[str] = ...
    USER_QUERY: typing.ClassVar[str] = ...
    def getGlobalSearchActivity(self) -> android.content.ComponentName: ...
    def getSearchableInfo(self, componentName: android.content.ComponentName, /) -> SearchableInfo: ...
    def getSearchablesInGlobalSearch(self) -> java.util.List[SearchableInfo]: ...
    def onCancel(self, dialog: android.content.DialogInterface, /) -> None: ...
    def onDismiss(self, dialog: android.content.DialogInterface, /) -> None: ...
    def setOnCancelListener(self, listener: SearchManager.OnCancelListener, /) -> None: ...
    def setOnDismissListener(self, listener: SearchManager.OnDismissListener, /) -> None: ...
    def startSearch(self, initialQuery: str | java.lang.String, selectInitialQuery: bool | java.jboolean | java.lang.Boolean, launchActivity: android.content.ComponentName, appSearchData: android.os.Bundle, globalSearch: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def stopSearch(self) -> None: ...
    def triggerSearch(self, query: str | java.lang.String, launchActivity: android.content.ComponentName, appSearchData: android.os.Bundle, /) -> None: ...

    class OnDismissListener(java.lang.Object):
        def onDismiss(self) -> None: ...

    class OnCancelListener(java.lang.Object):
        def onCancel(self) -> None: ...

class SearchableInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SearchableInfo]] = ...
    def autoUrlDetect(self) -> bool: ...
    def describeContents(self) -> int: ...
    def getHintId(self) -> int: ...
    def getImeOptions(self) -> int: ...
    def getInputType(self) -> int: ...
    def getSearchActivity(self) -> android.content.ComponentName: ...
    def getSettingsDescriptionId(self) -> int: ...
    def getSuggestAuthority(self) -> str: ...
    def getSuggestIntentAction(self) -> str: ...
    def getSuggestIntentData(self) -> str: ...
    def getSuggestPackage(self) -> str: ...
    def getSuggestPath(self) -> str: ...
    def getSuggestSelection(self) -> str: ...
    def getSuggestThreshold(self) -> int: ...
    def getVoiceLanguageId(self) -> int: ...
    def getVoiceLanguageModeId(self) -> int: ...
    def getVoiceMaxResults(self) -> int: ...
    def getVoicePromptTextId(self) -> int: ...
    def getVoiceSearchEnabled(self) -> bool: ...
    def getVoiceSearchLaunchRecognizer(self) -> bool: ...
    def getVoiceSearchLaunchWebSearch(self) -> bool: ...
    def queryAfterZeroResults(self) -> bool: ...
    def shouldIncludeInGlobalSearch(self) -> bool: ...
    def shouldRewriteQueryFromData(self) -> bool: ...
    def shouldRewriteQueryFromText(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Service(android.content.ComponentCallbacks2, android.content.ContextWrapper):
    START_CONTINUATION_MASK: typing.ClassVar[int] = ...
    START_FLAG_REDELIVERY: typing.ClassVar[int] = ...
    START_FLAG_RETRY: typing.ClassVar[int] = ...
    START_NOT_STICKY: typing.ClassVar[int] = ...
    START_REDELIVER_INTENT: typing.ClassVar[int] = ...
    START_STICKY: typing.ClassVar[int] = ...
    START_STICKY_COMPATIBILITY: typing.ClassVar[int] = ...
    STOP_FOREGROUND_DETACH: typing.ClassVar[int] = ...
    STOP_FOREGROUND_LEGACY: typing.ClassVar[int] = ...
    STOP_FOREGROUND_REMOVE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def attachBaseContext(self, newBase: android.content.Context, /) -> None: ...
    def dump(self, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def getApplication(self) -> Application: ...
    def getForegroundServiceType(self) -> int: ...
    def onBind(self, arg1: android.content.Intent, /) -> android.os.IBinder | None: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreate(self) -> None: ...
    def onDestroy(self) -> None: ...
    def onLowMemory(self) -> None: ...
    def onRebind(self, intent: android.content.Intent, /) -> None: ...
    def onStart(self, intent: android.content.Intent, startId: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStartCommand(self, intent: android.content.Intent, flags: int | java.jint | java.lang.Integer, startId: int | java.jint | java.lang.Integer, /) -> int: ...
    def onTaskRemoved(self, rootIntent: android.content.Intent, /) -> None: ...
    @typing.overload
    def onTimeout(self, startId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onTimeout(self, startId: int | java.jint | java.lang.Integer, fgsType: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTrimMemory(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    def onUnbind(self, intent: android.content.Intent, /) -> bool: ...
    @typing.overload
    def startForeground(self, id: int | java.jint | java.lang.Integer, notification: Notification, /) -> None: ...
    @typing.overload
    def startForeground(self, id: int | java.jint | java.lang.Integer, notification: Notification, foregroundServiceType: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def stopForeground(self, notificationBehavior: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def stopForeground(self, removeNotification: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def stopSelf(self) -> None: ...
    @typing.overload
    def stopSelf(self, startId: int | java.jint | java.lang.Integer, /) -> None: ...
    def stopSelfResult(self, startId: int | java.jint | java.lang.Integer, /) -> bool: ...

class ServiceStartNotAllowedException(java.lang.IllegalStateException):
    def getCause(self) -> java.lang.Throwable: ...

class SharedElementCallback(java.lang.Object):
    def __init__(self) -> None: ...
    def onCaptureSharedElementSnapshot(self, sharedElement: android.view.View, viewToGlobalMatrix: android.graphics.Matrix, screenBounds: android.graphics.RectF, /) -> android.os.Parcelable: ...
    def onCreateSnapshotView(self, context: android.content.Context, snapshot: android.os.Parcelable, /) -> android.view.View: ...
    def onMapSharedElements(self, names: java.util.List[java.lang.String], sharedElements: java.util.Map[java.lang.String, android.view.View], /) -> None: ...
    def onRejectSharedElements(self, rejectedSharedElements: java.util.List[android.view.View], /) -> None: ...
    def onSharedElementEnd(self, sharedElementNames: java.util.List[java.lang.String], sharedElements: java.util.List[android.view.View], sharedElementSnapshots: java.util.List[android.view.View], /) -> None: ...
    def onSharedElementStart(self, sharedElementNames: java.util.List[java.lang.String], sharedElements: java.util.List[android.view.View], sharedElementSnapshots: java.util.List[android.view.View], /) -> None: ...
    def onSharedElementsArrived(self, sharedElementNames: java.util.List[java.lang.String], sharedElements: java.util.List[android.view.View], listener: SharedElementCallback.OnSharedElementsReadyListener, /) -> None: ...

    class OnSharedElementsReadyListener(java.lang.Object):
        def onSharedElementsReady(self) -> None: ...

class StartForegroundCalledOnStoppedServiceException(android.os.Parcelable, java.lang.IllegalStateException):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[StartForegroundCalledOnStoppedServiceException]] = ...
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class StatusBarManager(java.lang.Object):
    TILE_ADD_REQUEST_ERROR_APP_NOT_IN_FOREGROUND: typing.ClassVar[int] = ...
    TILE_ADD_REQUEST_ERROR_BAD_COMPONENT: typing.ClassVar[int] = ...
    TILE_ADD_REQUEST_ERROR_MISMATCHED_PACKAGE: typing.ClassVar[int] = ...
    TILE_ADD_REQUEST_ERROR_NOT_CURRENT_USER: typing.ClassVar[int] = ...
    TILE_ADD_REQUEST_ERROR_NO_STATUS_BAR_SERVICE: typing.ClassVar[int] = ...
    TILE_ADD_REQUEST_ERROR_REQUEST_IN_PROGRESS: typing.ClassVar[int] = ...
    TILE_ADD_REQUEST_RESULT_TILE_ADDED: typing.ClassVar[int] = ...
    TILE_ADD_REQUEST_RESULT_TILE_ALREADY_ADDED: typing.ClassVar[int] = ...
    TILE_ADD_REQUEST_RESULT_TILE_NOT_ADDED: typing.ClassVar[int] = ...
    def canLaunchCaptureContentActivityForNote(self, activity: Activity, /) -> bool: ...
    def requestAddTileService(self, tileServiceComponentName: android.content.ComponentName, tileLabel: java.lang.CharSequence, icon: android.graphics.drawable.Icon, resultExecutor: java.util.concurrent.Executor, resultCallback: java.util.function.Consumer[java.lang.Integer], /) -> None: ...

class SyncNotedAppOp(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SyncNotedAppOp]] = ...
    def __init__(self, opCode: int | java.jint | java.lang.Integer, attributionTag: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAttributionTag(self) -> str | None: ...
    def getOp(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TabActivity(ActivityGroup):
    def __init__(self) -> None: ...
    def getTabHost(self) -> android.widget.TabHost: ...
    def getTabWidget(self) -> android.widget.TabWidget: ...
    def onChildTitleChanged(self, childActivity: Activity, title: java.lang.CharSequence, /) -> None: ...
    def onContentChanged(self) -> None: ...
    def onPostCreate(self, icicle: android.os.Bundle, /) -> None: ...
    def onRestoreInstanceState(self, state: android.os.Bundle, /) -> None: ...
    def onSaveInstanceState(self, outState: android.os.Bundle, /) -> None: ...
    @typing.overload
    def setDefaultTab(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setDefaultTab(self, tag: str | java.lang.String, /) -> None: ...

class TaskInfo(java.lang.Object):
    baseActivity: android.content.ComponentName = ...
    baseIntent: android.content.Intent = ...
    isRunning: bool = ...
    numActivities: int = ...
    origActivity: android.content.ComponentName = ...
    taskDescription: ActivityManager.TaskDescription = ...
    taskId: int = ...
    topActivity: android.content.ComponentName = ...
    def isVisible(self) -> bool: ...
    def toString(self) -> str: ...

class TaskStackBuilder(java.lang.Object):
    def addNextIntent(self, nextIntent: android.content.Intent, /) -> TaskStackBuilder: ...
    def addNextIntentWithParentStack(self, nextIntent: android.content.Intent, /) -> TaskStackBuilder: ...
    @typing.overload
    def addParentStack(self, sourceActivity: Activity, /) -> TaskStackBuilder: ...
    @typing.overload
    def addParentStack(self, sourceActivityName: android.content.ComponentName, /) -> TaskStackBuilder: ...
    @typing.overload
    def addParentStack(self, sourceActivityClass: typing.Type[java.lang.Object], /) -> TaskStackBuilder: ...
    @staticmethod
    def create(context: android.content.Context, /) -> TaskStackBuilder: ...
    def editIntentAt(self, index: int | java.jint | java.lang.Integer, /) -> android.content.Intent: ...
    def getIntentCount(self) -> int: ...
    def getIntents(self) -> java.chaquopy.JavaArray[android.content.Intent]: ...
    @typing.overload
    def getPendingIntent(self, requestCode: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> PendingIntent: ...
    @typing.overload
    def getPendingIntent(self, requestCode: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> PendingIntent: ...
    @typing.overload
    def startActivities(self) -> None: ...
    @typing.overload
    def startActivities(self, options: android.os.Bundle, /) -> None: ...

class TimePickerDialog(AlertDialog, android.content.DialogInterface.OnClickListener, android.widget.TimePicker.OnTimeChangedListener):
    @typing.overload
    def __init__(self, context: android.content.Context, listener: TimePickerDialog.OnTimeSetListener, hourOfDay: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, is24HourView: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, themeResId: int | java.jint | java.lang.Integer, listener: TimePickerDialog.OnTimeSetListener, hourOfDay: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, is24HourView: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onClick(self, dialog: android.content.DialogInterface, which: int | java.jint | java.lang.Integer, /) -> None: ...
    def onRestoreInstanceState(self, savedInstanceState: android.os.Bundle, /) -> None: ...
    def onSaveInstanceState(self) -> android.os.Bundle: ...
    def onTimeChanged(self, view: android.widget.TimePicker, hourOfDay: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, /) -> None: ...
    def show(self) -> None: ...
    def updateTime(self, hourOfDay: int | java.jint | java.lang.Integer, minuteOfHour: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnTimeSetListener(java.lang.Object):
        def onTimeSet(self, arg1: android.widget.TimePicker, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...

class UiAutomation(java.lang.Object):
    FLAG_DONT_SUPPRESS_ACCESSIBILITY_SERVICES: typing.ClassVar[int] = ...
    FLAG_DONT_USE_ACCESSIBILITY: typing.ClassVar[int] = ...
    ROTATION_FREEZE_0: typing.ClassVar[int] = ...
    ROTATION_FREEZE_180: typing.ClassVar[int] = ...
    ROTATION_FREEZE_270: typing.ClassVar[int] = ...
    ROTATION_FREEZE_90: typing.ClassVar[int] = ...
    ROTATION_FREEZE_CURRENT: typing.ClassVar[int] = ...
    ROTATION_UNFREEZE: typing.ClassVar[int] = ...
    @typing.overload
    def adoptShellPermissionIdentity(self) -> None: ...
    @typing.overload
    def adoptShellPermissionIdentity(self, *permissions: java.lang.String) -> None: ...
    def clearCache(self) -> bool: ...
    def clearWindowAnimationFrameStats(self) -> None: ...
    def clearWindowContentFrameStats(self, windowId: int | java.jint | java.lang.Integer, /) -> bool: ...
    def dropShellPermissionIdentity(self) -> None: ...
    def executeAndWaitForEvent(self, command: java.lang.Runnable, filter: UiAutomation.AccessibilityEventFilter, timeoutMillis: int | java.jlong | java.lang.Long, /) -> android.view.accessibility.AccessibilityEvent: ...
    def executeShellCommand(self, command: str | java.lang.String, /) -> android.os.ParcelFileDescriptor: ...
    def executeShellCommandRw(self, command: str | java.lang.String, /) -> java.chaquopy.JavaArray[android.os.ParcelFileDescriptor]: ...
    def executeShellCommandRwe(self, command: str | java.lang.String, /) -> java.chaquopy.JavaArray[android.os.ParcelFileDescriptor]: ...
    def findFocus(self, focus: int | java.jint | java.lang.Integer, /) -> android.view.accessibility.AccessibilityNodeInfo | None: ...
    def getRootInActiveWindow(self) -> android.view.accessibility.AccessibilityNodeInfo | None: ...
    def getServiceInfo(self) -> android.accessibilityservice.AccessibilityServiceInfo: ...
    def getWindowAnimationFrameStats(self) -> android.view.WindowAnimationFrameStats: ...
    def getWindowContentFrameStats(self, windowId: int | java.jint | java.lang.Integer, /) -> android.view.WindowContentFrameStats | None: ...
    def getWindows(self) -> java.util.List[android.view.accessibility.AccessibilityWindowInfo]: ...
    def getWindowsOnAllDisplays(self) -> android.util.SparseArray[java.util.List[android.view.accessibility.AccessibilityWindowInfo]]: ...
    def grantRuntimePermission(self, packageName: str | java.lang.String, permission: str | java.lang.String, /) -> None: ...
    def grantRuntimePermissionAsUser(self, packageName: str | java.lang.String, permission: str | java.lang.String, userHandle: android.os.UserHandle, /) -> None: ...
    def injectInputEvent(self, event: android.view.InputEvent, sync: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def performGlobalAction(self, action: int | java.jint | java.lang.Integer, /) -> bool: ...
    def revokeRuntimePermission(self, packageName: str | java.lang.String, permission: str | java.lang.String, /) -> None: ...
    def revokeRuntimePermissionAsUser(self, packageName: str | java.lang.String, permission: str | java.lang.String, userHandle: android.os.UserHandle, /) -> None: ...
    def setAnimationScale(self, scale: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setOnAccessibilityEventListener(self, listener: UiAutomation.OnAccessibilityEventListener, /) -> None: ...
    def setRotation(self, rotation: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setRunAsMonkey(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setServiceInfo(self, info: android.accessibilityservice.AccessibilityServiceInfo, /) -> None: ...
    @typing.overload
    def takeScreenshot(self) -> android.graphics.Bitmap | None: ...
    @typing.overload
    def takeScreenshot(self, window: android.view.Window, /) -> android.graphics.Bitmap | None: ...
    def toString(self) -> str: ...
    def waitForIdle(self, idleTimeoutMillis: int | java.jlong | java.lang.Long, globalTimeoutMillis: int | java.jlong | java.lang.Long, /) -> None: ...

    class OnAccessibilityEventListener(java.lang.Object):
        def onAccessibilityEvent(self, arg1: android.view.accessibility.AccessibilityEvent, /) -> None: ...

    class AccessibilityEventFilter(java.lang.Object):
        def accept(self, arg1: android.view.accessibility.AccessibilityEvent, /) -> bool: ...

class UiModeManager(java.lang.Object):
    ACTION_ENTER_CAR_MODE: typing.ClassVar[str] = ...
    ACTION_ENTER_DESK_MODE: typing.ClassVar[str] = ...
    ACTION_EXIT_CAR_MODE: typing.ClassVar[str] = ...
    ACTION_EXIT_DESK_MODE: typing.ClassVar[str] = ...
    DISABLE_CAR_MODE_GO_HOME: typing.ClassVar[int] = ...
    ENABLE_CAR_MODE_ALLOW_SLEEP: typing.ClassVar[int] = ...
    ENABLE_CAR_MODE_GO_CAR_HOME: typing.ClassVar[int] = ...
    MODE_NIGHT_AUTO: typing.ClassVar[int] = ...
    MODE_NIGHT_CUSTOM: typing.ClassVar[int] = ...
    MODE_NIGHT_NO: typing.ClassVar[int] = ...
    MODE_NIGHT_YES: typing.ClassVar[int] = ...
    def addContrastChangeListener(self, executor: java.util.concurrent.Executor, listener: UiModeManager.ContrastChangeListener, /) -> None: ...
    def disableCarMode(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def enableCarMode(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def getContrast(self) -> float: ...
    def getCurrentModeType(self) -> int: ...
    def getCustomNightModeEnd(self) -> java.time.LocalTime: ...
    def getCustomNightModeStart(self) -> java.time.LocalTime: ...
    def getNightMode(self) -> int: ...
    def removeContrastChangeListener(self, listener: UiModeManager.ContrastChangeListener, /) -> None: ...
    def setApplicationNightMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCustomNightModeEnd(self, time: java.time.LocalTime, /) -> None: ...
    def setCustomNightModeStart(self, time: java.time.LocalTime, /) -> None: ...
    def setNightMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...

    class ContrastChangeListener(java.lang.Object):
        def onContrastChanged(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...

class VoiceInteractor(java.lang.Object):
    def getActiveRequest(self, name: str | java.lang.String, /) -> VoiceInteractor.Request | None: ...
    def getActiveRequests(self) -> java.chaquopy.JavaArray[VoiceInteractor.Request]: ...
    def getPackageName(self) -> str: ...
    def isDestroyed(self) -> bool: ...
    def notifyDirectActionsChanged(self) -> None: ...
    def registerOnDestroyedCallback(self, executor: java.util.concurrent.Executor, callback: java.lang.Runnable, /) -> bool: ...
    @typing.overload
    def submitRequest(self, request: VoiceInteractor.Request, /) -> bool: ...
    @typing.overload
    def submitRequest(self, request: VoiceInteractor.Request, name: str | java.lang.String, /) -> bool: ...
    def supportsCommands(self, commands: java.chaquopy.JavaArray[java.lang.String], /) -> java.chaquopy.JavaArrayJBoolean: ...
    def unregisterOnDestroyedCallback(self, callback: java.lang.Runnable, /) -> bool: ...

    class Request(java.lang.Object):
        def cancel(self) -> None: ...
        def getActivity(self) -> Activity: ...
        def getContext(self) -> android.content.Context: ...
        def getName(self) -> str: ...
        def onAttached(self, activity: Activity, /) -> None: ...
        def onCancel(self) -> None: ...
        def onDetached(self) -> None: ...
        def toString(self) -> str: ...

    class Prompt(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VoiceInteractor.Prompt]] = ...
        @typing.overload
        def __init__(self, prompt: java.lang.CharSequence, /) -> None: ...
        @typing.overload
        def __init__(self, voicePrompts: java.chaquopy.JavaArray[java.lang.CharSequence], visualPrompt: java.lang.CharSequence, /) -> None: ...
        def countVoicePrompts(self) -> int: ...
        def describeContents(self) -> int: ...
        def getVisualPrompt(self) -> java.lang.CharSequence: ...
        def getVoicePromptAt(self, index: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class PickOptionRequest(VoiceInteractor.Request):
        def __init__(self, prompt: VoiceInteractor.Prompt, options: java.chaquopy.JavaArray[VoiceInteractor.PickOptionRequest.Option], extras: android.os.Bundle, /) -> None: ...
        def onPickOptionResult(self, finished: bool | java.jboolean | java.lang.Boolean, selections: java.chaquopy.JavaArray[VoiceInteractor.PickOptionRequest.Option], result: android.os.Bundle, /) -> None: ...

        class Option(android.os.Parcelable):
            CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VoiceInteractor.PickOptionRequest.Option]] = ...
            def __init__(self, label: java.lang.CharSequence, index: int | java.jint | java.lang.Integer, /) -> None: ...
            def addSynonym(self, synonym: java.lang.CharSequence, /) -> VoiceInteractor.PickOptionRequest.Option: ...
            def countSynonyms(self) -> int: ...
            def describeContents(self) -> int: ...
            def getExtras(self) -> android.os.Bundle: ...
            def getIndex(self) -> int: ...
            def getLabel(self) -> java.lang.CharSequence: ...
            def getSynonymAt(self, index: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
            def setExtras(self, extras: android.os.Bundle, /) -> None: ...
            def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class ConfirmationRequest(VoiceInteractor.Request):
        def __init__(self, prompt: VoiceInteractor.Prompt, extras: android.os.Bundle, /) -> None: ...
        def onConfirmationResult(self, confirmed: bool | java.jboolean | java.lang.Boolean, result: android.os.Bundle, /) -> None: ...

    class CompleteVoiceRequest(VoiceInteractor.Request):
        def __init__(self, prompt: VoiceInteractor.Prompt, extras: android.os.Bundle, /) -> None: ...
        def onCompleteResult(self, result: android.os.Bundle, /) -> None: ...

    class CommandRequest(VoiceInteractor.Request):
        def __init__(self, command: str | java.lang.String, args: android.os.Bundle, /) -> None: ...
        def onCommandResult(self, isCompleted: bool | java.jboolean | java.lang.Boolean, result: android.os.Bundle, /) -> None: ...

    class AbortVoiceRequest(VoiceInteractor.Request):
        def __init__(self, prompt: VoiceInteractor.Prompt, extras: android.os.Bundle, /) -> None: ...
        def onAbortResult(self, result: android.os.Bundle, /) -> None: ...

class WallpaperColors(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WallpaperColors]] = ...
    HINT_SUPPORTS_DARK_TEXT: typing.ClassVar[int] = ...
    HINT_SUPPORTS_DARK_THEME: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, parcel: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, primaryColor: android.graphics.Color, secondaryColor: android.graphics.Color, tertiaryColor: android.graphics.Color, /) -> None: ...
    @typing.overload
    def __init__(self, primaryColor: android.graphics.Color, secondaryColor: android.graphics.Color, tertiaryColor: android.graphics.Color, colorHints: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromBitmap(bitmap: android.graphics.Bitmap, /) -> WallpaperColors: ...
    @staticmethod
    def fromDrawable(drawable: android.graphics.drawable.Drawable, /) -> WallpaperColors: ...
    def getColorHints(self) -> int: ...
    def getPrimaryColor(self) -> android.graphics.Color: ...
    def getSecondaryColor(self) -> android.graphics.Color | None: ...
    def getTertiaryColor(self) -> android.graphics.Color | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WallpaperInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WallpaperInfo]] = ...
    def __init__(self, context: android.content.Context, service: android.content.pm.ResolveInfo, /) -> None: ...
    def describeContents(self) -> int: ...
    def dump(self, pw: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
    def getComponent(self) -> android.content.ComponentName: ...
    def getPackageName(self) -> str: ...
    def getServiceInfo(self) -> android.content.pm.ServiceInfo: ...
    def getServiceName(self) -> str: ...
    def getSettingsActivity(self) -> str: ...
    def getSettingsSliceUri(self) -> android.net.Uri | None: ...
    def getShowMetadataInPreview(self) -> bool: ...
    def loadAuthor(self, pm: android.content.pm.PackageManager, /) -> java.lang.CharSequence: ...
    def loadContextDescription(self, pm: android.content.pm.PackageManager, /) -> java.lang.CharSequence: ...
    def loadContextUri(self, pm: android.content.pm.PackageManager, /) -> android.net.Uri: ...
    def loadDescription(self, pm: android.content.pm.PackageManager, /) -> java.lang.CharSequence: ...
    def loadIcon(self, pm: android.content.pm.PackageManager, /) -> android.graphics.drawable.Drawable: ...
    def loadLabel(self, pm: android.content.pm.PackageManager, /) -> java.lang.CharSequence: ...
    def loadThumbnail(self, pm: android.content.pm.PackageManager, /) -> android.graphics.drawable.Drawable: ...
    def shouldUseDefaultUnfoldTransition(self) -> bool: ...
    def supportsMultipleDisplays(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class WallpaperManager(java.lang.Object):
    ACTION_CHANGE_LIVE_WALLPAPER: typing.ClassVar[str] = ...
    ACTION_CROP_AND_SET_WALLPAPER: typing.ClassVar[str] = ...
    ACTION_LIVE_WALLPAPER_CHOOSER: typing.ClassVar[str] = ...
    COMMAND_DROP: typing.ClassVar[str] = ...
    COMMAND_SECONDARY_TAP: typing.ClassVar[str] = ...
    COMMAND_TAP: typing.ClassVar[str] = ...
    EXTRA_LIVE_WALLPAPER_COMPONENT: typing.ClassVar[str] = ...
    FLAG_LOCK: typing.ClassVar[int] = ...
    FLAG_SYSTEM: typing.ClassVar[int] = ...
    WALLPAPER_PREVIEW_META_DATA: typing.ClassVar[str] = ...
    def addOnColorsChangedListener(self, listener: WallpaperManager.OnColorsChangedListener, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def clear(self) -> None: ...
    @typing.overload
    def clear(self, which: int | java.jint | java.lang.Integer, /) -> None: ...
    def clearWallpaper(self) -> None: ...
    def clearWallpaperOffsets(self, windowToken: android.os.IBinder, /) -> None: ...
    def forgetLoadedWallpaper(self) -> None: ...
    @typing.overload
    def getBuiltInDrawable(self) -> android.graphics.drawable.Drawable: ...
    @typing.overload
    def getBuiltInDrawable(self, which: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable: ...
    @typing.overload
    def getBuiltInDrawable(self, outWidth: int | java.jint | java.lang.Integer, outHeight: int | java.jint | java.lang.Integer, scaleToFit: bool | java.jboolean | java.lang.Boolean, horizontalAlignment: float | java.jfloat | java.lang.Float, verticalAlignment: float | java.jfloat | java.lang.Float, /) -> android.graphics.drawable.Drawable: ...
    @typing.overload
    def getBuiltInDrawable(self, outWidth: int | java.jint | java.lang.Integer, outHeight: int | java.jint | java.lang.Integer, scaleToFit: bool | java.jboolean | java.lang.Boolean, horizontalAlignment: float | java.jfloat | java.lang.Float, verticalAlignment: float | java.jfloat | java.lang.Float, which: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable: ...
    def getCropAndSetWallpaperIntent(self, imageUri: android.net.Uri, /) -> android.content.Intent: ...
    def getDesiredMinimumHeight(self) -> int: ...
    def getDesiredMinimumWidth(self) -> int: ...
    @typing.overload
    def getDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getDrawable(self, which: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getFastDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getFastDrawable(self, which: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    @staticmethod
    def getInstance(context: android.content.Context, /) -> WallpaperManager: ...
    def getWallpaperColors(self, which: int | java.jint | java.lang.Integer, /) -> WallpaperColors | None: ...
    def getWallpaperFile(self, which: int | java.jint | java.lang.Integer, /) -> android.os.ParcelFileDescriptor | None: ...
    def getWallpaperId(self, which: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getWallpaperInfo(self) -> WallpaperInfo | None: ...
    @typing.overload
    def getWallpaperInfo(self, which: int | java.jint | java.lang.Integer, /) -> WallpaperInfo | None: ...
    def hasResourceWallpaper(self, resid: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isSetWallpaperAllowed(self) -> bool: ...
    def isWallpaperSupported(self) -> bool: ...
    @typing.overload
    def peekDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def peekDrawable(self, which: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def peekFastDrawable(self) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def peekFastDrawable(self, which: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    def removeOnColorsChangedListener(self, callback: WallpaperManager.OnColorsChangedListener, /) -> None: ...
    def sendWallpaperCommand(self, windowToken: android.os.IBinder, action: str | java.lang.String, x: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, z: int | java.jint | java.lang.Integer, extras: android.os.Bundle, /) -> None: ...
    @typing.overload
    def setBitmap(self, bitmap: android.graphics.Bitmap, /) -> None: ...
    @typing.overload
    def setBitmap(self, fullImage: android.graphics.Bitmap, visibleCropHint: android.graphics.Rect, allowBackup: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    @typing.overload
    def setBitmap(self, fullImage: android.graphics.Bitmap, visibleCropHint: android.graphics.Rect, allowBackup: bool | java.jboolean | java.lang.Boolean, which: int | java.jint | java.lang.Integer, /) -> int: ...
    def setDisplayPadding(self, padding: android.graphics.Rect, /) -> None: ...
    @typing.overload
    def setResource(self, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setResource(self, resid: int | java.jint | java.lang.Integer, which: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def setStream(self, bitmapData: java.io.InputStream, /) -> None: ...
    @typing.overload
    def setStream(self, bitmapData: java.io.InputStream, visibleCropHint: android.graphics.Rect, allowBackup: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    @typing.overload
    def setStream(self, bitmapData: java.io.InputStream, visibleCropHint: android.graphics.Rect, allowBackup: bool | java.jboolean | java.lang.Boolean, which: int | java.jint | java.lang.Integer, /) -> int: ...
    def setWallpaperOffsetSteps(self, xStep: float | java.jfloat | java.lang.Float, yStep: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setWallpaperOffsets(self, windowToken: android.os.IBinder, xOffset: float | java.jfloat | java.lang.Float, yOffset: float | java.jfloat | java.lang.Float, /) -> None: ...
    def suggestDesiredDimensions(self, minimumWidth: int | java.jint | java.lang.Integer, minimumHeight: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnColorsChangedListener(java.lang.Object):
        def onColorsChanged(self, arg1: WallpaperColors, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class ZygotePreload(java.lang.Object):
    def doPreload(self, arg1: android.content.pm.ApplicationInfo, /) -> None: ...
